@@ -1,4 +1,4 @@
-/* Copyright (c) 2012-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2012-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -6,7 +6,6 @@
 package app.bittorrent;
 
 import org.simgrid.msg.Msg;
-import org.simgrid.msg.RngStream;
 
 class Main{
   private Main() {
@@ -14,9 +13,6 @@ class Main{
   }
 
   public static void main(String[] args) {
-    int[] seed = { 12345, 12345, 12345, 12345, 12345, 12345 };
-    RngStream.setPackageSeed(seed);
-
     Msg.init(args);
     if(args.length < 2) {
       Msg.info("Usage   : Bittorrent platform_file deployment_file");
