@@ -1,6 +1,6 @@
 #!/usr/bin/env perl
 
-# Copyright (c) 2011-2019. The SimGrid Team.
+# Copyright (c) 2011-2020. The SimGrid Team.
 # All rights reserved.
 
 # This program is free software; you can redistribute it and/or modify it
@@ -19,7 +19,7 @@ open FILE, $conf_file or die "Unable to open $conf_file";
 
 print "<!-- This platform was automatically converted from the OptorSim platform.\n";
 print "\n";
-print "  OptorSim files only describes information of the cluster interconnexion.\n";
+print "  OptorSim files only describes information of the cluster interconnection.\n";
 print "  In a sense, it reflects the topology of a National Research and Education\n";
 print "  Network (NREN), but not of a full-fledged computational platform.\n";
 print "  The caracteristics of each cluster have been artificially added.\n";
