@@ -1,4 +1,4 @@
-# Copyright (c) 2007-2019. The SimGrid Team. All rights reserved.
+# Copyright (c) 2007-2020. The SimGrid Team. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the license (GNU LGPL) which comes with this package.
@@ -6,7 +6,7 @@
 # This Python file acts as the foil to the corresponding XML file, where the
 # action takes place: Actors are started and stopped at predefined time
 
-from simgrid import *
+from simgrid import Engine, this_actor
 import sys
 
 
@@ -14,8 +14,7 @@ class Sleeper:
     """This actor just sleeps until termination"""
 
     def __init__(self, *args):
-        # sys.exit(1); simgrid.info("Exiting now (done sleeping or got killed)."))
-        this_actor.on_exit(lambda: print("BAAA"))
+        this_actor.on_exit(lambda: this_actor.info("Exiting now (done sleeping or got killed)."))
 
     def __call__(self):
         this_actor.info("Hello! I go to sleep.")
