@@ -1,4 +1,4 @@
-/* Copyright (c) 2012-2019. The SimGrid Team.
+/* Copyright (c) 2012-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -8,8 +8,6 @@
 #include "s4u-peer.hpp"
 #include "s4u-tracker.hpp"
 
-simgrid::xbt::Extension<simgrid::s4u::Host, HostBittorrent> HostBittorrent::EXTENSION_ID;
-
 int main(int argc, char* argv[])
 {
   simgrid::s4u::Engine e(&argc, argv);
@@ -19,12 +17,6 @@ int main(int argc, char* argv[])
 
   e.load_platform(argv[1]);
 
-  /* Install our extension on all existing hosts */
-  HostBittorrent::EXTENSION_ID = simgrid::s4u::Host::extension_create<HostBittorrent>();
-  std::vector<simgrid::s4u::Host*> list = simgrid::s4u::Engine::get_instance()->get_all_hosts();
-  for (auto const& host : list)
-    host->extension_set(new HostBittorrent(host));
-
   e.register_actor<Tracker>("tracker");
   e.register_actor<Peer>("peer");
   e.load_deployment(argv[2]);
