@@ -1,11 +1,11 @@
-/* Copyright (c) 2012-2019. The SimGrid Team.
+/* Copyright (c) 2012-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#ifndef BITTORRENT_TRACKER_HPP_
-#define BITTORRENT_TRACKER_HPP_
+#ifndef BITTORRENT_TRACKER_HPP
+#define BITTORRENT_TRACKER_HPP
 
 #include "s4u-bittorrent.hpp"
 #include <set>
@@ -32,7 +32,6 @@ public:
 
 class Tracker {
   double deadline;
-  RngStream stream;
   simgrid::s4u::Mailbox* mailbox;
   std::set<int> known_peers;
 
