@@ -1,4 +1,4 @@
-/* Copyright (c) 2010-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2010-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -67,13 +67,12 @@ public:
   {
     double compute_cost;
     do {
-      double* msg  = static_cast<double*>(mailbox->get());
+      const double* msg = static_cast<double*>(mailbox->get());
       compute_cost = *msg;
       delete msg;
 
       if (compute_cost > 0) /* If compute_cost is valid, execute a computation of that cost */
         simgrid::s4u::this_actor::execute(compute_cost);
-
     } while (compute_cost > 0); /* Stop when receiving an invalid compute_cost */
 
     XBT_INFO("Exiting now.");
