@@ -1,4 +1,4 @@
-/* Copyright (c) 2010-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2010-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -6,7 +6,6 @@
 #include "s4u-dht-chord.hpp"
 
 XBT_LOG_NEW_DEFAULT_CATEGORY(s4u_chord, "Messages specific for this s4u example");
-simgrid::xbt::Extension<simgrid::s4u::Host, HostChord> HostChord::EXTENSION_ID;
 
 int nb_bits  = 24;
 int nb_keys  = 0;
@@ -43,10 +42,6 @@ int main(int argc, char* argv[])
   nb_keys = 1U << nb_bits;
   XBT_DEBUG("Sets nb_keys to %d", nb_keys);
 
-  HostChord::EXTENSION_ID = simgrid::s4u::Host::extension_create<HostChord>();
-  for (auto const& host : simgrid::s4u::Engine::get_instance()->get_all_hosts())
-    host->extension_set(new HostChord(host));
-
   e.register_actor<Node>("node");
   e.load_deployment(options[1]);
 
