@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# Copyright (c) 2012-2018. The SimGrid Team.
+# Copyright (c) 2012-2020. The SimGrid Team.
 # All rights reserved.
 
 # This program is free software; you can redistribute it and/or modify it
@@ -22,7 +22,7 @@ max_id = 2 ** nb_bits - 1
 all_ids = [0]
 
 sys.stdout.write("<?xml version='1.0'?>\n"
-                 "<!DOCTYPE platform SYSTEM \"http://simgrid.gforge.inria.fr/simgrid/simgrid.dtd\">\n"
+                 "<!DOCTYPE platform SYSTEM \"https://simgrid.org/simgrid.dtd\">\n"
                  "<platform version=\"4\">\n  <process host=\"node-0.simgrid.org\" function=\"node\">\n"
                  "     <argument value=\"0\"/>\n     <argument value=\"%d\"/>\n  </process>\n" % end_date)
 
@@ -30,7 +30,7 @@ for i in range(1, nb_nodes):
     ok = False
     while not ok:
         my_id = random.randint(0, max_id)
-        ok = not my_id in all_ids
+        ok = my_id not in all_ids
     known_id = all_ids[random.randint(0, len(all_ids) - 1)]
     start_date = i * 10
     line = "  <process host=\"node-%d.simgrid.org\" function=\"node\">\n    <argument value=\"%s\"/>"\
