@@ -1,4 +1,4 @@
-/* Copyright (c) 2009-2019. The SimGrid Team.
+/* Copyright (c) 2009-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -14,7 +14,7 @@
       This is done to avoid SMPI actors to start at actor_id=0.
    3. For each job:
         1. Sleep until job's starting time is reached (if needed)
-        2. Launch the replay of the corresponding time-indepent trace.
+        2. Launch the replay of the corresponding time-independent trace.
         3. Create inter-process noise, by spawning useless actors.
    4. Wait for completion (via s4u::Engine's run method)
 */
@@ -65,7 +65,7 @@ static void smpi_replay_process(Job* job, simgrid::s4u::BarrierPtr barrier, int
 }
 
 // Sleeps for a given amount of time
-static int sleeper_process(int* param)
+static int sleeper_process(const int* param)
 {
   XBT_DEBUG("Sleeping for %d seconds", *param);
   simgrid::s4u::this_actor::sleep_for(*param);
@@ -106,7 +106,7 @@ static int job_executor_process(Job* job)
 }
 
 // Executes a workload of SMPI processes
-static int workload_executor_process(std::vector<Job*>* workload)
+static int workload_executor_process(const std::vector<Job*>* workload)
 {
   for (Job* job : *workload) {
     // Let's wait until the job's waiting time if needed
