@@ -1,4 +1,4 @@
-/* Copyright (c) 2010-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2010-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -23,7 +23,7 @@ public:
       : name_(name), start_time_(start_time), end_time_(end_time), type_(type)
   {
   }
-  void add_characteristic(char* characteristic);
+  void add_characteristic(const char* characteristic);
   void add_resources(const std::vector<sg_host_t>& host_selection);
   void add_info(char* key, char* value);
   void print(FILE* file) const;
