@@ -1,4 +1,4 @@
-/* Copyright (c) 2004-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -34,6 +34,8 @@ public:
 
   virtual ~Model();
 
+  bool is_update_lazy() { return update_algorithm_ == UpdateAlgo::LAZY; }
+
   /** @brief Get the set of [actions](@ref Action) in *inited* state */
   Action::StateSet* get_inited_action_set() { return &inited_action_set_; }
 
@@ -59,7 +61,10 @@ public:
   void set_maxmin_system(lmm::System* system);
 
   /** @brief Get the update algorithm of the current Model */
-  UpdateAlgo get_update_algorithm() const { return update_algorithm_; }
+  XBT_ATTRIB_DEPRECATED_v329("Please use is_update_lazy()") UpdateAlgo get_update_algorithm() const
+  {
+    return update_algorithm_;
+  }
 
   /** @brief Get Action heap */
   ActionHeap& get_action_heap() { return action_heap_; }
@@ -70,9 +75,24 @@ public:
    * @param now The current time of the simulation
    * @return The delta of time till the next action will finish
    */
-  virtual double next_occuring_event(double now);
-  virtual double next_occuring_event_lazy(double now);
-  virtual double next_occuring_event_full(double now);
+  virtual double next_occurring_event(double now);
+  virtual double next_occurring_event_lazy(double now);
+  virtual double next_occurring_event_full(double now);
+
+  XBT_ATTRIB_DEPRECATED_v329("Please use next_occurring_event()") virtual double next_occuring_event(double now) final
+  {
+    return next_occurring_event(now);
+  }
+  XBT_ATTRIB_DEPRECATED_v329("Please use next_occurring_event_lazy()") virtual double next_occuring_event_lazy(
+      double now) final
+  {
+    return next_occurring_event_lazy(now);
+  }
+  XBT_ATTRIB_DEPRECATED_v329("Please use next_occurring_event_full()") virtual double next_occuring_event_full(
+      double now) final
+  {
+    return next_occurring_event_full(now);
+  }
 
 private:
   Action* extract_action(Action::StateSet* list);
@@ -96,7 +116,13 @@ public:
    * The only model that is not is ns-3: computing the next timestamp moves the model up to that point,
    * so we need to call it only when the next timestamp of other sources is computed.
    */
-  virtual bool next_occuring_event_is_idempotent() { return true; }
+  virtual bool next_occurring_event_is_idempotent() { return true; }
+
+  XBT_ATTRIB_DEPRECATED_v329(
+      "Please use next_occurring_event_is_idempotent()") virtual bool next_occuring_event_is_idempotent() final
+  {
+    return next_occurring_event_is_idempotent();
+  }
 
 private:
   std::unique_ptr<lmm::System> maxmin_system_;
