@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2013-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -14,7 +14,7 @@ namespace kernel {
 namespace routing {
 
 /** @ingroup ROUTING_API
- *  @brief NetZone with an explicit routing computed on need with Dijsktra
+ *  @brief NetZone with an explicit routing computed on need with Dijkstra
  *
  *  The path between components is computed each time you request it,
  *  using the Dijkstra algorithm. A cache can be used to reduce the computation.
@@ -23,19 +23,22 @@ namespace routing {
  * long path resolution times.
  */
 class XBT_PRIVATE DijkstraZone : public RoutedZone {
-public:
-  DijkstraZone(NetZoneImpl* father, const std::string& name, resource::NetworkModel* netmodel, bool cached);
-  DijkstraZone(const DijkstraZone&) = delete;
-  DijkstraZone& operator=(const DijkstraZone&) = delete;
-
-  ~DijkstraZone() override;
-
 private:
+  static void route_graph_delete(xbt_graph_t);
+
+  std::unique_ptr<s_xbt_graph_t, decltype(&DijkstraZone::route_graph_delete)> route_graph_{
+      xbt_graph_new_graph(1, nullptr), &DijkstraZone::route_graph_delete};
+  std::map<int, xbt_node_t> graph_node_map_;
+  bool cached_;
+  std::map<int, std::vector<int>> route_cache_;
+
   xbt_node_t route_graph_new_node(int id);
   xbt_node_t node_map_search(int id);
   void new_edge(int src_id, int dst_id, RouteCreationArgs* e_route);
 
 public:
+  DijkstraZone(NetZoneImpl* father, const std::string& name, resource::NetworkModel* netmodel, bool cached);
+
   /* For each vertex (node) already in the graph,
    * make sure it also has a loopback link; this loopback
    * can potentially already be in the graph, and in that
@@ -51,11 +54,6 @@ public:
   void get_local_route(NetPoint* src, NetPoint* dst, RouteCreationArgs* route, double* lat) override;
   void add_route(NetPoint* src, NetPoint* dst, NetPoint* gw_src, NetPoint* gw_dst,
                  std::vector<resource::LinkImpl*>& link_list, bool symmetrical) override;
-
-  xbt_graph_t route_graph_ = nullptr;          /* xbt_graph */
-  std::map<int, xbt_node_t> graph_node_map_;   /* map */
-  bool cached_;                                /* cache mode */
-  std::map<int, std::vector<int>> route_cache_; /* use in cache mode */
 };
 } // namespace routing
 } // namespace kernel
