@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2013-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -29,7 +29,7 @@ public:
     /* There can't be route in an Empty zone */
   }
 
-  void get_graph(xbt_graph_t graph, std::map<std::string, xbt_node_t>* /*nodes*/,
+  void get_graph(const s_xbt_graph_t* graph, std::map<std::string, xbt_node_t>* /*nodes*/,
                  std::map<std::string, xbt_edge_t>* /*edges*/) override;
 };
 } // namespace routing
