@@ -1,4 +1,4 @@
-/* Copyright (c) 2014-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2014-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -51,7 +51,7 @@ public:
    * instead of passing by an upper level switch.
    */
   resource::LinkImpl* loopback;
-  FatTreeNode(ClusterCreationArgs* cluster, int id, int level, int position);
+  FatTreeNode(const ClusterCreationArgs* cluster, int id, int level, int position);
 };
 
 /** @brief Link in a fat tree (@ref FatTreeZone).
@@ -61,7 +61,7 @@ public:
  */
 class FatTreeLink {
 public:
-  FatTreeLink(ClusterCreationArgs* cluster, FatTreeNode* source, FatTreeNode* destination);
+  FatTreeLink(const ClusterCreationArgs* cluster, FatTreeNode* source, FatTreeNode* destination);
   /** Link going up in the tree */
   resource::LinkImpl* up_link_;
   /** Link going down in the tree */
