@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2013-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -55,7 +55,7 @@ public:
 namespace vivaldi {
 class XBT_PRIVATE Coords {
 public:
-  static simgrid::xbt::Extension<NetPoint, Coords> EXTENSION_ID;
+  static xbt::Extension<NetPoint, Coords> EXTENSION_ID;
   explicit Coords(NetPoint* host, const std::string& str);
   virtual ~Coords() = default;
 
