@@ -1,4 +1,4 @@
-/* Copyright (c) 2017-2019. The SimGrid Team.
+/* Copyright (c) 2017-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -10,12 +10,12 @@
 #include <simgrid/forward.h>
 #include <xbt/base.h>
 
-SG_BEGIN_DECL()
+SG_BEGIN_DECL
 
 XBT_PUBLIC void sg_host_dvfs_plugin_init();
 
 #define MSG_host_dvfs_plugin_init() sg_host_dvfs_plugin_init()
 
-SG_END_DECL()
+SG_END_DECL
 
 #endif
