@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2006-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -19,110 +19,27 @@
 #include <unordered_map>
 
 namespace simgrid {
+
+extern template class XBT_PUBLIC xbt::Extendable<s4u::Actor>;
+
 namespace s4u {
 
-/**
+/** An actor is an independent stream of execution in your distributed application.
  *
- * An actor is an independent stream of execution in your distributed application.
+ * \rst
+ * It is located on a (simulated) :cpp:class:`host <simgrid::s4u::Host>`, but can interact
+ * with the whole simulated platform.
  *
  * You can think of an actor as a process in your distributed application, or as a thread in a multithreaded program.
  * This is the only component in SimGrid that actually does something on its own, executing its own code.
  * A resource will not get used if you don't schedule activities on them. This is the code of Actors that create and
- * schedule these activities.
+ * schedule these activities. **Please refer to the** :ref:`examples <s4u_ex_actors>` **for more information.**
  *
- * An actor is located on a (simulated) host, but it can interact
- * with the whole simulated platform.
+ * This API is strongly inspired from the C++11 threads.
+ * The `documentation of this standard <http://en.cppreference.com/w/cpp/thread>`_
+ * may help to understand the philosophy of the SimGrid actors.
  *
- * The s4u::Actor API is strongly inspired from the C++11 threads.
- * The <a href="http://en.cppreference.com/w/cpp/thread">documentation
- * of this standard</a> may help to understand the philosophy of the S4U
- * Actors.
- *
- * @section s4u_actor_def Defining the skeleton of an Actor
- *
- * As in the <a href="http://en.cppreference.com/w/cpp/thread">C++11
- * standard</a>, you can declare the code of your actor either as a
- * pure function or as an object. It is very simple with functions:
- *
- * @code{.cpp}
- * #include <simgrid/s4u/actor.hpp>
- *
- * // Declare the code of your worker
- * void worker() {
- *   printf("Hello s4u");
- *   simgrid::s4u::this_actor::execute(5*1024*1024); // Get the worker executing a task of 5 MFlops
- * };
- *
- * // From your main or from another actor, create your actor on the host Jupiter
- * // The following line actually creates a new actor, even if there is no "new".
- * Actor("Alice", simgrid::s4u::Host::by_name("Jupiter"), worker);
- * @endcode
- *
- * But some people prefer to encapsulate their actors in classes and
- * objects to save the actor state in a cleanly dedicated location.
- * The syntax is slightly more complicated, but not much.
- *
- * @code{.cpp}
- * #include <simgrid/s4u/actor.hpp>
- *
- * // Declare the class representing your actors
- * class Worker {
- * public:
- *   void operator()() { // Two pairs of () because this defines the method called ()
- *     printf("Hello s4u");
- *     simgrid::s4u::this_actor::execute(5*1024*1024); // Get the worker executing a task of 5 MFlops
- *   }
- * };
- *
- * // From your main or from another actor, create your actor. Note the () after Worker
- * Actor("Bob", simgrid::s4u::Host::by_name("Jupiter"), Worker());
- * @endcode
- *
- * @section s4u_actor_flesh Fleshing your actor
- *
- * The body of your actor can use the functions of the
- * simgrid::s4u::this_actor namespace to interact with the world.
- * This namespace contains the methods to start new activities
- * (executions, communications, etc), and to get informations about
- * the currently running thread (its location, etc).
- *
- * Please refer to the @link simgrid::s4u::this_actor full API @endlink.
- *
- *
- * @section s4u_actor_deploy Using a deployment file
- *
- * @warning This is currently not working with S4U. Sorry about that.
- *
- * The best practice is to use an external deployment file as
- * follows, because it makes it easier to test your application in
- * differing settings. Load this file with
- * s4u::Engine::loadDeployment() before the simulation starts.
- * Refer to the @ref deployment section for more information.
- *
- * @code{.xml}
- * <?xml version='1.0'?>
- * <!DOCTYPE platform SYSTEM "https://simgrid.org/simgrid.dtd">
- * <platform version="4.1">
- *
- *   <!-- Start an actor called 'master' on the host called 'Tremblay' -->
- *   <actor host="Tremblay" function="master">
- *      <!-- Here come the parameter that you want to feed to this instance of master -->
- *      <argument value="20"/>        <!-- argv[1] -->
- *      <argument value="50000000"/>  <!-- argv[2] -->
- *      <argument value="1000000"/>   <!-- argv[3] -->
- *      <argument value="5"/>         <!-- argv[4] -->
- *   </actor>
- *
- *   <!-- Start an actor called 'worker' on the host called 'Jupiter' -->
- *   <actor host="Jupiter" function="worker"/> <!-- Don't provide any parameter ->>
- *
- * </platform>
- * @endcode
- *
- *  @{
- */
-
-/** @brief Simulation Agent */
+ * \endrst */
 class XBT_PUBLIC Actor : public xbt::Extendable<Actor> {
 #ifndef DOXYGEN
   friend Exec;
@@ -136,14 +53,16 @@ class XBT_PUBLIC Actor : public xbt::Extendable<Actor> {
   explicit Actor(smx_actor_t pimpl) : pimpl_(pimpl) {}
 
 public:
-
+#ifndef DOXYGEN
   // ***** No copy *****
   Actor(Actor const&) = delete;
   Actor& operator=(Actor const&) = delete;
 
   // ***** Reference count *****
-  friend XBT_PUBLIC void intrusive_ptr_add_ref(Actor * actor);
-  friend XBT_PUBLIC void intrusive_ptr_release(Actor * actor);
+  friend XBT_PUBLIC void intrusive_ptr_add_ref(const Actor* actor);
+  friend XBT_PUBLIC void intrusive_ptr_release(const Actor* actor);
+#endif
+  /** Retrieve the amount of references on that object. Useful to debug the automatic refcounting */
   int get_refcount();
 
   // ***** Actor creation *****
@@ -160,14 +79,20 @@ public:
   static xbt::signal<void(Actor const&)> on_sleep;
   /** Signal to others that an actor wakes up for a sleep **/
   static xbt::signal<void(Actor const&)> on_wake_up;
-  /** Signal to others that an actor is going to migrated to another host**/
-  static xbt::signal<void(Actor const&)> on_migration_start;
   /** Signal to others that an actor is has been migrated to another host **/
-  static xbt::signal<void(Actor const&)> on_migration_end;
+  static xbt::signal<void(Actor const&, Host const& previous_location)> on_host_change;
+#ifndef DOXYGEN
+  static xbt::signal<void(Actor const&)> on_migration_start; // XBT_ATTRIB_DEPRECATED_v329
+  static xbt::signal<void(Actor const&)> on_migration_end;   // XBT_ATTRIB_DEPRECATED_v329
+#endif
+
   /** Signal indicating that an actor terminated its code.
+   *  @beginrst
    *  The actor may continue to exist if it is still referenced in the simulation, but it's not active anymore.
-   *  If you want to free extra data when the actor's destructor is called, use Actor::on_destruction.
-   *  If you want to register to the termination of a given actor, use this_actor::on_exit() instead.*/
+   *  If you want to free extra data when the actor's destructor is called, use :cpp:var:`Actor::on_destruction`.
+   *  If you want to register to the termination of a given actor, use :cpp:func:`this_actor::on_exit()` instead.
+   *  @endrst
+   */
   static xbt::signal<void(Actor const&)> on_termination;
   /** Signal indicating that an actor is about to disappear (its destructor was called).
    *  This signal is fired for any destructed actor, which is mostly useful when designing plugins and extensions.
@@ -175,18 +100,17 @@ public:
    *  If you want to register to the termination of a given actor, use this_actor::on_exit() instead.*/
   static xbt::signal<void(Actor const&)> on_destruction;
 
-  /** Create an actor from a std::function<void()>
-   *
-   *  If the actor is restarted, the actor has a fresh copy of the function.
-   */
+  /** Create an actor from a std::function<void()>.
+   *  If the actor is restarted, it gets a fresh copy of the function. */
   static ActorPtr create(const std::string& name, s4u::Host* host, const std::function<void()>& code);
+  /** Create an actor, but don't start it yet.
+   *
+   * This is usefull to set some properties or extension before actually starting it */
   static ActorPtr init(const std::string& name, s4u::Host* host);
+  /** Start a previously initialized actor */
   ActorPtr start(const std::function<void()>& code);
 
-  /** Create an actor from a std::function
-   *
-   *  If the actor is restarted, the actor has a fresh copy of the function.
-   */
+  /** Create an actor from a callable thing. */
   template <class F> static ActorPtr create(const std::string& name, s4u::Host* host, F code)
   {
     return create(name, host, std::function<void()>(std::move(code)));
@@ -203,7 +127,7 @@ public:
     return create(name, host, std::bind(std::move(code), std::move(args)...));
   }
 
-  // Create actor from function name:
+  /** Create actor from function name and a vector of strings as arguments. */
   static ActorPtr create(const std::string& name, s4u::Host* host, const std::string& function,
                          std::vector<std::string> args);
 
@@ -225,10 +149,10 @@ public:
   /** Retrieves the actor ID of that actor's creator */
   aid_t get_ppid() const;
 
-  /** Suspend an actor, that is blocked until resume()ed by another actor */
+  /** Suspend an actor, that is blocked until resumeed by another actor */
   void suspend();
 
-  /** Resume an actor that was previously suspend()ed */
+  /** Resume an actor that was previously suspended */
   void resume();
 
   /** Returns true if the actor is suspended. */
@@ -264,15 +188,15 @@ public:
    * Asynchronous activities started by the actor are not migrated automatically, so you have
    * to take care of this yourself (only you knows which ones should be migrated).
    */
-  void migrate(Host * new_host);
+  void set_host(Host* new_host);
+#ifndef DOXYGEN
+  XBT_ATTRIB_DEPRECATED_v329("Please use set_host() instead") void migrate(Host* new_host) { set_host(new_host); }
+#endif
 
   /** Ask the actor to die.
    *
    * Any blocking activity will be canceled, and it will be rescheduled to free its memory.
    * Being killed is not something that actors can defer or avoid.
-   *
-   * SimGrid still have sometimes issues when you kill actors that are currently communicating and such.
-   * Still. Please report any bug that you may encounter with a minimal working example.
    */
   void kill();
 
@@ -292,6 +216,7 @@ public:
    * blocked until bob terminates.
    */
   void join(double timeout);
+  /** Kill that actor and restart it from start. */
   Actor* restart();
 
   /** Kill all actors (but the issuer). Being killed is not something that actors can delay or avoid. */
@@ -305,13 +230,6 @@ public:
   get_properties() const; // FIXME: do not export the map, but only the keys or something
   const char* get_property(const std::string& key) const;
   void set_property(const std::string& key, const std::string& value);
-
-#ifndef DOXYGEN
-  XBT_ATTRIB_DEPRECATED_v325("Please use Actor::on_exit(fun) instead") void on_exit(
-      const std::function<void(int, void*)>& fun, void* data);
-
-  XBT_ATTRIB_DEPRECATED_v325("Please use Actor::by_pid(pid).kill() instead") static void kill(aid_t pid);
-#endif
 };
 
 /** @ingroup s4u_api
@@ -374,17 +292,18 @@ XBT_PUBLIC void execute(double flop, double priority);
  * vector means that `host0` should compute 1000 flops while `host1` will compute 2000 flops. A matrix of
  * communications' sizes of ``[0, 1, 2, 3]`` specifies the following data exchanges:
  *
- *   +-----------+-------+------+
- *   |from \\ to | host0 | host1|
- *   +===========+=======+======+
- *   |host0      |   0   |  1   |
- *   +-----------+-------+------+
- *   |host1      |   2   |  3   |
- *   +-----------+-------+------+
+ * - from host0: [ to host0:  0 bytes; to host1: 1 byte ]
+ *
+ * - from host1: [ to host0: 2 bytes; to host1: 3 bytes ]
+ *
+ * Or, in other words:
  *
  * - From host0 to host0: 0 bytes are exchanged
+ *
  * - From host0 to host1: 1 byte is exchanged
+ *
  * - From host1 to host0: 2 bytes are exchanged
+ *
  * - From host1 to host1: 3 bytes are exchanged
  *
  * In a parallel execution, all parts (all executions on each hosts, all communications) progress exactly at the
@@ -398,26 +317,17 @@ XBT_PUBLIC void execute(double flop, double priority);
  *
  * \endrst
  */
+/** Block the current actor until the built parallel execution completes */
 XBT_PUBLIC void parallel_execute(const std::vector<s4u::Host*>& hosts, const std::vector<double>& flops_amounts,
                                  const std::vector<double>& bytes_amounts);
 
-/** \rst
- * Block the current actor until the built :ref:`parallel execution <API_s4u_parallel_execute>` completes, or until the
- * timeout. \endrst
- */
-XBT_PUBLIC void parallel_execute(const std::vector<s4u::Host*>& hosts, const std::vector<double>& flops_amounts,
-                                 const std::vector<double>& bytes_amounts, double timeout);
-
-#ifndef DOXYGEN
-XBT_ATTRIB_DEPRECATED_v325("Please use std::vectors as parameters") XBT_PUBLIC
-    void parallel_execute(int host_nb, s4u::Host* const* host_list, const double* flops_amount,
-                          const double* bytes_amount);
-XBT_ATTRIB_DEPRECATED_v325("Please use std::vectors as parameters") XBT_PUBLIC
-    void parallel_execute(int host_nb, s4u::Host* const* host_list, const double* flops_amount,
-                          const double* bytes_amount, double timeout);
-#endif
+XBT_ATTRIB_DEPRECATED_v329("Please use exec_init(...)->wait_for(timeout)") XBT_PUBLIC
+    void parallel_execute(const std::vector<s4u::Host*>& hosts, const std::vector<double>& flops_amounts,
+                          const std::vector<double>& bytes_amounts, double timeout);
 
+/** Initialize a sequential execution that must then be started manually */
 XBT_PUBLIC ExecPtr exec_init(double flops_amounts);
+/** Initialize a parallel execution that must then be started manually */
 XBT_PUBLIC ExecPtr exec_init(const std::vector<s4u::Host*>& hosts, const std::vector<double>& flops_amounts,
                              const std::vector<double>& bytes_amounts);
 
@@ -443,9 +353,6 @@ XBT_PUBLIC void suspend();
 /** @brief Yield the current actor. */
 XBT_PUBLIC void yield();
 
-/** @brief Resume the current actor, that was suspend()ed previously. */
-XBT_PUBLIC void resume();
-
 /** @brief kill the current actor. */
 XBT_PUBLIC void exit();
 
@@ -466,13 +373,9 @@ XBT_PUBLIC void exit();
 XBT_PUBLIC void on_exit(const std::function<void(bool)>& fun);
 
 /** @brief Migrate the current actor to a new host. */
-XBT_PUBLIC void migrate(Host* new_host);
-
-/** @} */
-
+XBT_PUBLIC void set_host(Host* new_host);
 #ifndef DOXYGEN
-XBT_ATTRIB_DEPRECATED_v325("Please use std::function<void(bool)> for first parameter.") XBT_PUBLIC
-    void on_exit(const std::function<void(int, void*)>& fun, void* data);
+XBT_ATTRIB_DEPRECATED_v329("Please use set_host() instead") XBT_PUBLIC void migrate(Host* new_host);
 #endif
 }
 
