@@ -1,4 +1,4 @@
-/* Copyright (c) 2018-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2018-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -20,8 +20,8 @@ namespace s4u {
 
 class XBT_PUBLIC Barrier {
 private:
-  MutexPtr mutex_;
-  ConditionVariablePtr cond_;
+  MutexPtr mutex_            = Mutex::create();
+  ConditionVariablePtr cond_ = ConditionVariable::create();
   unsigned int expected_actors_;
   unsigned int arrived_actors_ = 0;
 
@@ -29,14 +29,17 @@ private:
   std::atomic_int_fast32_t refcount_{0};
 
 public:
-  explicit Barrier(unsigned int count);
-  ~Barrier()              = default;
+  /** Creates a barrier for the given amount of actors */
+  explicit Barrier(unsigned int expected_actors) : expected_actors_(expected_actors) {}
 #ifndef DOXYGEN
+  ~Barrier()              = default;
   Barrier(Barrier const&) = delete;
   Barrier& operator=(Barrier const&) = delete;
 #endif
 
+  /** Creates a barrier for the given amount of actors */
   static BarrierPtr create(unsigned int expected_actors);
+  /** Blocks into the barrier. Every waiting actors will be unlocked once the expected amount of actors reaches the barrier */
   int wait();
 
 #ifndef DOXYGEN
