@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2006-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -7,8 +7,8 @@
 #define SIMGRID_S4U_MAILBOX_HPP
 
 #include <simgrid/forward.h>
-
 #include <simgrid/s4u/Actor.hpp>
+#include <smpi/forward.hpp>
 #include <xbt/string.hpp>
 
 #include <string>
@@ -19,6 +19,7 @@ namespace s4u {
 /** @brief Mailboxes: Network rendez-vous points. */
 class XBT_PUBLIC Mailbox {
   friend Comm;
+  friend smpi::Request;
   friend kernel::activity::MailboxImpl;
 
   kernel::activity::MailboxImpl* const pimpl_;
@@ -26,16 +27,16 @@ class XBT_PUBLIC Mailbox {
   explicit Mailbox(kernel::activity::MailboxImpl * mbox) : pimpl_(mbox) {}
   ~Mailbox() = default;
 
-public:
-  /** private function, do not use. FIXME: make me protected */
+protected:
   kernel::activity::MailboxImpl* get_impl() const { return pimpl_; }
 
+public:
   /** @brief Retrieves the name of that mailbox as a C++ string */
   const xbt::string& get_name() const;
   /** @brief Retrieves the name of that mailbox as a C string */
   const char* get_cname() const;
 
-  /** Retrieve the mailbox associated to the given name */
+  /** Retrieve the mailbox associated to the given name. Mailboxes are created on demand. */
   static Mailbox* by_name(const std::string& name);
 
   /** Returns whether the mailbox contains queued communications */
@@ -80,7 +81,7 @@ public:
   /** Creates and start a data transmission to that mailbox */
   CommPtr put_async(void* data, uint64_t simulated_size_in_bytes);
 
-  smx_activity_t iprobe(int type, int (*match_fun)(void*, void*, kernel::activity::CommImpl*), void* data);
+  smx_activity_t iprobe(int type, bool (*match_fun)(void*, void*, kernel::activity::CommImpl*), void* data);
   /** Blocking data transmission */
   void put(void* payload, uint64_t simulated_size_in_bytes);
   /** Blocking data transmission with timeout */
