@@ -1,4 +1,4 @@
-/* Copyright (c) 2010-2019. The SimGrid Team.
+/* Copyright (c) 2010-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -19,7 +19,7 @@
 
 #if SIMGRID_HAVE_MC
 #undef assert
-#define assert(x) MC_assert(x)
+#define assert(x) MC_assert(!!(x))
 #endif
 
 #ifdef TRACE_CALL_LOCATION /* Defined by smpicc on the command line */
