@@ -1,4 +1,4 @@
-/* Copyright (c) 2018-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2018-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -34,6 +34,9 @@ int smpi_getopt_long(int argc, char* const* argv, const char* options, const str
                      int* opt_index);
 int smpi_getopt(int argc, char* const* argv, const char* options);
 
+void* smpi_shared_malloc_intercept(size_t size, const char* file, int line);
+void* smpi_shared_calloc_intercept(size_t num_elm, size_t elem_size, const char* file, int line);
+void smpi_shared_free(void* data);
 #ifdef __cplusplus
 } // extern "C"
 #endif
