@@ -1,4 +1,4 @@
-/* Copyright (c) 2005-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2005-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -8,16 +8,14 @@
 
 #include <xbt/base.h>
 
-#include <cstddef>
 #include <functional>
 #include <memory>
 #include <string>
-#include <vector>
 
-SG_BEGIN_DECL()
+SG_BEGIN_DECL
 /** @brief Shows a backtrace of the current location */
 XBT_PUBLIC void xbt_backtrace_display_current();
-SG_END_DECL()
+SG_END_DECL
 
 namespace simgrid {
 namespace xbt {
@@ -38,15 +36,10 @@ class BacktraceImpl;
  */
 class Backtrace {
 public:
-  BacktraceImpl* impl_ = nullptr;
+  std::shared_ptr<BacktraceImpl> impl_;
   Backtrace();
-  Backtrace(const Backtrace& bt);
-  Backtrace(Backtrace&& bt);
-  Backtrace& operator=(const Backtrace& rhs);
-  Backtrace& operator=(Backtrace&& rhs);
-  ~Backtrace();
   /** @brief Translate the backtrace in a human friendly form, unmangled with source code locations. */
-  std::string const resolve() const;
+  std::string resolve() const;
   /** @brief Display the resolved backtrace on stderr */
   void display() const;
 };
