@@ -1,6 +1,6 @@
 /* xbt.h - Public interface to the xbt (simgrid's toolbox)                  */
 
-/* Copyright (c) 2004-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -13,36 +13,18 @@
 #  define _GNU_SOURCE
 #endif
 
-// Teach the compiler that some code path is unreacheable:
-#if defined(__has_builtin)
-#  if __has_builtin(__builtin_unreachable)
-#    define XBT_UNREACHABLE() __builtin_unreachable()
-#  else
-#    include <stdlib.h>
-#    define XBT_UNREACHABLE() abort()
-#  endif
-#elif (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 5)
-#  define XBT_UNREACHABLE() __builtin_unreachable()
-#else
-#  include <stdlib.h>
-#  define XBT_UNREACHABLE() abort()
-#endif
-
 /* On MinGW, stdio.h defines __MINGW_PRINTF_FORMAT and __MINGW_SCANF_FORMAT
    which are the suitable format style (either gnu_printf or ms_printf)
    depending on which version is available (__USE_MINGW_ANSI_STDIO): */
 #ifdef __MINGW32__
 #  include <stdio.h>
 
-#  define XBT_ATTRIB_PRINTF( format_idx, arg_idx )    \
-     __attribute__((__format__ (__MINGW_PRINTF_FORMAT, format_idx, arg_idx)))
-#  define XBT_ATTRIB_SCANF( format_idx, arg_idx )     \
-     __attribute__((__MINGW_SCANF_FORMAT (__scanf__, format_idx, arg_idx)))
+#define XBT_ATTRIB_PRINTF(format_idx, arg_idx)                                                                         \
+  __attribute__((__format__(__MINGW_PRINTF_FORMAT, (format_idx), (arg_idx))))
+#define XBT_ATTRIB_SCANF(format_idx, arg_idx) __attribute__((__MINGW_SCANF_FORMAT(__scanf__, (format_idx), (arg_idx))))
 #else
-#  define XBT_ATTRIB_PRINTF( format_idx, arg_idx )    \
-     __attribute__((__format__ (__printf__, format_idx, arg_idx)))
-#  define XBT_ATTRIB_SCANF( format_idx, arg_idx )     \
-     __attribute__((__format__ (__scanf__, format_idx, arg_idx)))
+#define XBT_ATTRIB_PRINTF(format_idx, arg_idx) __attribute__((__format__(__printf__, (format_idx), (arg_idx))))
+#define XBT_ATTRIB_SCANF(format_idx, arg_idx) __attribute__((__format__(__scanf__, (format_idx), (arg_idx))))
 #endif
 
 #if defined(__cplusplus)
@@ -71,12 +53,10 @@
 #define XBT_ATTRIB_DEPRECATED(mesg) __attribute__((deprecated(mesg)))
 #endif
 
-#define XBT_ATTRIB_DEPRECATED_v324(mesg)                                                                               \
-  XBT_ATTRIB_DEPRECATED(mesg " (this compatibility wrapper will be dropped in v3.24)") /* Will be dropped in v3.24 */
-#define XBT_ATTRIB_DEPRECATED_v325(mesg)                                                                               \
-  XBT_ATTRIB_DEPRECATED(mesg " (this compatibility wrapper will be dropped in v3.25)") /* Will be dropped in v3.25 */
-#define XBT_ATTRIB_DEPRECATED_v326(mesg)                                                                               \
-  XBT_ATTRIB_DEPRECATED(mesg " (this compatibility wrapper will be dropped in v3.26)") /* Will be dropped in v3.26 */
+#define XBT_ATTRIB_DEPRECATED_v328(mesg)                                                                               \
+  XBT_ATTRIB_DEPRECATED(mesg " (this compatibility wrapper will be dropped in v3.28)")
+#define XBT_ATTRIB_DEPRECATED_v329(mesg)                                                                               \
+  XBT_ATTRIB_DEPRECATED(mesg " (this compatibility wrapper will be dropped in v3.29)")
 
 #if !defined(__APPLE__)
 #  define XBT_ATTRIB_CONSTRUCTOR(prio) __attribute__((__constructor__(prio)))
@@ -94,6 +74,15 @@
 #  endif
 #endif
 
+/* Stringify argument. */
+#define _XBT_STRINGIFY(a) #a
+
+/* Concatenate arguments. _XBT_CONCAT2 adds a level of indirection over _XBT_CONCAT. */
+#define _XBT_CONCAT(a, b) a##b
+#define _XBT_CONCAT2(a, b) _XBT_CONCAT(a, b)
+#define _XBT_CONCAT3(a, b, c) _XBT_CONCAT2(_XBT_CONCAT2(a, b), c)
+#define _XBT_CONCAT4(a, b, c, d) _XBT_CONCAT2(_XBT_CONCAT3(a, b, c), d)
+
 /*
  * Expands to `one' if there is only one argument for the variadic part.
  * Otherwise, expands to `more'.
@@ -182,17 +171,17 @@
 /* C++ users need love */
 #ifndef SG_BEGIN_DECL
 # ifdef __cplusplus
-#  define SG_BEGIN_DECL() extern "C" {
+#  define SG_BEGIN_DECL extern "C" {
 # else
-#  define SG_BEGIN_DECL()
+#  define SG_BEGIN_DECL
 # endif
 #endif
 
 #ifndef SG_END_DECL
 # ifdef __cplusplus
-#  define SG_END_DECL() }
+#  define SG_END_DECL }
 # else
-#  define SG_END_DECL()
+#  define SG_END_DECL
 # endif
 #endif
 /* End of cruft for C++ */
