@@ -1,4 +1,4 @@
-/* Copyright (c) 2016-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2016-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -217,7 +217,6 @@ class Flag {
   std::string name_;
 
 public:
-
   /** Constructor
    *
    *  @param name  Flag name
@@ -287,7 +286,7 @@ public:
   template<class U>
   Flag& operator=(U const& that) { value_ = that; return *this; }
   template<class U>
-  Flag& operator=(U && that)     { value_ = that; return *this; }
+  Flag& operator=(U&& that) { value_ = std::forward<U>(that); return *this; }
   template<class U>
   bool operator==(U const& that) const { return value_ == that; }
   template<class U>
@@ -305,7 +304,7 @@ public:
 XBT_PUBLIC void finalize();
 XBT_PUBLIC void show_aliases();
 XBT_PUBLIC void help();
-}
-}
+} // namespace config
+} // namespace simgrid
 
 #endif
