@@ -1,6 +1,6 @@
 /* dynar - a generic dynamic array                                          */
 
-/* Copyright (c) 2004-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -13,14 +13,14 @@
 #include <xbt/base.h> /* SG_BEGIN_DECL */
 #include <xbt/function_types.h>
 
-SG_BEGIN_DECL()
+SG_BEGIN_DECL
 
 /** @addtogroup XBT_dynar
  * @brief DynArr are dynamically sized vector which may contain any type of variables.
  *
  * These are the SimGrid version of the dynamically size arrays, which all C programmer recode one day or another.
  *
- * For performance concerns, the content of DynArr must be homogeneous (in contrary to dictionnaries -- see the
+ * For performance concerns, the content of DynArr must be homogeneous (in contrary to dictionaries -- see the
  * @ref XBT_dict section). You thus have to provide the function which will be used to free the content at
  * structure creation (of type void_f_pvoid_t).
  *
@@ -63,15 +63,12 @@ SG_BEGIN_DECL()
  */
 /** @brief Dynar data type (opaque type) */
 typedef struct xbt_dynar_s *xbt_dynar_t;
+typedef const struct xbt_dynar_s* const_xbt_dynar_t;
 
-XBT_PUBLIC xbt_dynar_t xbt_dynar_new(const unsigned long elm_size, void_f_pvoid_t const free_f);
-XBT_PUBLIC void xbt_dynar_init(xbt_dynar_t dynar, const unsigned long elmsize, void_f_pvoid_t const free_f);
+XBT_PUBLIC xbt_dynar_t xbt_dynar_new(const unsigned long elm_size, void_f_pvoid_t free_f);
 XBT_PUBLIC void xbt_dynar_free(xbt_dynar_t* dynar);
-XBT_PUBLIC void xbt_dynar_free_voidp(void* dynar);
 XBT_PUBLIC void xbt_dynar_free_container(xbt_dynar_t* dynar);
-XBT_PUBLIC void xbt_dynar_free_data(xbt_dynar_t dynar);
 XBT_PUBLIC void xbt_dynar_shrink(xbt_dynar_t dynar, int empty_slots);
-XBT_PUBLIC void xbt_dynar_dump(xbt_dynar_t dynar);
 
 /** @} */
 /** @defgroup XBT_dynar_array Dynar as a regular array
@@ -80,19 +77,14 @@ XBT_PUBLIC void xbt_dynar_dump(xbt_dynar_t dynar);
  *  @{
  */
 
-XBT_PUBLIC void xbt_dynar_get_cpy(const xbt_dynar_t dynar, const unsigned long idx, void* const dst);
-XBT_PUBLIC void xbt_dynar_set(xbt_dynar_t dynar, const int idx, const void* src);
-XBT_PUBLIC void xbt_dynar_replace(xbt_dynar_t dynar, const unsigned long idx, const void* object);
+XBT_PUBLIC void xbt_dynar_get_cpy(const_xbt_dynar_t dynar, unsigned long idx, void* dst);
 
-XBT_PUBLIC void xbt_dynar_insert_at(xbt_dynar_t const dynar, const int idx, const void* src);
-XBT_PUBLIC void xbt_dynar_remove_at(xbt_dynar_t const dynar, const int idx, void* const dst);
-XBT_PUBLIC void xbt_dynar_remove_n_at(xbt_dynar_t const dynar, const unsigned int n, const int idx);
+XBT_PUBLIC void xbt_dynar_insert_at(xbt_dynar_t dynar, int idx, const void* src);
+XBT_PUBLIC void xbt_dynar_remove_at(xbt_dynar_t dynar, int idx, void* dst);
 
-XBT_PUBLIC unsigned int xbt_dynar_search(xbt_dynar_t const dynar, void* elem);
-XBT_PUBLIC signed int xbt_dynar_search_or_negative(xbt_dynar_t const dynar, void* const elem);
-XBT_PUBLIC int xbt_dynar_member(xbt_dynar_t const dynar, void* elem);
-XBT_PUBLIC void xbt_dynar_sort(xbt_dynar_t const dynar, int_f_cpvoid_cpvoid_t compar_fn);
-XBT_PUBLIC int xbt_dynar_compare(xbt_dynar_t d1, xbt_dynar_t d2, int (*compar)(const void*, const void*));
+XBT_PUBLIC signed int xbt_dynar_search_or_negative(const_xbt_dynar_t dynar, const void* elem);
+XBT_PUBLIC int xbt_dynar_member(const_xbt_dynar_t dynar, const void* elem);
+XBT_PUBLIC void xbt_dynar_sort(const_xbt_dynar_t dynar, int_f_cpvoid_cpvoid_t compar_fn);
 XBT_PUBLIC void* xbt_dynar_to_array(xbt_dynar_t dynar);
 
 /** @} */
@@ -102,10 +94,9 @@ XBT_PUBLIC void* xbt_dynar_to_array(xbt_dynar_t dynar);
  *  @{
  */
 
-XBT_PUBLIC unsigned long xbt_dynar_length(const xbt_dynar_t dynar);
-XBT_PUBLIC int xbt_dynar_is_empty(const xbt_dynar_t dynar);
-XBT_PUBLIC void xbt_dynar_reset(xbt_dynar_t const dynar);
-XBT_PUBLIC void xbt_dynar_merge(xbt_dynar_t* d1, xbt_dynar_t* d2);
+XBT_PUBLIC unsigned long xbt_dynar_length(const_xbt_dynar_t dynar);
+XBT_PUBLIC int xbt_dynar_is_empty(const_xbt_dynar_t dynar);
+XBT_PUBLIC void xbt_dynar_reset(xbt_dynar_t dynar);
 
 /** @} */
 /** @defgroup XBT_dynar_perl Perl-like use of dynars
@@ -114,11 +105,11 @@ XBT_PUBLIC void xbt_dynar_merge(xbt_dynar_t* d1, xbt_dynar_t* d2);
  *  @{
  */
 
-XBT_PUBLIC void xbt_dynar_push(xbt_dynar_t const dynar, const void* src);
-XBT_PUBLIC void xbt_dynar_pop(xbt_dynar_t const dynar, void* const dst);
-XBT_PUBLIC void xbt_dynar_unshift(xbt_dynar_t const dynar, const void* src);
-XBT_PUBLIC void xbt_dynar_shift(xbt_dynar_t const dynar, void* const dst);
-XBT_PUBLIC void xbt_dynar_map(const xbt_dynar_t dynar, void_f_pvoid_t const op);
+XBT_PUBLIC void xbt_dynar_push(xbt_dynar_t dynar, const void* src);
+XBT_PUBLIC void xbt_dynar_pop(xbt_dynar_t dynar, void* dst);
+XBT_PUBLIC void xbt_dynar_unshift(xbt_dynar_t dynar, const void* src);
+XBT_PUBLIC void xbt_dynar_shift(xbt_dynar_t dynar, void* dst);
+XBT_PUBLIC void xbt_dynar_map(const_xbt_dynar_t dynar, void_f_pvoid_t op);
 
 /** @} */
 /** @defgroup XBT_dynar_ctn Direct manipulation to the dynars content
@@ -129,11 +120,11 @@ XBT_PUBLIC void xbt_dynar_map(const xbt_dynar_t dynar, void_f_pvoid_t const op);
  *  @{
  */
 
-XBT_PUBLIC void* xbt_dynar_set_at_ptr(const xbt_dynar_t dynar, const unsigned long idx);
-XBT_PUBLIC void* xbt_dynar_get_ptr(const xbt_dynar_t dynar, const unsigned long idx);
-XBT_PUBLIC void* xbt_dynar_insert_at_ptr(xbt_dynar_t const dynar, const int idx);
-XBT_PUBLIC void* xbt_dynar_push_ptr(xbt_dynar_t const dynar);
-XBT_PUBLIC void* xbt_dynar_pop_ptr(xbt_dynar_t const dynar);
+XBT_PUBLIC void* xbt_dynar_set_at_ptr(const xbt_dynar_t dynar, unsigned long idx);
+XBT_PUBLIC void* xbt_dynar_get_ptr(const_xbt_dynar_t dynar, unsigned long idx);
+XBT_PUBLIC void* xbt_dynar_insert_at_ptr(xbt_dynar_t dynar, int idx);
+XBT_PUBLIC void* xbt_dynar_push_ptr(xbt_dynar_t dynar);
+XBT_PUBLIC void* xbt_dynar_pop_ptr(xbt_dynar_t dynar);
 
 /** @} */
 /** @defgroup XBT_dynar_speed Speed optimized access to dynars of scalars
@@ -160,9 +151,6 @@ XBT_PUBLIC void* xbt_dynar_pop_ptr(xbt_dynar_t const dynar);
  *  @hideinitializer */
 #  define xbt_dynar_getfirst_as(dynar,type) \
           (*(type*)xbt_dynar_get_ptr((dynar),0))
-/** @brief Quick insertion of scalar content
- *  @hideinitializer */
-#define xbt_dynar_insert_at_as(dynar, idx, type, value) *(type*)xbt_dynar_insert_at_ptr((dynar), (idx)) = (value)
 /** @brief Quick insertion of scalar content
  *  @hideinitializer */
 #define xbt_dynar_push_as(dynar, type, value) *(type*)xbt_dynar_push_ptr(dynar) = (value)
@@ -183,7 +171,7 @@ XBT_PUBLIC void* xbt_dynar_pop_ptr(xbt_dynar_t const dynar);
  *  @{
  */
 
-XBT_PUBLIC void xbt_dynar_cursor_rm(xbt_dynar_t dynar, unsigned int* const cursor);
+XBT_PUBLIC void xbt_dynar_cursor_rm(xbt_dynar_t dynar, unsigned int* cursor);
 
 /*
  * @warning DO NOT USE THIS STRUCTURE DIRECTLY! Instead, use the public interface:
@@ -201,7 +189,7 @@ typedef struct xbt_dynar_s {
   void_f_pvoid_t free_f;
 } s_xbt_dynar_t;
 
-static inline int _xbt_dynar_cursor_get(const xbt_dynar_t dynar, unsigned int idx, void* const dst)
+static inline int _xbt_dynar_cursor_get(const_xbt_dynar_t dynar, unsigned int idx, void* dst)
 {
   if (!dynar) /* iterating over a NULL dynar is a no-op */
     return 0;
@@ -237,17 +225,7 @@ xbt_dynar_foreach (dyn,cpt,str) {
 #define xbt_dynar_foreach(_dynar, _cursor, _data)                                                                      \
   for ((_cursor) = 0; _xbt_dynar_cursor_get((_dynar), (_cursor), &(_data)); (_cursor)++)
 
-#ifndef __cplusplus
-#define xbt_dynar_foreach_ptr(_dynar, _cursor, _ptr)                                                                   \
-  for ((_cursor) = 0; ((_ptr) = (_cursor) < (_dynar)->used ? xbt_dynar_get_ptr((_dynar), (_cursor)) : NULL);           \
-       (_cursor)++)
-#else
-#define xbt_dynar_foreach_ptr(_dynar, _cursor, _ptr)                                                                   \
-  for ((_cursor) = 0;                                                                                                  \
-       ((_ptr) = (_cursor) < (_dynar)->used ? (decltype(_ptr))xbt_dynar_get_ptr((_dynar), (_cursor)) : NULL);          \
-       (_cursor)++)
-#endif
 /** @} */
-SG_END_DECL()
+SG_END_DECL
 
 #endif /* XBT_DYNAR_H */
