@@ -1,6 +1,6 @@
 /* function_type.h - classical types for pointer to function                */
 
-/* Copyright (c) 2006-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2006-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -10,7 +10,7 @@
 
 #include <xbt/base.h>
 
-SG_BEGIN_DECL()
+SG_BEGIN_DECL
 
 typedef void (*void_f_pvoid_t) (void *);
 typedef void *(*pvoid_f_void_t) (void);
@@ -23,5 +23,5 @@ typedef int (*int_f_cpvoid_cpvoid_t) (const void *, const void *);
 
 typedef int (*xbt_main_func_t) (int argc, char *argv[]);
 
-SG_END_DECL()
+SG_END_DECL
 #endif                          /* XBT_FUNCTION_TYPE_H */
