@@ -1,4 +1,4 @@
-/* Copyright (c) 2015-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2015-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -27,7 +27,6 @@ namespace simgrid {
 namespace xbt {
 
 template <class F> class MainFunction {
-private:
   F code_;
   std::shared_ptr<const std::vector<std::string>> args_;
 
@@ -109,8 +108,6 @@ template<class T> class Task;
  */
 template<class R, class... Args>
 class Task<R(Args...)> {
-private:
-
   // Placeholder for some class type:
   struct whatever {};
 
@@ -171,8 +168,7 @@ public:
       that.vtable_->move(buffer_, that.buffer_);
     else
       std::memcpy(static_cast<void*>(&buffer_), static_cast<void*>(&that.buffer_), sizeof(buffer_));
-
-    vtable_ = that.vtable_;
+    vtable_      = std::move(that.vtable_);
     that.vtable_ = nullptr;
   }
   Task& operator=(Task const& that) = delete;
@@ -183,13 +179,12 @@ public:
       that.vtable_->move(buffer_, that.buffer_);
     else
       std::memcpy(static_cast<void*>(&buffer_), static_cast<void*>(&that.buffer_), sizeof(buffer_));
-    vtable_ = that.vtable_;
+    vtable_      = std::move(that.vtable_);
     that.vtable_ = nullptr;
     return *this;
   }
 
 private:
-
   template<class F>
   typename std::enable_if<canSBO<F>()>::type
   init(F code)
@@ -200,6 +195,7 @@ private:
         F* src = reinterpret_cast<F*>(&buffer);
         F code = std::move(*src);
         src->~F();
+        // NOTE: std::forward<Args>(args)... is correct.
         return code(std::forward<Args>(args)...);
       },
       // Destroy:
@@ -228,6 +224,7 @@ private:
       [](TaskUnion& buffer, Args... args) {
         // Delete F when we go out of scope:
         std::unique_ptr<F> code(*reinterpret_cast<F**>(&buffer));
+        // NOTE: std::forward<Args>(args)... is correct.
         return (*code)(std::forward<Args>(args)...);
       },
       // Destroy:
@@ -254,13 +251,14 @@ public:
       throw std::bad_function_call();
     const TaskVtable* vtable = vtable_;
     vtable_ = nullptr;
+    // NOTE: std::forward<Args>(args)... is correct.
+    // see C++ [func.wrap.func.inv] for an example
     return vtable->call(buffer_, std::forward<Args>(args)...);
   }
 };
 
 template<class F, class... Args>
 class TaskImpl {
-private:
   F code_;
   std::tuple<Args...> args_;
   typedef decltype(simgrid::xbt::apply(std::move(code_), std::move(args_))) result_type;
