@@ -1,6 +1,6 @@
 /* log - a generic logging facility in the spirit of log4j                  */
 
-/* Copyright (c) 2004-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -33,7 +33,7 @@
 #include <stddef.h> /* NULL */
 #include <stdio.h>  /* FILE */
 #include <xbt/misc.h>
-SG_BEGIN_DECL()
+SG_BEGIN_DECL
 /**@brief Log priorities
  * @ingroup XBT_log
  *
@@ -102,8 +102,9 @@ typedef enum {
  * Implementation of XBT_LOG_NEW_SUBCATEGORY, which must declare "extern parent" in addition to avoid an extra
  * declaration of root when XBT_LOG_NEW_SUBCATEGORY is called by XBT_LOG_NEW_CATEGORY */
 #define XBT_LOG_NEW_SUBCATEGORY_helper(catName, parent, desc)                                                          \
-  SG_BEGIN_DECL()                                                                                                      \
+  SG_BEGIN_DECL                                                                                                        \
   extern void _XBT_LOGV_CTOR(catName)(void) XBT_ATTRIB_CONSTRUCTOR(600);                                               \
+  SG_END_DECL                                                                                                          \
   void _XBT_LOGV_CTOR(catName)(void)                                                                                   \
   {                                                                                                                    \
     XBT_LOG_EXTERNAL_CATEGORY(catName);                                                                                \
@@ -111,7 +112,6 @@ typedef enum {
       _xbt_log_cat_init(&_XBT_LOGV(catName), xbt_log_priority_uninitialized);                                          \
     }                                                                                                                  \
   }                                                                                                                    \
-  SG_END_DECL()                                                                                                        \
   XBT_EXPORT_NO_IMPORT s_xbt_log_category_t _XBT_LOGV(catName) = {                                                     \
       &_XBT_LOGV(parent),                                                                                              \
       NULL /* firstChild */,                                                                                           \
@@ -260,7 +260,7 @@ struct xbt_log_event_s {
  * @param cat the category (not only its name, but the variable)
  * @param thresholdPriority the priority
  *
- * Programatically alters a category's threshold priority (don't use).
+ * Programmatically alters a category's threshold priority (don't use).
  */
 XBT_PUBLIC void xbt_log_threshold_set(xbt_log_category_t cat, e_xbt_log_priority_t thresholdPriority);
 
@@ -269,7 +269,7 @@ XBT_PUBLIC void xbt_log_threshold_set(xbt_log_category_t cat, e_xbt_log_priority
  * @param cat the category (not only its name, but the variable)
  * @param app the appender
  *
- * Programatically sets the category's appender. (the preferred interface is through xbt_log_control_set())
+ * Programmatically sets the category's appender. (the preferred interface is through xbt_log_control_set())
  */
 XBT_PUBLIC void xbt_log_appender_set(xbt_log_category_t cat, xbt_log_appender_t app);
 /**
@@ -277,7 +277,7 @@ XBT_PUBLIC void xbt_log_appender_set(xbt_log_category_t cat, xbt_log_appender_t
  * @param cat the category (not only its name, but the variable)
  * @param lay the layout
  *
- * Programatically sets the category's layout. (the preferred interface is through xbt_log_control_set())
+ * Programmatically sets the category's layout. (the preferred interface is through xbt_log_control_set())
  */
 XBT_PUBLIC void xbt_log_layout_set(xbt_log_category_t cat, xbt_log_layout_t lay);
 
@@ -286,7 +286,7 @@ XBT_PUBLIC void xbt_log_layout_set(xbt_log_category_t cat, xbt_log_layout_t lay)
  * @param cat the category (not only its name, but the variable)
  * @param additivity whether logging actions must be passed to parent.
  *
- * Programatically sets whether the logging actions must be passed to the parent category.
+ * Programmatically sets whether the logging actions must be passed to the parent category.
  * (the preferred interface is through xbt_log_control_set())
  */
 XBT_PUBLIC void xbt_log_additivity_set(xbt_log_category_t cat, int additivity);
@@ -492,5 +492,5 @@ extern xbt_log_layout_t xbt_log_default_layout;
  */
 #define XBT_HELP(...) XBT_CINFO(xbt_help, __VA_ARGS__)
 
-SG_END_DECL()
-#endif                          /* ! _XBT_LOG_H_ */
+SG_END_DECL
+#endif /* XBT_LOG_H */
