@@ -1,6 +1,6 @@
 /* xbt/mallocator.h -- api to recycle allocated objects                     */
 
-/* Copyright (c) 2006-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2006-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -11,7 +11,7 @@
 #include <xbt/function_types.h>
 #include <xbt/misc.h>
 
-SG_BEGIN_DECL()
+SG_BEGIN_DECL
 
 /** @addtogroup XBT_mallocator
  *  @brief The mallocator system
@@ -50,5 +50,5 @@ XBT_PUBLIC void xbt_mallocator_release(xbt_mallocator_t mallocator, void* object
 XBT_PUBLIC void xbt_mallocator_initialization_is_done(int protect);
 /** @} */
 
-SG_END_DECL()
-#endif                          /* _XBT_MALLOCATOR_H */
+SG_END_DECL
+#endif /* XBT_MALLOCATOR_H */
