@@ -1,6 +1,6 @@
 /* xbt.h - Public interface to the xbt (simgrid's toolbox)                  */
 
-/* Copyright (c) 2004-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -12,7 +12,7 @@
 
 #include <stdarg.h>
 
-SG_BEGIN_DECL()
+SG_BEGIN_DECL
 
 /** Cache the size of a memory page for the current system. */
 XBT_PUBLIC_DATA int xbt_pagesize;
@@ -39,6 +39,6 @@ XBT_PUBLIC char* bvprintf(const char* fmt, va_list ap);
 XBT_PUBLIC char* bprintf(const char* fmt, ...) XBT_ATTRIB_PRINTF(1, 2);
 /** @} */
 
-SG_END_DECL()
+SG_END_DECL
 
 #endif                          /* XBT_MISC_H */
