@@ -1,6 +1,6 @@
 /* module - modularize the code                                             */
 
-/* Copyright (c) 2004-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -10,10 +10,10 @@
 
 #include <xbt/misc.h>           /* XBT_PUBLIC */
 
-SG_BEGIN_DECL()
+SG_BEGIN_DECL
 
 XBT_PUBLIC void xbt_init(int* argc, char** argv);
 
-SG_END_DECL()
+SG_END_DECL
 
 #endif /* XBT_MODULE_H */
