@@ -1,6 +1,6 @@
 /* str.h - XBT string related functions.                                    */
 
-/* Copyright (c) 2007-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -14,7 +14,7 @@
 
 #include <stdarg.h> /* va_* */
 
-SG_BEGIN_DECL()
+SG_BEGIN_DECL
 
 /** @addtogroup XBT_str
  *  @brief String manipulation functions
@@ -111,5 +111,5 @@ static inline unsigned int xbt_str_hash(const char *str)
 }
 
 /**@}*/
-SG_END_DECL()
+SG_END_DECL
 #endif                          /* XBT_STR_H */
