@@ -1,6 +1,6 @@
 /* Context switching within the JVM.                                        */
 
-/* Copyright (c) 2009-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2009-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -51,4 +51,4 @@ XBT_PRIVATE void java_main_jprocess(jobject process);
 
 }}} // namespace simgrid::kernel::context
 
-#endif                          /* !_XBT_CONTEXT_JAVA_H */
+#endif /* SIMGRID_JAVA_JAVA_CONTEXT_HPP */
