@@ -1,17 +1,16 @@
-/* Copyright (c) 2014-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2014-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 package org.simgrid;
 
-import java.io.FileOutputStream;
 import java.io.InputStream;
 import java.io.IOException;
-import java.io.OutputStream;
 import java.io.File;
 import java.nio.file.Files;
 import java.nio.file.Path;
+import java.util.stream.Stream;
 
 /** Helper class loading the native functions of SimGrid that we use for downcalls
  *
@@ -19,6 +18,7 @@ import java.nio.file.Path;
  * containing a call to this.
  */
 public final class NativeLib {
+	private static final boolean WINDOWS_OS = System.getProperty("os.name").toLowerCase().startsWith("win");
 	private static boolean isNativeInited = false;
 	private static Path tempDir = null; // where the embeeded libraries are unpacked before loading them
 
@@ -42,7 +42,7 @@ public final class NativeLib {
 		if (isNativeInited)
 			return;
 
-		if (System.getProperty("os.name").toLowerCase().startsWith("win"))
+		if (WINDOWS_OS)
 			NativeLib.nativeInit("winpthread-1");
 
 		NativeLib.nativeInit("simgrid");
@@ -90,7 +90,24 @@ public final class NativeLib {
 		
 		// We must write the lib onto the disk before loading it -- stupid operating systems
 		if (tempDir == null) {
-			tempDir = Files.createTempDirectory("simgrid-java-");
+			final String tempPrefix = "simgrid-java-";
+
+			if (WINDOWS_OS) {
+				// The cleanup at exit fails on Windows where it is impossible to delete files which are still in
+				// use.  Try to remove stale temporary files from previous executions, and limit disk usage.
+				Path tmpdir = (new File(System.getProperty("java.io.tmpdir"))).toPath();
+				try (Stream<Path> paths = Files.find(tmpdir, 1,
+					(Path p, java.nio.file.attribute.BasicFileAttributes a) ->
+						a.isDirectory() && !p.equals(tmpdir) &&
+						p.getFileName().toString().startsWith(tempPrefix))) {
+					paths.map(Path::toFile)
+					     .map(FileCleaner::new)
+					     .forEach(FileCleaner::run);
+
+				}
+			}
+
+			tempDir = Files.createTempDirectory(tempPrefix);
 			// don't leak the files on disk, but remove it on JVM shutdown
 			Runtime.getRuntime().addShutdownHook(new Thread(new FileCleaner(tempDir.toFile())));
 		}
@@ -102,27 +119,20 @@ public final class NativeLib {
 		     name+".dll", "lib"+name+".dll", /* windows (pure and mingw) */
 		     "lib"+name+".dylib"             /* macOS */}) {
 						
-			File fileOut = new File(tempDir.toFile().getAbsolutePath() + File.separator + filename);
-			boolean done = false;
+			File fileOut = new File(tempDir.toFile(), filename);
 			try ( // Try-with-resources. These stream will be autoclosed when needed.
 				InputStream in = NativeLib.class.getClassLoader().getResourceAsStream(path+filename);
-				OutputStream out = new FileOutputStream(fileOut);
 			) {
 				if (in != null) {
 					/* copy the library in position */
-					byte[] buffer = new byte[4096];
-					int bytesRead;
-					while ((bytesRead = in.read(buffer)) != -1)     // Read until EOF
-						out.write(buffer, 0, bytesRead);
-					done = true;
-				}
-			}
-			if (done) {
-				/* load that library */
-				System.load(fileOut.getAbsolutePath());
+					Files.copy(in, fileOut.toPath());
 
-				/* It loaded! we're good */
-				return true;
+					/* load that library */
+					System.load(fileOut.getAbsolutePath());
+
+					/* It loaded! we're good */
+					return true;
+				}
 			}
 		}
 		
@@ -161,16 +171,16 @@ public final class NativeLib {
 		}
 		@Override
 		public void run() {
-			try {
-				for (File f : dir.listFiles())
-					if (! f.delete() && !f.getAbsolutePath().contains("appveyor")) // Be silent on AppVeyor to not break the tests. Ugly trick :)
-						System.out.println("Unable to clean temporary file "+f.getAbsolutePath()+" during shutdown.");
-				if (! dir.delete() && !dir.getAbsolutePath().contains("appveyor") )
-					System.out.println("Unable to clean temporary file "+dir.getAbsolutePath()+" during shutdown.");			    	
+                        try (Stream<Path> paths = Files.walk(dir.toPath())) {
+                                paths.sorted(java.util.Comparator.reverseOrder())
+                                     .map(java.nio.file.Path::toFile)
+                                     //.peek(System.err::println) // Prints what gets removed
+                                     .forEach(java.io.File::delete);
 			} catch(Exception e) {
-				System.out.println("Error while cleaning temporary file "+dir.getAbsolutePath()+" during shutdown: "+e.getCause());
+				System.err.println("Error while cleaning temporary file " + dir.getAbsolutePath() +
+				                   ": " + e.getCause());
 				e.printStackTrace();
-			}
+                        }
 		}
 	}
 }
