@@ -1,4 +1,4 @@
-/* Copyright (c) 2012-2019. The SimGrid Team.
+/* Copyright (c) 2012-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -66,8 +66,11 @@ public class Semaphore {
 	}
 
 
-	/** Deletes this semaphore when the GC reclaims it */
-	@Override
+	/**
+	 * Deletes this semaphore when the GC reclaims it
+	 * @deprecated (from Java9 onwards)
+	 */
+	@Deprecated @Override
 	protected void finalize() throws Throwable {
 		nativeFinalize();
 	}
@@ -80,4 +83,4 @@ public class Semaphore {
 		org.simgrid.NativeLib.nativeInit();
 		nativeInit();
 	}
-}
\ No newline at end of file
+}
