@@ -1,4 +1,4 @@
-/* Copyright (c) 2008-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2008-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -13,7 +13,7 @@
 #include <ucontext.h>
 #endif
 
-SG_BEGIN_DECL()
+SG_BEGIN_DECL
 
 struct s_stack_region{
   void *address;
@@ -25,6 +25,6 @@ struct s_stack_region{
 };
 typedef struct s_stack_region  s_stack_region_t;
 
-SG_END_DECL()
+SG_END_DECL
 
 #endif
