@@ -1,4 +1,4 @@
-/* Copyright (c) 2019. The SimGrid Team. All rights reserved.               */
+/* Copyright (c) 2019-2020. The SimGrid Team. All rights reserved.               */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -8,7 +8,7 @@
 
 #include <xbt/base.h>
 
-SG_BEGIN_DECL()
+SG_BEGIN_DECL
 
 #ifdef COVERAGE
 extern void __gcov_flush();
@@ -17,6 +17,6 @@ extern void __gcov_flush();
 #define coverage_checkpoint() (void)0
 #endif
 
-SG_END_DECL()
+SG_END_DECL
 
 #endif
