@@ -1,4 +1,4 @@
-/* Copyright (c) 2010-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2010-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -22,16 +22,14 @@ std::set<std::string> declared_marks;
 std::set<std::string> user_host_variables;
 std::set<std::string> user_vm_variables;
 std::set<std::string> user_link_variables;
-extern std::set<std::string> trivaNodeTypes;
-extern std::set<std::string> trivaEdgeTypes;
 
-static xbt_dynar_t instr_set_to_dynar(std::set<std::string>* filter)
+static xbt_dynar_t instr_set_to_dynar(const std::set<std::string>& filter)
 {
   if (not TRACE_is_enabled() || not TRACE_needs_platform())
     return nullptr;
 
   xbt_dynar_t ret = xbt_dynar_new (sizeof(char*), &xbt_free_ref);
-  for (auto const& name : *filter)
+  for (auto const& name : filter)
     xbt_dynar_push_as(ret, char*, xbt_strdup(name.c_str()));
 
   return ret;
@@ -123,7 +121,7 @@ xbt_dynar_t TRACE_get_categories ()
 {
   if (not TRACE_is_enabled() || not TRACE_categorized())
     return nullptr;
-  return instr_set_to_dynar(&created_categories);
+  return instr_set_to_dynar(created_categories);
 }
 
 /** @ingroup TRACE_mark
@@ -138,7 +136,7 @@ xbt_dynar_t TRACE_get_categories ()
  */
 void TRACE_declare_mark(const char *mark_type)
 {
-  /* safe switchs. tracing has to be activated and if platform is not traced, we can't deal with marks */
+  /* safe switches. tracing has to be activated and if platform is not traced, we can't deal with marks */
   if (not TRACE_is_enabled() || not TRACE_needs_platform())
     return;
 
@@ -241,7 +239,7 @@ void TRACE_mark(const char *mark_type, const char *mark_value)
                                 simgrid::xbt::string_printf("mark_type with name (%s) is not declared", mark_type));
   } else {
     XBT_DEBUG("MARK %s %s", mark_type, mark_value);
-    new simgrid::instr::NewEvent(MSG_get_clock(), simgrid::instr::Container::get_root(), type,
+    new simgrid::instr::NewEvent(simgrid_get_clock(), simgrid::instr::Container::get_root(), type,
                                  type->get_entity_value(mark_value));
   }
 }
@@ -258,7 +256,7 @@ xbt_dynar_t TRACE_get_marks ()
   if (not TRACE_is_enabled())
     return nullptr;
 
-  return instr_set_to_dynar(&declared_marks);
+  return instr_set_to_dynar(declared_marks);
 }
 
 static void instr_user_variable(double time, const char* resource, const char* variable_name, const char* father_type,
@@ -385,7 +383,7 @@ void TRACE_vm_variable_declare_with_color (const char *variable, const char *col
  */
 void TRACE_vm_variable_set (const char *vm, const char *variable, double value)
 {
-  TRACE_vm_variable_set_with_time (MSG_get_clock(), vm, variable, value);
+  TRACE_vm_variable_set_with_time(simgrid_get_clock(), vm, variable, value);
 }
 
 /** @ingroup TRACE_user_variables
@@ -399,7 +397,7 @@ void TRACE_vm_variable_set (const char *vm, const char *variable, double value)
  */
 void TRACE_vm_variable_add (const char *vm, const char *variable, double value)
 {
-  TRACE_vm_variable_add_with_time (MSG_get_clock(), vm, variable, value);
+  TRACE_vm_variable_add_with_time(simgrid_get_clock(), vm, variable, value);
 }
 
 /** @ingroup TRACE_user_variables
@@ -413,7 +411,7 @@ void TRACE_vm_variable_add (const char *vm, const char *variable, double value)
  */
 void TRACE_vm_variable_sub (const char *vm, const char *variable, double value)
 {
-  TRACE_vm_variable_sub_with_time (MSG_get_clock(), vm, variable, value);
+  TRACE_vm_variable_sub_with_time(simgrid_get_clock(), vm, variable, value);
 }
 
 /** @ingroup TRACE_user_variables
@@ -519,7 +517,7 @@ void TRACE_host_variable_declare_with_color (const char *variable, const char *c
  */
 void TRACE_host_variable_set (const char *host, const char *variable, double value)
 {
-  TRACE_host_variable_set_with_time (MSG_get_clock(), host, variable, value);
+  TRACE_host_variable_set_with_time(simgrid_get_clock(), host, variable, value);
 }
 
 /** @ingroup TRACE_user_variables
@@ -533,7 +531,7 @@ void TRACE_host_variable_set (const char *host, const char *variable, double val
  */
 void TRACE_host_variable_add (const char *host, const char *variable, double value)
 {
-  TRACE_host_variable_add_with_time (MSG_get_clock(), host, variable, value);
+  TRACE_host_variable_add_with_time(simgrid_get_clock(), host, variable, value);
 }
 
 /** @ingroup TRACE_user_variables
@@ -547,7 +545,7 @@ void TRACE_host_variable_add (const char *host, const char *variable, double val
  */
 void TRACE_host_variable_sub (const char *host, const char *variable, double value)
 {
-  TRACE_host_variable_sub_with_time (MSG_get_clock(), host, variable, value);
+  TRACE_host_variable_sub_with_time(simgrid_get_clock(), host, variable, value);
 }
 
 /** @ingroup TRACE_user_variables
@@ -620,7 +618,7 @@ void TRACE_host_variable_sub_with_time (double time, const char *host, const cha
  */
 xbt_dynar_t TRACE_get_host_variables ()
 {
-  return instr_set_to_dynar(&user_host_variables);
+  return instr_set_to_dynar(user_host_variables);
 }
 
 /* for link variables */
@@ -666,7 +664,7 @@ void TRACE_link_variable_declare_with_color (const char *variable, const char *c
  */
 void TRACE_link_variable_set (const char *link, const char *variable, double value)
 {
-  TRACE_link_variable_set_with_time (MSG_get_clock(), link, variable, value);
+  TRACE_link_variable_set_with_time(simgrid_get_clock(), link, variable, value);
 }
 
 /** @ingroup TRACE_user_variables
@@ -680,7 +678,7 @@ void TRACE_link_variable_set (const char *link, const char *variable, double val
  */
 void TRACE_link_variable_add (const char *link, const char *variable, double value)
 {
-  TRACE_link_variable_add_with_time (MSG_get_clock(), link, variable, value);
+  TRACE_link_variable_add_with_time(simgrid_get_clock(), link, variable, value);
 }
 
 /** @ingroup TRACE_user_variables
@@ -694,7 +692,7 @@ void TRACE_link_variable_add (const char *link, const char *variable, double val
  */
 void TRACE_link_variable_sub (const char *link, const char *variable, double value)
 {
-  TRACE_link_variable_sub_with_time (MSG_get_clock(), link, variable, value);
+  TRACE_link_variable_sub_with_time(simgrid_get_clock(), link, variable, value);
 }
 
 /** @ingroup TRACE_user_variables
@@ -774,7 +772,7 @@ void TRACE_link_variable_sub_with_time (double time, const char *link, const cha
  */
 void TRACE_link_srcdst_variable_set (const char *src, const char *dst, const char *variable, double value)
 {
-  TRACE_link_srcdst_variable_set_with_time (MSG_get_clock(), src, dst, variable, value);
+  TRACE_link_srcdst_variable_set_with_time(simgrid_get_clock(), src, dst, variable, value);
 }
 
 /** @ingroup TRACE_user_variables
@@ -793,7 +791,7 @@ void TRACE_link_srcdst_variable_set (const char *src, const char *dst, const cha
  */
 void TRACE_link_srcdst_variable_add (const char *src, const char *dst, const char *variable, double value)
 {
-  TRACE_link_srcdst_variable_add_with_time (MSG_get_clock(), src, dst, variable, value);
+  TRACE_link_srcdst_variable_add_with_time(simgrid_get_clock(), src, dst, variable, value);
 }
 
 /** @ingroup TRACE_user_variables
@@ -812,7 +810,7 @@ void TRACE_link_srcdst_variable_add (const char *src, const char *dst, const cha
  */
 void TRACE_link_srcdst_variable_sub (const char *src, const char *dst, const char *variable, double value)
 {
-  TRACE_link_srcdst_variable_sub_with_time (MSG_get_clock(), src, dst, variable, value);
+  TRACE_link_srcdst_variable_sub_with_time(simgrid_get_clock(), src, dst, variable, value);
 }
 
 /** @ingroup TRACE_user_variables
@@ -891,7 +889,7 @@ void TRACE_link_srcdst_variable_sub_with_time (double time, const char *src, con
  */
 xbt_dynar_t TRACE_get_link_variables ()
 {
-  return instr_set_to_dynar(&user_link_variables);
+  return instr_set_to_dynar(user_link_variables);
 }
 
 /** @ingroup TRACE_user_variables
@@ -974,29 +972,3 @@ void TRACE_host_pop_state(const char* host, const char* state_name)
 {
   simgrid::instr::Container::by_name(host)->get_state(state_name)->pop_event();
 }
-
-/** @ingroup TRACE_API
- *  @brief Get Paje container types that can be mapped to the nodes of a graph.
- *
- *  This function can be used to create a user made  graph configuration file for Triva. Normally, it is used with the
- *  functions defined in @ref TRACE_user_variables.
- *
- *  @return A dynar with the types, must be freed with xbt_dynar_free.
- */
-xbt_dynar_t TRACE_get_node_types ()
-{
-  return instr_set_to_dynar(&trivaNodeTypes);
-}
-
-/** @ingroup TRACE_API
- *  @brief Get Paje container types that can be mapped to the edges of a graph.
- *
- *  This function can be used to create a user made graph configuration file for Triva. Normally, it is used with the
- *  functions defined in @ref TRACE_user_variables.
- *
- *  @return A dynar with the types, must be freed with xbt_dynar_free.
- */
-xbt_dynar_t TRACE_get_edge_types ()
-{
-  return instr_set_to_dynar(&trivaEdgeTypes);
-}
