@@ -1,4 +1,4 @@
-/* Copyright (c) 2012-2019. The SimGrid Team.
+/* Copyright (c) 2012-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -13,7 +13,7 @@ namespace simgrid {
 namespace instr {
 
 EntityValue::EntityValue(const std::string& name, const std::string& color, Type* father)
-    : id_(instr_new_paje_id()), name_(name), color_(color), father_(father){};
+    : id_(instr_new_paje_id()), name_(name), color_(color), father_(father){}
 
 void EntityValue::print()
 {
