@@ -1,4 +1,4 @@
-/* Copyright (c) 2010-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2010-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -56,7 +56,7 @@ public:
   explicit TIData(const std::string& name) : name_(name){};
   // CPuTI: compute, sleep (+ waitAny and waitall out of laziness)
   explicit TIData(const std::string& name, double amount) : name_(name), amount_(amount){};
-  // Pt2PtTI: send, isend, sssend, issend, recv, irecv
+  // Pt2PtTI: send, isend, ssend, issend, recv, irecv
   explicit TIData(const std::string& name, int endpoint, int size, const std::string& datatype)
       : name_(name), endpoint(endpoint), send_size(size), send_type(datatype){};
   // CollTI: bcast, reduce, allreduce, gather, scatter, allgather, alltoall
@@ -115,13 +115,14 @@ public:
 };
 
 class Pt2PtTIData : public TIData {
-  int tag;
+  int tag = 0;
+
 public:
   explicit Pt2PtTIData(const std::string& name, int endpoint, int size, int tag, const std::string& datatype)
       : TIData(name, endpoint, size, datatype), tag(tag){};
 
   explicit Pt2PtTIData(const std::string& name, int endpoint, int size, const std::string& datatype)
-      : TIData(name, endpoint, size, datatype), tag(0){};
+      : TIData(name, endpoint, size, datatype){};
   std::string print() override
   {
     std::stringstream stream;
@@ -269,8 +270,6 @@ XBT_PRIVATE void TRACE_surf_resource_set_utilization(const char* type, const cha
                                                      double delta);
 
 /* instr_paje.c */
-extern XBT_PRIVATE std::set<std::string> trivaNodeTypes;
-extern XBT_PRIVATE std::set<std::string> trivaEdgeTypes;
 XBT_PRIVATE long long int instr_new_paje_id();
 XBT_PRIVATE void instr_define_callbacks();
 void instr_new_variable_type(const std::string& new_typename, const std::string& color);
@@ -290,6 +289,6 @@ XBT_PRIVATE std::string TRACE_get_filename();
 
 /* instr_platform */
 xbt_graph_t instr_routing_platform_graph();
-void instr_routing_platform_graph_export_graphviz(xbt_graph_t g, const char* filename);
+void instr_routing_platform_graph_export_graphviz(const s_xbt_graph_t* g, const char* filename);
 
 #endif
