@@ -1,11 +1,11 @@
-/* Copyright (c) 2016-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2016-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include <simgrid/s4u/NetZone.hpp>
-
 #include <map>
+#include <simgrid/s4u/NetZone.hpp>
+#include <simgrid/simix.hpp>
 #include <string>
 #include <unordered_map>
 
@@ -14,8 +14,8 @@ namespace kernel {
 
 class EngineImpl {
   std::map<std::string, s4u::Host*> hosts_;
-  std::map<std::string, s4u::Link*> links_;
-  std::map<std::string, s4u::Storage*> storages_;
+  std::map<std::string, resource::LinkImpl*> links_;
+  std::map<std::string, resource::StorageImpl*> storages_;
   std::unordered_map<std::string, routing::NetPoint*> netpoints_;
   friend s4u::Engine;
 
@@ -25,6 +25,12 @@ public:
   EngineImpl(const EngineImpl&) = delete;
   EngineImpl& operator=(const EngineImpl&) = delete;
   virtual ~EngineImpl();
+
+  void load_deployment(const std::string& file);
+  void register_function(const std::string& name, xbt_main_func_t code);
+  void register_function(const std::string& name, void (*code)(std::vector<std::string>));
+  void register_default(xbt_main_func_t code);
+
   routing::NetZoneImpl* netzone_root_ = nullptr;
 };
 
