@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -19,13 +19,28 @@
 namespace simgrid {
 namespace kernel {
 namespace activity {
+enum class State {
+  WAITING = 0,
+  READY,
+  RUNNING,
+  DONE,
+  CANCELED,
+  FAILED,
+  SRC_HOST_FAILURE,
+  DST_HOST_FAILURE,
+  TIMEOUT,
+  SRC_TIMEOUT,
+  DST_TIMEOUT,
+  LINK_FAILURE
+};
 
 class XBT_PUBLIC ActivityImpl {
   std::atomic_int_fast32_t refcount_{0};
+
 public:
   virtual ~ActivityImpl();
   ActivityImpl() = default;
-  e_smx_state_t state_ = SIMIX_WAITING; /* State of the activity */
+  State state_   = State::WAITING;      /* State of the activity */
   std::list<smx_simcall_t> simcalls_;   /* List of simcalls waiting for this activity */
   resource::Action* surf_action_ = nullptr;
 
@@ -41,7 +56,7 @@ public:
   virtual void register_simcall(smx_simcall_t simcall);
   void clean_action();
   virtual double get_remaining() const;
-  // boost::intrusive_ptr<ActivityImpl> support:
+  // Support for the boost::intrusive_ptr<ActivityImpl> datatype
   friend XBT_PUBLIC void intrusive_ptr_add_ref(ActivityImpl* activity);
   friend XBT_PUBLIC void intrusive_ptr_release(ActivityImpl* activity);
 
