@@ -1,10 +1,10 @@
-/* Copyright (c) 2007-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#ifndef SIMIX_SYNCHRO_IO_HPP
-#define SIMIX_SYNCHRO_IO_HPP
+#ifndef SIMGRID_KERNEL_ACTIVITY_IO_HPP
+#define SIMGRID_KERNEL_ACTIVITY_IO_HPP
 
 #include "src/kernel/activity/ActivityImpl.hpp"
 #include "surf/surf.hpp"
@@ -20,6 +20,7 @@ class XBT_PUBLIC IoImpl : public ActivityImpl_T<IoImpl> {
   sg_size_t size_                 = 0;
   s4u::Io::OpType type_           = s4u::Io::OpType::READ;
   sg_size_t performed_ioops_      = 0;
+  resource::Action* timeout_detector_ = nullptr;
 
 public:
   IoImpl& set_size(sg_size_t size);
@@ -27,7 +28,15 @@ public:
   IoImpl& set_storage(resource::StorageImpl* storage);
   IoImpl& set_disk(resource::DiskImpl* disk);
 
-  sg_size_t get_performed_ioops() { return performed_ioops_; }
+  void set_timeout_detector(resource::Action* action)
+  {
+    timeout_detector_ = action;
+    timeout_detector_->set_activity(this);
+  }
+
+  sg_size_t get_performed_ioops() const { return performed_ioops_; }
+  resource::DiskImpl* get_disk() const { return disk_; }
+  resource::StorageImpl* get_storage() const { return storage_; }
 
   IoImpl* start();
   void post() override;
