@@ -1,10 +1,10 @@
-/* Copyright (c) 2007-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#ifndef SIMIX_MAILBOXIMPL_H
-#define SIMIX_MAILBOXIMPL_H
+#ifndef SIMGRID_KERNEL_ACTIVITY_MAILBOX_HPP
+#define SIMGRID_KERNEL_ACTIVITY_MAILBOX_HPP
 
 #include <boost/circular_buffer.hpp>
 #include <xbt/string.hpp>
@@ -29,10 +29,7 @@ class MailboxImpl {
   friend s4u::Mailbox* s4u::Mailbox::by_name(const std::string& name);
   friend mc::CommunicationDeterminismChecker;
 
-  explicit MailboxImpl(const std::string& name)
-      : piface_(this), name_(name), comm_queue_(MAX_MAILBOX_SIZE), done_comm_queue_(MAX_MAILBOX_SIZE)
-  {
-  }
+  explicit MailboxImpl(const std::string& name) : piface_(this), name_(name) {}
 
 public:
   const xbt::string& get_name() const { return name_; }
@@ -42,14 +39,14 @@ public:
   void set_receiver(s4u::ActorPtr actor);
   void push(CommImplPtr comm);
   void remove(const CommImplPtr& comm);
-  CommImplPtr iprobe(int type, int (*match_fun)(void*, void*, CommImpl*), void* data);
-  CommImplPtr find_matching_comm(CommImpl::Type type, int (*match_fun)(void*, void*, CommImpl*), void* this_user_data,
+  CommImplPtr iprobe(int type, bool (*match_fun)(void*, void*, CommImpl*), void* data);
+  CommImplPtr find_matching_comm(CommImpl::Type type, bool (*match_fun)(void*, void*, CommImpl*), void* this_user_data,
                                  const CommImplPtr& my_synchro, bool done, bool remove_matching);
 
   actor::ActorImplPtr permanent_receiver_; // actor to which the mailbox is attached
-  boost::circular_buffer_space_optimized<CommImplPtr> comm_queue_;
-  boost::circular_buffer_space_optimized<CommImplPtr> done_comm_queue_; // messages already received in the permanent
-                                                                        // receive mode
+  boost::circular_buffer_space_optimized<CommImplPtr> comm_queue_{MAX_MAILBOX_SIZE};
+  // messages already received in the permanent receive mode
+  boost::circular_buffer_space_optimized<CommImplPtr> done_comm_queue_{MAX_MAILBOX_SIZE};
 };
 } // namespace activity
 } // namespace kernel
@@ -57,4 +54,4 @@ public:
 
 XBT_PRIVATE void SIMIX_mailbox_exit();
 
-#endif /* SIMIX_MAILBOXIMPL_H */
+#endif
