@@ -1,10 +1,10 @@
-/* Copyright (c) 2012-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2012-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#ifndef SIMIX_MUTEXIMPL_HPP
-#define SIMIX_MUTEXIMPL_HPP
+#ifndef SIMGRID_KERNEL_ACTIVITY_MUTEX_HPP
+#define SIMGRID_KERNEL_ACTIVITY_MUTEX_HPP
 
 #include "simgrid/s4u/ConditionVariable.hpp"
 #include "src/kernel/actor/ActorImpl.hpp"
@@ -18,6 +18,9 @@ class XBT_PUBLIC MutexImpl {
   std::atomic_int_fast32_t refcount_{1};
   s4u::Mutex piface_;
   bool locked_ = false;
+  actor::ActorImpl* owner_ = nullptr;
+  // List of sleeping actors:
+  actor::SynchroList sleeping_;
 
 public:
   MutexImpl() : piface_(this) {}
@@ -32,9 +35,8 @@ public:
   MutexImpl* ref();
   void unref();
 
-  actor::ActorImpl* owner_ = nullptr;
-  // List of sleeping actors:
-  actor::SynchroList sleeping_;
+  void remove_sleeping_actor(actor::ActorImpl& actor) { xbt::intrusive_erase(sleeping_, actor); }
+  actor::ActorImpl* get_owner() const { return owner_; }
 
   // boost::intrusive_ptr<Mutex> support:
   friend void intrusive_ptr_add_ref(MutexImpl* mutex)
@@ -51,7 +53,7 @@ public:
 
   s4u::Mutex& mutex() { return piface_; }
 };
-}
-}
-}
-#endif /* SIMIX_MUTEXIMPL_HPP */
+} // namespace activity
+} // namespace kernel
+} // namespace simgrid
+#endif
