@@ -1,10 +1,10 @@
-/* Copyright (c) 2007-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#ifndef SIMIX_SYNCHRO_RAW_HPP
-#define SIMIX_SYNCHRO_RAW_HPP
+#ifndef SIMGRID_KERNEL_ACTIVITY_SYNCHRO_RAW_HPP
+#define SIMGRID_KERNEL_ACTIVITY_SYNCHRO_RAW_HPP
 
 #include "src/kernel/activity/ActivityImpl.hpp"
 #include "surf/surf.hpp"
