@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -19,11 +19,10 @@
 #include "src/surf/cpu_interface.hpp"
 
 #include <boost/range/algorithm.hpp>
+#include <utility>
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(simix_process, simix, "Logging specific to SIMIX (process)");
 
-static unsigned long simix_process_maxpid = 0;
-
 /**
  * @brief Returns the current agent.
  *
@@ -33,33 +32,37 @@ static unsigned long simix_process_maxpid = 0;
  */
 smx_actor_t SIMIX_process_self()
 {
-  simgrid::kernel::context::Context* self_context = simgrid::kernel::context::Context::self();
-
-  return (self_context != nullptr) ? self_context->get_actor() : nullptr;
-}
-
-/**
- * @brief Returns whether a process has pending asynchronous communications.
- * @return true if there are asynchronous communications in this process
- * @deprecated
- */
-int SIMIX_process_has_pending_comms(smx_actor_t process)
-{
-
-  return process->comms.size() > 0;
+  return simgrid::kernel::actor::ActorImpl::self();
 }
 
 namespace simgrid {
 namespace kernel {
 namespace actor {
 
-ActorImpl::ActorImpl(const simgrid::xbt::string& name, s4u::Host* host) : host_(host), name_(name), piface_(this)
+static unsigned long maxpid = 0;
+int get_maxpid()
 {
-  pid_           = simix_process_maxpid++;
-  simcall.issuer = this;
+  return maxpid;
 }
 
-ActorImpl::~ActorImpl() = default;
+ActorImpl* ActorImpl::self()
+{
+  context::Context* self_context = context::Context::self();
+
+  return (self_context != nullptr) ? self_context->get_actor() : nullptr;
+}
+
+ActorImpl::ActorImpl(xbt::string name, s4u::Host* host) : host_(host), name_(std::move(name)), piface_(this)
+{
+  pid_           = maxpid++;
+  simcall.issuer_ = this;
+}
+
+ActorImpl::~ActorImpl()
+{
+  if (simix_global != nullptr && this != simix_global->maestro_)
+    s4u::Actor::on_destruction(*ciface());
+}
 
 /* Become an actor in the simulation
  *
@@ -74,11 +77,11 @@ ActorImplPtr ActorImpl::attach(const std::string& name, void* data, s4u::Host* h
 {
   // This is mostly a copy/paste from create(), it'd be nice to share some code between those two functions.
 
-  XBT_DEBUG("Attach process %s on host '%s'", name.c_str(), host->get_cname());
+  XBT_DEBUG("Attach actor %s on host '%s'", name.c_str(), host->get_cname());
 
   if (not host->is_on()) {
-    XBT_WARN("Cannot launch process '%s' on failed host '%s'", name.c_str(), host->get_cname());
-    throw simgrid::HostFailureException(XBT_THROW_POINT, "Cannot attach actor on failed host.");
+    XBT_WARN("Cannot attach actor '%s' on failed host '%s'", name.c_str(), host->get_cname());
+    throw HostFailureException(XBT_THROW_POINT, "Cannot attach actor on failed host.");
   }
 
   ActorImpl* actor = new ActorImpl(xbt::string(name), host);
@@ -94,21 +97,21 @@ ActorImplPtr ActorImpl::attach(const std::string& name, void* data, s4u::Host* h
   if (properties != nullptr)
     actor->set_properties(*properties);
 
-  /* Add the process to it's host process list */
-  host->pimpl_->process_list_.push_back(*actor);
+  /* Add the actor to it's host actor list */
+  host->pimpl_->add_actor(actor);
 
-  /* Now insert it in the global process list and in the process to run list */
+  /* Now insert it in the global actor list and in the actors to run list */
   simix_global->process_list[actor->get_pid()] = actor;
   XBT_DEBUG("Inserting [%p] %s(%s) in the to_run list", actor, actor->get_cname(), host->get_cname());
   simix_global->actors_to_run.push_back(actor);
   intrusive_ptr_add_ref(actor);
 
-  auto* context = dynamic_cast<simgrid::kernel::context::AttachContext*>(actor->context_.get());
+  auto* context = dynamic_cast<context::AttachContext*>(actor->context_.get());
   xbt_assert(nullptr != context, "Not a suitable context");
   context->attach_start();
 
   /* The on_creation() signal must be delayed until there, where the pid and everything is set */
-  simgrid::s4u::Actor::on_creation(*actor->ciface());
+  s4u::Actor::on_creation(*actor->ciface());
 
   return ActorImplPtr(actor);
 }
@@ -128,6 +131,20 @@ void ActorImpl::detach()
   context->attach_stop();
 }
 
+void ActorImpl::cleanup_from_simix()
+{
+  const std::lock_guard<std::mutex> lock(simix_global->mutex);
+  simix_global->process_list.erase(pid_);
+  if (host_ && host_actor_list_hook.is_linked())
+    host_->pimpl_->remove_actor(this);
+  if (not smx_destroy_list_hook.is_linked()) {
+#if SIMGRID_HAVE_MC
+    xbt_dynar_push_as(simix_global->dead_actors_vector, ActorImpl*, this);
+#endif
+    simix_global->actors_to_destroy.push_back(*this);
+  }
+}
+
 void ActorImpl::cleanup()
 {
   finished_ = true;
@@ -140,7 +157,7 @@ void ActorImpl::cleanup()
 
   if (on_exit) {
     // Execute the termination callbacks
-    bool failed = context_->iwannadie;
+    bool failed = context_->wannadie();
     for (auto exit_fun = on_exit->crbegin(); exit_fun != on_exit->crend(); ++exit_fun)
       (*exit_fun)(failed);
     on_exit.reset();
@@ -154,7 +171,7 @@ void ActorImpl::cleanup()
 
   XBT_DEBUG("%s@%s(%ld) should not run anymore", get_cname(), get_host()->get_cname(), get_pid());
 
-  if (this == simix_global->maestro_process) /* Do not cleanup maestro */
+  if (this == simix_global->maestro_) /* Do not cleanup maestro */
     return;
 
   XBT_DEBUG("Cleanup actor %s (%p), waiting synchro %p", get_cname(), this, waiting_synchro.get());
@@ -164,40 +181,23 @@ void ActorImpl::cleanup()
     kill_timer->remove();
     kill_timer = nullptr;
   }
+  cleanup_from_simix();
 
-  simix_global->mutex.lock();
-
-  simix_global->process_list.erase(pid_);
-  if (host_ && host_process_list_hook.is_linked())
-    simgrid::xbt::intrusive_erase(host_->pimpl_->process_list_, *this);
-  if (not smx_destroy_list_hook.is_linked()) {
-#if SIMGRID_HAVE_MC
-    xbt_dynar_push_as(simix_global->dead_actors_vector, ActorImpl*, this);
-#endif
-    simix_global->actors_to_destroy.push_back(*this);
-  }
-
-  simix_global->mutex.unlock();
-
-  context_->iwannadie = false; // don't let the simcall's yield() do a Context::stop(), to avoid infinite loops
-  simgrid::simix::simcall([this] { simgrid::s4u::Actor::on_destruction(*ciface()); });
-  context_->iwannadie = true;
+  context_->set_wannadie(false); // don't let the simcall's yield() do a Context::stop(), to avoid infinite loops
+  actor::simcall([this] { s4u::Actor::on_termination(*ciface()); });
+  context_->set_wannadie();
 }
 
 void ActorImpl::exit()
 {
-  context_->iwannadie = true;
+  context_->set_wannadie();
   suspended_          = false;
   exception_          = nullptr;
 
-  // Forcefully kill the actor if its host is turned off. Not a HostFailureException because you should not survive that
-  if (not host_->is_on())
-    this->throw_exception(std::make_exception_ptr(ForcefulKillException("host failed")));
-
   /* destroy the blocking synchro if any */
   if (waiting_synchro != nullptr) {
     waiting_synchro->cancel();
-    waiting_synchro->state_ = SIMIX_FAILED;
+    waiting_synchro->state_ = activity::State::FAILED;
 
     activity::ExecImplPtr exec   = boost::dynamic_pointer_cast<activity::ExecImpl>(waiting_synchro);
     activity::CommImplPtr comm   = boost::dynamic_pointer_cast<activity::CommImpl>(waiting_synchro);
@@ -216,10 +216,14 @@ void ActorImpl::exit()
 
     waiting_synchro = nullptr;
   }
+
+  // Forcefully kill the actor if its host is turned off. Not a HostFailureException because you should not survive that
+  this->throw_exception(std::make_exception_ptr(ForcefulKillException(host_->is_on() ? "exited" : "host failed")));
 }
 
 void ActorImpl::kill(ActorImpl* actor)
 {
+  xbt_assert(actor != simix_global->maestro_, "Killing maestro is a rather bad idea");
   if (actor->finished_) {
     XBT_DEBUG("Ignoring request to kill actor %s@%s that is already dead", actor->get_cname(),
               actor->host_->get_cname());
@@ -272,9 +276,8 @@ void ActorImpl::yield()
   /* Ok, maestro returned control to us */
   XBT_DEBUG("Control returned to me: '%s'", get_cname());
 
-  if (context_->iwannadie) {
+  if (context_->wannadie()) {
     XBT_DEBUG("Actor %s@%s is dead", get_cname(), host_->get_cname());
-    // throw simgrid::kernel::context::ForcefulKillException(); Does not seem to properly kill the actor
     context_->stop();
     THROW_IMPOSSIBLE;
   }
@@ -284,7 +287,7 @@ void ActorImpl::yield()
 
     xbt_assert(exception_ == nullptr, "Gasp! This exception may be lost by subsequent calls.");
     suspended_ = false;
-    suspend(this);
+    suspend();
   }
 
   if (exception_ != nullptr) {
@@ -324,7 +327,7 @@ void ActorImpl::undaemonize()
 
 s4u::Actor* ActorImpl::restart()
 {
-  xbt_assert(this != simix_global->maestro_process, "Restarting maestro is not supported");
+  xbt_assert(this != simix_global->maestro_, "Restarting maestro is not supported");
 
   XBT_DEBUG("Restarting actor %s on %s", get_cname(), host_->get_cname());
 
@@ -344,34 +347,31 @@ s4u::Actor* ActorImpl::restart()
   return actor->ciface();
 }
 
-activity::ActivityImplPtr ActorImpl::suspend(ActorImpl* issuer)
+void ActorImpl::suspend()
 {
   if (suspended_) {
     XBT_DEBUG("Actor '%s' is already suspended", get_cname());
-    return nullptr;
+    return;
   }
 
   suspended_ = true;
 
-  /* If we are suspending another actor that is waiting on a sync, suspend its synchronization. */
-  if (this != issuer) {
-    if (waiting_synchro)
-      waiting_synchro->suspend();
-    /* If the other actor is not waiting, its suspension is delayed to when the actor is rescheduled. */
+  /* If the suspended actor is waiting on a sync, suspend its synchronization. */
+  if (waiting_synchro == nullptr) {
+    auto exec = new activity::ExecImpl();
+    exec->set_name("suspend").set_host(host_).set_flops_amount(0.0).start();
+    waiting_synchro = activity::ExecImplPtr(exec);
 
-    return nullptr;
-  } else {
-    activity::ExecImpl* exec = new activity::ExecImpl();
-    (*exec).set_name("suspend").set_host(host_).set_flops_amount(0.0).start();
-    return activity::ExecImplPtr(exec);
+    waiting_synchro->simcalls_.push_back(&simcall);
   }
+  waiting_synchro->suspend();
 }
 
 void ActorImpl::resume()
 {
   XBT_IN("actor = %p", this);
 
-  if (context_->iwannadie) {
+  if (context_->wannadie()) {
     XBT_VERB("Ignoring request to suspend an actor that is currently dying.");
     return;
   }
@@ -387,10 +387,10 @@ void ActorImpl::resume()
   XBT_OUT();
 }
 
-activity::ActivityImplPtr ActorImpl::join(ActorImpl* actor, double timeout)
+activity::ActivityImplPtr ActorImpl::join(const ActorImpl* actor, double timeout)
 {
   activity::ActivityImplPtr sleep = this->sleep(timeout);
-  SIMIX_process_on_exit(actor, [sleep](bool) {
+  actor->on_exit->emplace_back([sleep](bool) {
     if (sleep->surf_action_)
       sleep->surf_action_->finish(resource::Action::State::FINISHED);
   });
@@ -400,11 +400,11 @@ activity::ActivityImplPtr ActorImpl::join(ActorImpl* actor, double timeout)
 activity::ActivityImplPtr ActorImpl::sleep(double duration)
 {
   if (not host_->is_on())
-    throw_exception(std::make_exception_ptr(simgrid::HostFailureException(
+    throw_exception(std::make_exception_ptr(HostFailureException(
         XBT_THROW_POINT, std::string("Host ") + host_->get_cname() + " failed, you cannot sleep there.")));
 
-  activity::SleepImpl* sleep = new activity::SleepImpl();
-  (*sleep).set_name("sleep").set_host(host_).set_duration(duration).start();
+  auto sleep = new activity::SleepImpl();
+  sleep->set_name("sleep").set_host(host_).set_duration(duration).start();
   return activity::SleepImplPtr(sleep);
 }
 
@@ -428,11 +428,25 @@ void ActorImpl::throw_exception(std::exception_ptr e)
   }
 }
 
+void ActorImpl::simcall_answer()
+{
+  if (this != simix_global->maestro_) {
+    XBT_DEBUG("Answer simcall %s (%d) issued by %s (%p)", SIMIX_simcall_name(simcall.call_), (int)simcall.call_,
+              get_cname(), this);
+    simcall.call_ = SIMCALL_NONE;
+    xbt_assert(not XBT_LOG_ISENABLED(simix_process, xbt_log_priority_debug) ||
+                   std::find(begin(simix_global->actors_to_run), end(simix_global->actors_to_run), this) ==
+                       end(simix_global->actors_to_run),
+               "Actor %p should not exist in actors_to_run!", this);
+    simix_global->actors_to_run.push_back(this);
+  }
+}
+
 void ActorImpl::set_host(s4u::Host* dest)
 {
-  xbt::intrusive_erase(host_->pimpl_->process_list_, *this);
+  host_->pimpl_->remove_actor(this);
   host_ = dest;
-  dest->pimpl_->process_list_.push_back(*this);
+  dest->pimpl_->add_actor(this);
 }
 
 ActorImplPtr ActorImpl::init(const std::string& name, s4u::Host* host)
@@ -454,7 +468,7 @@ ActorImpl* ActorImpl::start(const simix::ActorCode& code)
   if (not host_->is_on()) {
     XBT_WARN("Cannot launch actor '%s' on failed host '%s'", name_.c_str(), host_->get_cname());
     intrusive_ptr_release(this);
-    throw simgrid::HostFailureException(XBT_THROW_POINT, "Cannot start actor on failed host.");
+    throw HostFailureException(XBT_THROW_POINT, "Cannot start actor on failed host.");
   }
 
   this->code_ = code;
@@ -464,7 +478,7 @@ ActorImpl* ActorImpl::start(const simix::ActorCode& code)
   XBT_DEBUG("Start context '%s'", get_cname());
 
   /* Add the actor to its host's actor list */
-  host_->pimpl_->process_list_.push_back(*this);
+  host_->pimpl_->add_actor(this);
   simix_global->process_list[pid_] = this;
 
   /* Now insert it in the global actor list and in the actor to run list */
@@ -483,7 +497,7 @@ ActorImplPtr ActorImpl::create(const std::string& name, const simix::ActorCode&
   if (parent_actor != nullptr)
     actor = parent_actor->init(xbt::string(name), host);
   else
-    actor = SIMIX_process_self()->init(xbt::string(name), host);
+    actor = self()->init(xbt::string(name), host);
 
   /* actor data */
   actor->set_user_data(data);
@@ -508,63 +522,23 @@ void create_maestro(const std::function<void()>& code)
     maestro->context_.reset(simix_global->context_factory->create_maestro(simix::ActorCode(code), maestro));
   }
 
-  maestro->simcall.issuer       = maestro;
-  simix_global->maestro_process = maestro;
+  maestro->simcall.issuer_      = maestro;
+  simix_global->maestro_        = maestro;
 }
 
 } // namespace actor
 } // namespace kernel
 } // namespace simgrid
 
-void SIMIX_process_detach()
-{
-  simgrid::kernel::actor::ActorImpl::detach();
-}
-
-smx_actor_t SIMIX_process_attach(const char* name, void* data, const char* hostname,
-                                 std::unordered_map<std::string, std::string>* properties,
-                                 smx_actor_t /*parent_process*/)
-{
-  return simgrid::kernel::actor::ActorImpl::attach(name, data, sg_host_by_name(hostname), properties).get();
-}
-
-/** @deprecated When this function gets removed, also remove the xbt_ex class, that is only there to help users to
- * transition */
-void SIMIX_process_throw(smx_actor_t actor, xbt_errcat_t cat, int value, const char* msg)
-{
-  xbt_ex e(XBT_THROW_POINT, msg);
-  e.category = cat;
-  e.value    = value;
-  actor->throw_exception(std::make_exception_ptr(e));
-}
-
-void simcall_HANDLER_process_suspend(smx_simcall_t simcall, smx_actor_t actor)
-{
-  smx_activity_t sync_suspend = actor->suspend(simcall->issuer);
-
-  if (actor != simcall->issuer) {
-    SIMIX_simcall_answer(simcall);
-  } else {
-    sync_suspend->simcalls_.push_back(simcall);
-    actor->waiting_synchro = sync_suspend;
-    actor->waiting_synchro->suspend();
-  }
-  /* If we are suspending ourselves, then just do not finish the simcall now */
-}
-
-int SIMIX_process_get_maxpid()
-{
-  return simix_process_maxpid;
-}
-
-int SIMIX_process_count()
+int SIMIX_process_count() // XBT_ATTRIB_DEPRECATED_v329
 {
   return simix_global->process_list.size();
 }
 
-void* SIMIX_process_self_get_data() // deprecated
+// XBT_DEPRECATED_v329
+void* SIMIX_process_self_get_data()
 {
-  smx_actor_t self = SIMIX_process_self();
+  smx_actor_t self = simgrid::kernel::actor::ActorImpl::self();
 
   if (self == nullptr) {
     return nullptr;
@@ -572,47 +546,17 @@ void* SIMIX_process_self_get_data() // deprecated
   return self->get_user_data();
 }
 
-void SIMIX_process_self_set_data(void* data) // deprecated
+// XBT_DEPRECATED_v329
+void SIMIX_process_self_set_data(void* data)
 {
-  SIMIX_process_self()->set_user_data(data);
+  simgrid::kernel::actor::ActorImpl::self()->set_user_data(data);
 }
 
 /* needs to be public and without simcall because it is called
    by exceptions and logging events */
 const char* SIMIX_process_self_get_name()
 {
-
-  smx_actor_t process = SIMIX_process_self();
-  if (process == nullptr || process == simix_global->maestro_process)
-    return "maestro";
-
-  return process->get_cname();
-}
-
-void simcall_HANDLER_process_join(smx_simcall_t simcall, smx_actor_t process, double timeout)
-{
-  if (process->finished_) {
-    // The joined process is already finished, just wake up the issuer process right away
-    simcall_process_sleep__set__result(simcall, SIMIX_DONE);
-    SIMIX_simcall_answer(simcall);
-    return;
-  }
-  smx_activity_t sync = simcall->issuer->join(process, timeout);
-  sync->simcalls_.push_back(simcall);
-  simcall->issuer->waiting_synchro = sync;
-}
-
-void simcall_HANDLER_process_sleep(smx_simcall_t simcall, double duration)
-{
-  if (MC_is_active() || MC_record_replay_is_active()) {
-    MC_process_clock_add(simcall->issuer, duration);
-    simcall_process_sleep__set__result(simcall, SIMIX_DONE);
-    SIMIX_simcall_answer(simcall);
-    return;
-  }
-  smx_activity_t sync = simcall->issuer->sleep(duration);
-  sync->simcalls_.push_back(simcall);
-  simcall->issuer->waiting_synchro = sync;
+  return SIMIX_is_maestro() ? "maestro" : simgrid::kernel::actor::ActorImpl::self()->get_cname();
 }
 
 /**
@@ -623,35 +567,21 @@ void simcall_HANDLER_process_sleep(smx_simcall_t simcall, double duration)
  * @param self the current process
  */
 
-/** @brief Returns the list of processes to run.
- * @deprecated
- */
-const std::vector<smx_actor_t>& simgrid::simix::process_get_runnable()
-{
-  return simix_global->actors_to_run;
-}
-
 /** @brief Returns the process from PID. */
 smx_actor_t SIMIX_process_from_PID(aid_t PID)
 {
-  auto actor = simix_global->process_list.find(PID);
-  return actor == simix_global->process_list.end() ? nullptr : actor->second;
+  auto item = simix_global->process_list.find(PID);
+  if (item == simix_global->process_list.end()) {
+    for (auto& a : simix_global->actors_to_destroy)
+      if (a.get_pid() == PID)
+        return &a;
+    return nullptr; // Not found, even in the trash
+  }
+  return item->second;
 }
 
-void SIMIX_process_on_exit(smx_actor_t actor, int_f_pvoid_pvoid_t fun, void* data)
-{
-  SIMIX_process_on_exit(actor, [fun, data](bool failed) {
-    intptr_t status = failed ? SMX_EXIT_FAILURE : SMX_EXIT_SUCCESS;
-    fun(reinterpret_cast<void*>(status), data);
-  });
-}
-
-void SIMIX_process_on_exit(smx_actor_t actor, const std::function<void(int, void*)>& fun, void* data)
-{
-  SIMIX_process_on_exit(actor, [fun, data](bool failed) { fun(failed ? SMX_EXIT_FAILURE : SMX_EXIT_SUCCESS, data); });
-}
-
-void SIMIX_process_on_exit(smx_actor_t actor, const std::function<void(bool /*failed*/)>& fun)
+void SIMIX_process_on_exit(smx_actor_t actor,
+                           const std::function<void(bool /*failed*/)>& fun) // XBT_ATTRIB_DEPRECATED_v329
 {
   xbt_assert(actor, "current process not found: are you in maestro context ?");
   actor->on_exit->emplace_back(fun);
@@ -675,13 +605,13 @@ void SIMIX_process_on_exit(smx_actor_t actor, const std::function<void(bool /*fa
 smx_actor_t simcall_process_create(const std::string& name, const simgrid::simix::ActorCode& code, void* data,
                                    sg_host_t host, std::unordered_map<std::string, std::string>* properties)
 {
-  smx_actor_t self = SIMIX_process_self();
-  return simgrid::simix::simcall([&name, &code, data, host, properties, self] {
+  smx_actor_t self = simgrid::kernel::actor::ActorImpl::self();
+  return simgrid::kernel::actor::simcall([&name, &code, data, host, properties, self] {
     return simgrid::kernel::actor::ActorImpl::create(name, code, data, host, properties, self).get();
   });
 }
 
 void simcall_process_set_data(smx_actor_t process, void* data)
 {
-  simgrid::simix::simcall([process, data] { process->set_user_data(data); });
+  simgrid::kernel::actor::simcall([process, data] { process->set_user_data(data); });
 }
