@@ -1,10 +1,10 @@
-/* Copyright (c) 2009-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2009-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#ifndef SIMGRID_SIMIX_RAW_CONTEXT_HPP
-#define SIMGRID_SIMIX_RAW_CONTEXT_HPP
+#ifndef SIMGRID_KERNEL_CONTEXT_RAW_CONTEXT_HPP
+#define SIMGRID_KERNEL_CONTEXT_RAW_CONTEXT_HPP
 
 #include <atomic>
 #include <cstdint>
@@ -28,13 +28,11 @@ class RawContext : public SwappedContext {
 public:
   RawContext(std::function<void()>&& code, actor::ActorImpl* actor, SwappedContextFactory* factory);
 
-  void swap_into(SwappedContext* to) override;
-
 private:
   /** pointer to top the stack stack */
   void* stack_top_ = nullptr;
 
-  static void wrapper(RawContext* context);
+  void swap_into_for_real(SwappedContext* to) override;
 };
 
 class RawContextFactory : public SwappedContextFactory {
