@@ -1,12 +1,12 @@
-/* Copyright (c) 2009-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2009-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 /* \file ThreadContext.hpp Context switching with native threads */
 
-#ifndef SIMGRID_SIMIX_THREAD_CONTEXT_HPP
-#define SIMGRID_SIMIX_THREAD_CONTEXT_HPP
+#ifndef SIMGRID_KERNEL_CONTEXT_THREAD_CONTEXT_HPP
+#define SIMGRID_KERNEL_CONTEXT_THREAD_CONTEXT_HPP
 
 #include "simgrid/simix.hpp"
 #include "src/kernel/context/Context.hpp"
@@ -24,7 +24,7 @@ public:
   ThreadContext(const ThreadContext&) = delete;
   ThreadContext& operator=(const ThreadContext&) = delete;
   ~ThreadContext() override;
-  void stop() override;
+  XBT_ATTRIB_NORETURN void stop() override;
   void suspend() override;
   void attach_start() override;
   void attach_stop() override;
@@ -103,8 +103,6 @@ public:
   }
 
 private:
-  bool parallel_;
-
   ThreadContext* create_context(std::function<void()>&& code, actor::ActorImpl* actor, bool maestro);
 };
 } // namespace context
