@@ -1,10 +1,10 @@
-/* Copyright (c) 2009-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2009-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#ifndef SIMGRID_SIMIX_UNIX_CONTEXT_HPP
-#define SIMGRID_SIMIX_UNIX_CONTEXT_HPP
+#ifndef SIMGRID_KERNEL_CONTEXT_UNIX_CONTEXT_HPP
+#define SIMGRID_KERNEL_CONTEXT_UNIX_CONTEXT_HPP
 
 #include <ucontext.h> /* context relative declarations */
 
@@ -27,10 +27,10 @@ class UContext : public SwappedContext {
 public:
   UContext(std::function<void()>&& code, actor::ActorImpl* actor, SwappedContextFactory* factory);
 
-  void swap_into(SwappedContext* to) override;
-
 private:
   ucontext_t uc_;         /* the ucontext that executes the code */
+
+  void swap_into_for_real(SwappedContext* to) override;
 };
 
 class UContextFactory : public SwappedContextFactory {
