@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -21,7 +21,7 @@ public:
   std::size_t heap_bytes_used = 0;
   int actors_count            = 0;
   int num          = 0; // unique id of that state in the storage of all stored IDs
-  int original_num = 0; // num field of the VisitedState to which I was declared equal to (used for dot_output)
+  int original_num = -1; // num field of the VisitedState to which I was declared equal to (used for dot_output)
 
   explicit VisitedState(unsigned long state_number);
   ~VisitedState() = default;
