@@ -1,4 +1,4 @@
-/* Copyright (c) 2016-2019. The SimGrid Team.
+/* Copyright (c) 2016-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -18,5 +18,5 @@ Checker::Checker(Session& s) : session_(&s)
   mc_model_checker->setChecker(this);
 }
 
-}
-}
+} // namespace mc
+} // namespace simgrid
