@@ -1,4 +1,4 @@
-/* Copyright (c) 2008-2019. The SimGrid Team.
+/* Copyright (c) 2008-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -30,7 +30,7 @@ public:
   void log_state() override;
 
 private:
-  void check_non_termination(simgrid::mc::State* current_state);
+  void check_non_termination(const State* current_state);
   void backtrack();
   void restore_state();
 
