@@ -1,4 +1,4 @@
-/* Copyright (c) 2008-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2008-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -35,13 +35,12 @@ XBT_PRIVATE void handle_simcall(smx_simcall_t req, int req_num);
  *  Most requests are always enabled but WAIT and WAITANY
  *  are not always enabled: a WAIT where the communication does not
  *  have both a source and a destination yet is not enabled
- *  (unless timeout is enabled in the wait and enabeld in SimGridMC).
+ *  (unless timeout is enabled in the wait and enabled in SimGridMC).
  */
 XBT_PRIVATE bool actor_is_enabled(smx_actor_t process);
 
 /** Check if the given simcall is visible */
-XBT_PRIVATE bool request_is_visible(smx_simcall_t req);
-
+XBT_PRIVATE bool request_is_visible(const s_smx_simcall* req);
 }
 }
 
