@@ -1,4 +1,4 @@
-/* Copyright (c) 2008-2019. The SimGrid Team.
+/* Copyright (c) 2008-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -18,9 +18,6 @@
  *  communicate with the MC (declared in modelchecker.h).
  */
 
-XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_client_api, mc,
-  "Public API for the model-checked application");
-
 // MC_random() is in mc_base.cpp
 
 void MC_assert(int prop)
