@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -10,9 +10,6 @@
 
 using simgrid::mc::remote;
 
-XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_comm_pattern, mc,
-                                "Logging specific to MC communication patterns");
-
 static void MC_patterns_copy(std::vector<simgrid::mc::PatternCommunication*>& dest,
                              std::vector<simgrid::mc::PatternCommunication> const& source)
 {
@@ -26,28 +23,28 @@ static void MC_patterns_copy(std::vector<simgrid::mc::PatternCommunication*>& de
 void MC_restore_communications_pattern(simgrid::mc::State* state)
 {
   for (unsigned i = 0; i < initial_communications_pattern.size(); i++)
-    initial_communications_pattern[i].index_comm = state->communicationIndices[i];
+    initial_communications_pattern[i].index_comm = state->communication_indices_[i];
 
   for (unsigned i = 0; i < MC_smx_get_maxpid(); i++)
-    MC_patterns_copy(incomplete_communications_pattern[i], state->incomplete_comm_pattern[i]);
+    MC_patterns_copy(incomplete_communications_pattern[i], state->incomplete_comm_pattern_[i]);
 }
 
 void MC_state_copy_incomplete_communications_pattern(simgrid::mc::State* state)
 {
-  state->incomplete_comm_pattern.clear();
+  state->incomplete_comm_pattern_.clear();
   for (unsigned i=0; i < MC_smx_get_maxpid(); i++) {
     std::vector<simgrid::mc::PatternCommunication> res;
     for (auto const& comm : incomplete_communications_pattern[i])
       res.push_back(comm->dup());
-    state->incomplete_comm_pattern.push_back(std::move(res));
+    state->incomplete_comm_pattern_.push_back(std::move(res));
   }
 }
 
 void MC_state_copy_index_communications_pattern(simgrid::mc::State* state)
 {
-  state->communicationIndices.clear();
+  state->communication_indices_.clear();
   for (auto const& list_process_comm : initial_communications_pattern)
-    state->communicationIndices.push_back(list_process_comm.index_comm);
+    state->communication_indices_.push_back(list_process_comm.index_comm);
 }
 
 void MC_handle_comm_pattern(e_mc_call_type_t call_type, smx_simcall_t req, int value, int backtracking)
@@ -81,5 +78,4 @@ void MC_handle_comm_pattern(e_mc_call_type_t call_type, smx_simcall_t req, int v
   default:
     xbt_die("Unexpected call type %i", (int)call_type);
   }
-
 }
