@@ -1,4 +1,4 @@
-/* Copyright (c) 2015-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2015-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -26,7 +26,6 @@ class Channel {
   }
 
 public:
-  Channel() = default;
   explicit Channel(int sock) : socket_(sock) {}
   ~Channel();
 
@@ -34,15 +33,6 @@ public:
   Channel(Channel const&) = delete;
   Channel& operator=(Channel const&) = delete;
 
-  // Move:
-  Channel(Channel&& that) : socket_(that.socket_) { that.socket_ = -1; }
-  Channel& operator=(Channel&& that)
-  {
-    this->socket_ = that.socket_;
-    that.socket_  = -1;
-    return *this;
-  }
-
   // Send
   int send(const void* message, size_t size) const;
   int send(e_mc_message_type type) const
