@@ -1,4 +1,4 @@
-/* Copyright (c) 2014-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2014-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -72,6 +72,7 @@ static const std::vector<std::string> filtered_libraries = {
     "libm",
     "libomp",
     "libpapi",
+    "libpcre2",
     "libpfm",
     "libpgmath",
     "libpthread",
@@ -85,7 +86,30 @@ static const std::vector<std::string> filtered_libraries = {
     "libunwind-ptrace",
     "libunwind-x86",
     "libunwind-x86_64",
-    "libz"};
+    "libz",
+    "libkrb5support", /*odd behaviour on fedora rawhide ... remove these when fixed*/
+    "libkeyutils",
+    "libunistring",
+    "libbrotlidec",
+    "liblber",
+    "libldap",
+    "libcom_err",
+    "libk5crypto",
+    "libkrb5",
+    "libgssapi_krb5",
+    "libssl",
+    "libpsl",
+    "libssh",
+    "libidn2",
+    "libnghttp2",
+    "libcurl",
+    "libdebuginfod",
+    "libbrotlicommon",
+    "libsasl2",
+    "libresolv",
+    "libcrypt",
+    "libselinux"
+};
 
 static bool is_simgrid_lib(const std::string& libname)
 {
@@ -196,16 +220,13 @@ void RemoteClient::init()
   this->init_memory_map_info();
 
   int fd = open_vm(this->pid_, O_RDWR);
-  if (fd < 0)
-    xbt_die("Could not open file for process virtual address space");
+  xbt_assert(fd >= 0, "Could not open file for process virtual address space");
   this->memory_file = fd;
 
   // Read std_heap (is a struct mdesc*):
   const simgrid::mc::Variable* std_heap_var = this->find_variable("__mmalloc_default_mdp");
-  if (not std_heap_var)
-    xbt_die("No heap information in the target process");
-  if (not std_heap_var->address)
-    xbt_die("No constant address for this variable");
+  xbt_assert(std_heap_var, "No heap information in the target process");
+  xbt_assert(std_heap_var->address, "No constant address for this variable");
   this->read_bytes(&this->heap_address, sizeof(mdesc*), remote(std_heap_var->address));
 
   this->smx_actors_infos.clear();
@@ -246,7 +267,7 @@ void RemoteClient::refresh_heap()
 
 /** Refresh the information about the process
  *
- *  Do not use direclty, this is used by the getters when appropriate
+ *  Do not use directly, this is used by the getters when appropriate
  *  in order to have fresh data.
  * */
 void RemoteClient::refresh_malloc_info()
@@ -368,7 +389,7 @@ const simgrid::mc::Variable* RemoteClient::find_variable(const char* name) const
 {
   // First lookup the variable in the executable shared object.
   // A global variable used directly by the executable code from a library
-  // is reinstanciated in the executable memory .data/.bss.
+  // is reinstantiated in the executable memory .data/.bss.
   // We need to look up the variable in the executable first.
   if (this->binary_info) {
     std::shared_ptr<simgrid::mc::ObjectInformation> const& info = this->binary_info;
@@ -407,16 +428,11 @@ std::string RemoteClient::read_string(RemotePtr<char> address) const
 
   while (1) {
     ssize_t c = pread(this->memory_file, res.data() + off, res.size() - off, (off_t)address.address() + off);
-    if (c == -1) {
-      if (errno == EINTR)
-        continue;
-      else
-        xbt_die("Could not read from from remote process");
-    }
-    if (c == 0)
-      xbt_die("Could not read string from remote process");
+    if (c == -1 && errno == EINTR)
+      continue;
+    xbt_assert(c > 0, "Could not read string from remote process");
 
-    void* p = memchr(res.data() + off, '\0', c);
+    const void* p = memchr(res.data() + off, '\0', c);
     if (p)
       return std::string(res.data());
 
@@ -468,7 +484,7 @@ void RemoteClient::ignore_region(std::uint64_t addr, std::size_t size)
   }
 
   unsigned int cursor           = 0;
-  IgnoredRegion* current_region = nullptr;
+  const IgnoredRegion* current_region = nullptr;
 
   int start = 0;
   int end   = ignored_regions_.size() - 1;
@@ -517,7 +533,7 @@ void RemoteClient::ignore_heap(IgnoredHeapRegion const& region)
   size_type cursor;
   while (start <= end) {
     cursor               = start + (end - start) / 2;
-    auto& current_region = ignored_heap_[cursor];
+    auto const& current_region = ignored_heap_[cursor];
     if (current_region.address == region.address)
       return;
     else if (current_region.address < region.address)
@@ -546,7 +562,7 @@ void RemoteClient::unignore_heap(void* address, size_t size)
   size_type cursor;
   while (start <= end) {
     cursor       = (start + end) / 2;
-    auto& region = ignored_heap_[cursor];
+    auto const& region = ignored_heap_[cursor];
     if (region.address < address)
       start = cursor + 1;
     else if ((char*)region.address <= ((char*)address + size)) {
@@ -603,7 +619,7 @@ void RemoteClient::dump_stack()
     return;
   }
 
-  simgrid::mc::dumpStack(stderr, std::move(cursor));
+  simgrid::mc::dumpStack(stderr, &cursor);
 
   _UPT_destroy(context);
   unw_destroy_addr_space(as);
