@@ -1,4 +1,4 @@
-/* Copyright (c) 2008-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2008-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -59,11 +59,11 @@ public:
  *  as a `uint64_t`.
  */
 template <class T> class RemotePtr {
-  std::uint64_t address_;
+  std::uint64_t address_ = 0;
 
 public:
-  RemotePtr() : address_(0) {}
-  explicit RemotePtr(std::nullptr_t) : address_(0) {}
+  RemotePtr() = default;
+  explicit RemotePtr(std::nullptr_t) {}
   explicit RemotePtr(std::uint64_t address) : address_(address) {}
   explicit RemotePtr(T* address) : address_((std::uintptr_t)address) {}
   explicit RemotePtr(Remote<T*> p) : address_((std::uintptr_t)*p.get_buffer()) {}
