@@ -1,4 +1,4 @@
-/* Copyright (c) 2015-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2015-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -21,15 +21,13 @@
 #include <cstring> // memcpy, memcmp
 #include <unistd.h>
 
-XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_page_snapshot, mc, "Logging specific to mc_page_snapshot");
-
 namespace simgrid {
 namespace mc {
 
 /** @brief Compute a hash for the given memory page
  *
- *  The page is used before inserting the page in the page store
- *  in order to find duplicate of this page in the page store.
+ *  The page is used before inserting the page in the page store in order to find duplicate of this page in the page
+ *  store.
  *
  *  @param data Memory page
  *  @return hash off the page
@@ -52,7 +50,7 @@ static XBT_ALWAYS_INLINE PageStore::hash_type mc_hash_page(const void* data)
 
 // ***** snapshot_page_manager
 
-PageStore::PageStore(std::size_t size) : memory_(nullptr), capacity_(size), top_index_(0)
+PageStore::PageStore(std::size_t size) : capacity_(size)
 {
   // Using mmap in order to be able to expand the region by relocating it somewhere else in the virtual memory space:
   void* memory =
@@ -92,7 +90,7 @@ void PageStore::resize(std::size_t size)
     // Check if expanding worked
     if (new_memory != (char*)this->memory_ + old_bytesize) {
       // New memory segment could not be put at the end of this->memory_,
-      // so cancel this one and try to rellocate everything and copy data
+      // so cancel this one and try to relocate everything and copy data
       munmap(new_memory, new_bytesize - old_bytesize);
       new_memory =
           mmap(nullptr, new_bytesize, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_POPULATE, -1, 0);
@@ -120,7 +118,6 @@ void PageStore::resize(std::size_t size)
 std::size_t PageStore::alloc_page()
 {
   if (this->free_pages_.empty()) {
-
     // Expand the region:
     if (this->top_index_ == this->capacity_)
       // All the pages are allocated, we need add more pages:
@@ -128,9 +125,7 @@ std::size_t PageStore::alloc_page()
 
     // Use a page from the top:
     return this->top_index_++;
-
   } else {
-
     // Use a page from free_pages_ (inside of the region):
     size_t res = this->free_pages_[this->free_pages_.size() - 1];
     this->free_pages_.pop_back();
@@ -147,7 +142,7 @@ void PageStore::remove_page(std::size_t pageno)
 }
 
 /** Store a page in memory */
-std::size_t PageStore::store_page(void* page)
+std::size_t PageStore::store_page(const void* page)
 {
   xbt_assert(top_index_ <= this->capacity_, "top_index is not consistent");
 
@@ -162,7 +157,6 @@ std::size_t PageStore::store_page(void* page)
   for (size_t const& pageno : page_set) {
     const void* snapshot_page = this->get_page(pageno);
     if (memcmp(page, snapshot_page, xbt_pagesize) == 0) {
-
       // If a page with the same content is already in the page store it's reused and its refcount is incremented.
       page_counts_[pageno]++;
       return pageno;
@@ -172,7 +166,7 @@ std::size_t PageStore::store_page(void* page)
   // Otherwise, a new page is allocated in the page store and the content of the page is `memcpy()`-ed to this new page.
   std::size_t pageno = alloc_page();
   xbt_assert(this->page_counts_[pageno] == 0, "Allocated page is already used");
-  void* snapshot_page = (void*)this->get_page(pageno);
+  void* snapshot_page = this->get_page(pageno);
   memcpy(snapshot_page, page, xbt_pagesize);
   page_set.insert(pageno);
   page_counts_[pageno]++;
