@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -66,7 +66,7 @@ public:
   /* Regular use */
   bool on_heap(const void* address) const
   {
-    const xbt_mheap_t heap = process()->get_heap();
+    const s_xbt_mheap_t* heap = process()->get_heap();
     return address >= heap->heapbase && address < heap->breakval;
   }
 
@@ -78,7 +78,7 @@ public:
 
   // To be private
   int num_state_;
-  std::size_t heap_bytes_used_;
+  std::size_t heap_bytes_used_ = 0;
   std::vector<std::unique_ptr<Region>> snapshot_regions_;
   std::set<pid_t> enabled_processes_;
   std::vector<std::size_t> stack_sizes_;
