@@ -1,4 +1,4 @@
-/* Copyright (c) 2004-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -13,8 +13,6 @@
 #include "src/instr/instr_private.hpp"
 #include "src/msg/msg_private.hpp"
 
-XBT_LOG_NEW_DEFAULT_SUBCATEGORY(msg_comm, msg, "Logging specific to MSG (comm)");
-
 namespace simgrid {
 namespace msg {
 
@@ -84,7 +82,7 @@ int MSG_comm_test(msg_comm_t comm)
  * @return the position of the finished communication if any
  * (but it may have failed, use MSG_comm_get_status() to know its status), or -1 if none is finished
  */
-int MSG_comm_testany(xbt_dynar_t comms)
+int MSG_comm_testany(const_xbt_dynar_t comms)
 {
   int finished_index = -1;
 
@@ -126,7 +124,7 @@ int MSG_comm_testany(xbt_dynar_t comms)
 }
 
 /** @brief Destroys the provided communication. */
-void MSG_comm_destroy(msg_comm_t comm)
+void MSG_comm_destroy(const_msg_comm_t comm)
 {
   delete comm;
 }
@@ -161,7 +159,7 @@ void MSG_comm_waitall(msg_comm_t* comm, int nb_elem, double timeout)
  * @return the position of the first finished communication
  * (but it may have failed, use MSG_comm_get_status() to know its status)
  */
-int MSG_comm_waitany(xbt_dynar_t comms)
+int MSG_comm_waitany(const_xbt_dynar_t comms)
 {
   int finished_index = -1;
 
@@ -207,9 +205,8 @@ int MSG_comm_waitany(xbt_dynar_t comms)
  * @param comm a finished communication
  * @return the status of the communication, or #MSG_OK if no error occurred during the communication
  */
-msg_error_t MSG_comm_get_status(msg_comm_t comm)
+msg_error_t MSG_comm_get_status(const_msg_comm_t comm)
 {
-
   return comm->get_status();
 }
 
@@ -218,27 +215,9 @@ msg_error_t MSG_comm_get_status(msg_comm_t comm)
  * @param comm the communication where to get the task
  * @return the task from the communication
  */
-msg_task_t MSG_comm_get_task(msg_comm_t comm)
+msg_task_t MSG_comm_get_task(const_msg_comm_t comm)
 {
   xbt_assert(comm, "Invalid parameter");
 
   return comm->task_received ? *comm->task_received : comm->task_sent;
 }
-
-/**
- * @brief This function is called by SIMIX in kernel mode to copy the data of a comm.
- * @param comm the comm
- * @param buff the data copied
- * @param buff_size size of the buffer
- */
-// deprecated but used by MSG_set_copy_callback. Should be removed in v325
-void MSG_comm_copy_data_from_SIMIX(simgrid::kernel::activity::CommImpl* comm, void* buff, size_t buff_size)
-{
-  SIMIX_comm_copy_pointer_callback(comm, buff, buff_size);
-
-  // notify the user callback if any
-  if (msg_global->task_copy_callback) {
-    msg_task_t task = static_cast<msg_task_t>(buff);
-    msg_global->task_copy_callback(task, comm->src_actor_->ciface(), comm->dst_actor_->ciface());
-  }
-}
