@@ -1,4 +1,4 @@
-/* Copyright (c) 2004-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -12,12 +12,10 @@
 #include <xbt/config.hpp>
 
 XBT_LOG_NEW_CATEGORY(msg, "All MSG categories");
-XBT_LOG_NEW_DEFAULT_SUBCATEGORY(msg_kernel, msg, "Logging specific to MSG (kernel)");
 
 bool MSG_Global_t::debug_multiple_use = false;
 
 MSG_Global_t* msg_global = nullptr;
-simgrid::xbt::Extension<simgrid::s4u::Actor, simgrid::msg::ActorUserData> simgrid::msg::ActorUserData::EXTENSION_ID;
 
 static void MSG_exit();
 
@@ -28,8 +26,8 @@ static void MSG_exit();
  * @brief Initialize MSG with less verifications
  * You should use the MSG_init() function instead. Failing to do so may turn into PEBKAC some day. You've been warned.
  */
-void MSG_init_nocheck(int *argc, char **argv) {
-
+void MSG_init_nocheck(int* argc, char** argv)
+{
   TRACE_global_init();
 
   if (not msg_global) {
@@ -43,7 +41,12 @@ void MSG_init_nocheck(int *argc, char **argv) {
     msg_global->sent_msg = 0;
     msg_global->task_copy_callback = nullptr;
     msg_global->process_data_cleanup = nullptr;
-    MSG_process_userdata_init();
+    simgrid::s4u::Actor::on_termination.connect([](simgrid::s4u::Actor const& actor) {
+      // free the data if a function was provided
+      void* userdata = sg_actor_data(&actor);
+      if (userdata && msg_global->process_data_cleanup)
+        msg_global->process_data_cleanup(userdata);
+    });
   }
 
   if(MC_is_active()){
@@ -55,12 +58,14 @@ void MSG_init_nocheck(int *argc, char **argv) {
     atexit(MSG_exit);
 }
 
-void MSG_config(const char *key, const char *value){
+void MSG_config(const char* key, const char* value)
+{
   xbt_assert(msg_global,"ERROR: Please call MSG_init() before using MSG_config()");
   simgrid::config::set_as_string(key, value);
 }
 
-static void MSG_exit() {
+static void MSG_exit()
+{
   delete msg_global;
   msg_global = nullptr;
 }
