@@ -1,4 +1,4 @@
-/* Copyright (c) 2004-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -10,16 +10,19 @@
 #include "simgrid/msg.h"
 #include "src/kernel/activity/CommImpl.hpp"
 #include <simgrid/modelchecker.h>
+#include <xbt/Extendable.hpp>
 
 #include <cmath>
 
 /**************** datatypes **********************************/
 namespace simgrid {
+
+extern template class XBT_PUBLIC xbt::Extendable<msg::Task>;
+
 namespace msg {
-class Task {
+class Task : public xbt::Extendable<Task> {
   std::string name_             = "";
   std::string tracing_category_ = "";
-  void* userdata_               = nullptr;
   long long int id_;
 
   double timeout_  = 0.0;
@@ -48,30 +51,30 @@ public:
   Task& operator=(const Task&) = delete;
   ~Task()                      = default;
 
-  bool is_used() { return is_used_; }
-  bool is_parallel() { return parallel_; }
+  bool is_used() const { return is_used_; }
+  bool is_parallel() const { return parallel_; }
 
   void set_used();
   void set_not_used() { this->is_used_ = false; }
   const std::string& get_name() const { return name_; }
-  const char* get_cname() { return name_.c_str(); }
+  const char* get_cname() const { return name_.c_str(); }
   void set_name(const char* new_name) { name_ = std::string(new_name); }
-  void set_tracing_category(const char* category) { tracing_category_ = category ? std::string(category) : ""; }
-  const std::string& get_tracing_category() { return tracing_category_; }
+  void set_tracing_category(const char* category) { tracing_category_ = category ? category : ""; }
+  const std::string& get_tracing_category() const { return tracing_category_; }
   bool has_tracing_category() { return not tracing_category_.empty(); }
-  void* get_user_data() { return userdata_; }
-  void set_user_data(void* data) { userdata_ = data; }
-  long long int get_id() { return id_; }
-  double get_priority() { return priority_; }
+  XBT_ATTRIB_DEPRECATED_v329("Please use set_data()") void* get_user_data() { return get_data(); }
+  XBT_ATTRIB_DEPRECATED_v329("Please use get_data()") void set_user_data(void* data) { set_data(data); }
+  long long int get_id() const { return id_; }
+  double get_priority() const { return priority_; }
   void set_priority(double priority);
   void set_bound(double bound) { bound_ = bound; }
-  double get_bound() { return bound_; }
+  double get_bound() const { return bound_; }
   void set_rate(double rate) { rate_ = rate; }
-  double get_rate() { return rate_; }
+  double get_rate() const { return rate_; }
   void set_timeout(double timeout) { timeout_ = timeout; }
 
-  s4u::Actor* get_sender();
-  s4u::Host* get_source();
+  s4u::Actor* get_sender() const;
+  s4u::Host* get_source() const;
 
   s4u::ExecPtr compute = nullptr; /* S4U modeling of computation */
   s4u::CommPtr comm    = nullptr; /* S4U modeling of communication */
@@ -98,17 +101,7 @@ public:
   bool test();
   msg_error_t wait_for(double timeout);
   void set_status(msg_error_t status) { status_ = status; }
-  msg_error_t get_status() { return status_; }
-};
-
-class ActorUserData {
-  void* userdata_      = nullptr;
-
-public:
-  static xbt::Extension<simgrid::s4u::Actor, ActorUserData> EXTENSION_ID;
-
-  void set_user_data(void* data) { userdata_ = data; }
-  void* get_user_data() { return userdata_; }
+  msg_error_t get_status() const { return status_; }
 };
 
 } // namespace msg
@@ -125,6 +118,5 @@ struct MSG_Global_t {
 XBT_PUBLIC_DATA MSG_Global_t* msg_global;
 
 /*************************************************************/
-XBT_PRIVATE void MSG_comm_copy_data_from_SIMIX(simgrid::kernel::activity::CommImpl* comm, void* buff, size_t buff_size);
 
 #endif
