@@ -1,4 +1,4 @@
-/* Copyright (c) 2004-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -16,13 +16,17 @@
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(msg_task, msg, "Logging specific to MSG (task)");
 
 namespace simgrid {
+
+template class xbt::Extendable<msg::Task>;
+
 namespace msg {
 
 Task::Task(const std::string& name, double flops_amount, double bytes_amount, void* data)
-    : name_(name), userdata_(data), flops_amount(flops_amount), bytes_amount(bytes_amount)
+    : name_(name), flops_amount(flops_amount), bytes_amount(bytes_amount)
 {
   static std::atomic_ullong counter{0};
   id_ = counter++;
+  set_data(data);
   if (MC_is_active())
     MC_ignore_heap(&(id_), sizeof(id_));
 }
@@ -74,10 +78,9 @@ msg_error_t Task::execute()
 
     compute->set_name(name_)
         ->set_tracing_category(tracing_category_)
-        ->set_timeout(timeout_)
         ->set_priority(1 / priority_)
         ->set_bound(bound_)
-        ->wait();
+        ->wait_for(timeout_);
 
     set_not_used();
     XBT_DEBUG("Execution task '%s' finished", get_cname());
@@ -161,12 +164,12 @@ void Task::set_priority(double priority)
   priority_ = 1.0 / priority;
 }
 
-s4u::Actor* Task::get_sender()
+s4u::Actor* Task::get_sender() const
 {
   return comm ? comm->get_sender() : nullptr;
 }
 
-s4u::Host* Task::get_source()
+s4u::Host* Task::get_source() const
 {
   return comm ? comm->get_sender()->get_host() : nullptr;
 }
@@ -203,14 +206,14 @@ void Task::report_multiple_use() const
  * @param flop_amount a value of the processing amount (in flop) needed to process this new task.
  * If 0, then it cannot be executed with MSG_task_execute(). This value has to be >=0.
  * @param message_size a value of the amount of data (in bytes) needed to transfer this new task. If 0, then it cannot
- * be transfered with MSG_task_send() and MSG_task_recv(). This value has to be >=0.
+ * be transferred with MSG_task_send() and MSG_task_recv(). This value has to be >=0.
  * @param data a pointer to any data may want to attach to the new object.  It is for user-level information and can
- * be nullptr. It can be retrieved with the function @ref MSG_task_get_data.
+ * be nullptr. It can be retrieved with the function MSG_task_get_data().
  * @return The new corresponding object.
  */
 msg_task_t MSG_task_create(const char *name, double flop_amount, double message_size, void *data)
 {
-  return simgrid::msg::Task::create(name ? std::string(name) : "", flop_amount, message_size, data);
+  return simgrid::msg::Task::create(name ? name : "", flop_amount, message_size, data);
 }
 
 /** @brief Creates a new parallel task
@@ -230,7 +233,7 @@ msg_task_t MSG_task_create(const char *name, double flop_amount, double message_
  * @param bytes_amount an array of @p host_nb* @p host_nb doubles.
  * @param data a pointer to any data may want to attach to the new object.
  *             It is for user-level information and can be nullptr.
- *             It can be retrieved with the function @ref MSG_task_get_data().
+ *             It can be retrieved with the function MSG_task_get_data().
  */
 msg_task_t MSG_parallel_task_create(const char *name, int host_nb, const msg_host_t * host_list,
                                     double *flops_amount, double *bytes_amount, void *data)
@@ -241,46 +244,31 @@ msg_task_t MSG_parallel_task_create(const char *name, int host_nb, const msg_hos
 }
 
 /** @brief Return the user data of the given task */
-void* MSG_task_get_data(msg_task_t task)
+void* MSG_task_get_data(const_msg_task_t task)
 {
-  return task->get_user_data();
+  return task->get_data();
 }
 
 /** @brief Sets the user data of a given task */
 void MSG_task_set_data(msg_task_t task, void *data)
 {
-  task->set_user_data(data);
-}
-
-/** @brief Sets a function to be called when a task has just been copied.
- * @param callback a callback function
- */
-// deprecated
-void MSG_task_set_copy_callback(void (*callback) (msg_task_t task, msg_process_t sender, msg_process_t receiver)) {
-
-  msg_global->task_copy_callback = callback;
-
-  if (callback) {
-    SIMIX_comm_set_copy_data_callback(MSG_comm_copy_data_from_SIMIX);
-  } else {
-    SIMIX_comm_set_copy_data_callback(SIMIX_comm_copy_pointer_callback);
-  }
+  task->set_data(data);
 }
 
 /** @brief Returns the sender of the given task */
-msg_process_t MSG_task_get_sender(msg_task_t task)
+msg_process_t MSG_task_get_sender(const_msg_task_t task)
 {
   return task->get_sender();
 }
 
 /** @brief Returns the source (the sender's host) of the given task */
-msg_host_t MSG_task_get_source(msg_task_t task)
+msg_host_t MSG_task_get_source(const_msg_task_t task)
 {
   return task->get_source();
 }
 
 /** @brief Returns the name of the given task. */
-const char *MSG_task_get_name(msg_task_t task)
+const char* MSG_task_get_name(const_msg_task_t task)
 {
   return task->get_cname();
 }
@@ -532,7 +520,7 @@ msg_error_t MSG_task_receive_bounded(msg_task_t* task, const char* alias, double
  */
 msg_error_t MSG_task_receive_with_timeout(msg_task_t* task, const char* alias, double timeout)
 {
-  return MSG_task_receive_ext_bounded(task, alias, timeout, nullptr, -1);
+  return MSG_task_receive_with_timeout_bounded(task, alias, timeout, -1);
 }
 
 /**
@@ -554,55 +542,8 @@ msg_error_t MSG_task_receive_with_timeout(msg_task_t* task, const char* alias, d
  */
 msg_error_t MSG_task_receive_with_timeout_bounded(msg_task_t* task, const char* alias, double timeout, double rate)
 {
-  return MSG_task_receive_ext_bounded(task, alias, timeout, nullptr, rate);
-}
-
-/**
- * @brief Receives a task from a mailbox from a specific host with a given timeout.
- *
- * This is a blocking function with a timeout, the execution flow will be blocked until the task is received or the
- * timeout is achieved. See #MSG_task_irecv for receiving tasks asynchronously. You can provide a -1 timeout
- * to obtain an infinite timeout.
- *
- * @param task a memory location for storing a #msg_task_t.
- * @param alias name of the mailbox to receive the task from
- * @param timeout is the maximum wait time for completion (provide -1 for no timeout)
- * @param host a #msg_host_t host from where the task was sent
- *
- * @return Returns
- * #MSG_OK if the task was successfully received,
- * #MSG_HOST_FAILURE, or #MSG_TRANSFER_FAILURE, or #MSG_TIMEOUT otherwise.
- */
-msg_error_t MSG_task_receive_ext(msg_task_t* task, const char* alias, double timeout, msg_host_t host)
-{
-  XBT_DEBUG("MSG_task_receive_ext: Trying to receive a message on mailbox '%s'", alias);
-  return MSG_task_receive_ext_bounded(task, alias, timeout, host, -1.0);
-}
-
-/**
- * @brief Receives a task from a mailbox from a specific host with a given timeout  and at a given rate.
- *
- * @param task a memory location for storing a #msg_task_t.
- * @param alias name of the mailbox to receive the task from
- * @param timeout is the maximum wait time for completion (provide -1 for no timeout)
- * @param host a #msg_host_t host from where the task was sent
- * @param rate limit the reception to rate bandwidth (byte/sec)
- *
- * The rate parameter can be used to receive a task with a limited bandwidth (smaller than the physical available
- * value). Use MSG_task_receive_ext() if you don't limit the rate (or pass -1 as a rate value do disable this feature).
- *
- * @return Returns
- * #MSG_OK if the task was successfully received,
- * #MSG_HOST_FAILURE, or #MSG_TRANSFER_FAILURE, or #MSG_TIMEOUT otherwise.
- */
-msg_error_t MSG_task_receive_ext_bounded(msg_task_t* task, const char* alias, double timeout, msg_host_t host,
-                                         double rate)
-{
-  XBT_DEBUG("MSG_task_receive_ext: Trying to receive a message on mailbox '%s'", alias);
+  XBT_DEBUG("MSG_task_receive_with_timeout_bounded: Trying to receive a message on mailbox '%s'", alias);
   msg_error_t ret = MSG_OK;
-  /* We no longer support getting a task from a specific host */
-  if (host)
-    THROW_UNIMPLEMENTED;
 
   /* Sanity check */
   xbt_assert(task, "Null pointer for the task storage");
@@ -730,7 +671,7 @@ msg_error_t MSG_task_destroy(msg_task_t task)
 
 /** @brief Cancel the given task
  *
- * If it was currently executed or transfered, the working process is stopped.
+ * If it was currently executed or transferred, the working process is stopped.
  */
 msg_error_t MSG_task_cancel(msg_task_t task)
 {
@@ -744,8 +685,8 @@ msg_error_t MSG_task_cancel(msg_task_t task)
  *
  * It works for either parallel or sequential tasks.
  */
-double MSG_task_get_remaining_work_ratio(msg_task_t task) {
-
+double MSG_task_get_remaining_work_ratio(const_msg_task_t task)
+{
   xbt_assert((task != nullptr), "Cannot get information from a nullptr task");
   if (task->compute) {
     // Task in progress
@@ -763,7 +704,8 @@ double MSG_task_get_remaining_work_ratio(msg_task_t task) {
  * It works for sequential tasks, but the remaining amount of work is not a scalar value for parallel tasks.
  * So you will get an exception if you call this function on parallel tasks. Just don't do it.
  */
-double MSG_task_get_flops_amount(msg_task_t task) {
+double MSG_task_get_flops_amount(const_msg_task_t task)
+{
   if (task->compute != nullptr) {
     return task->compute->get_remaining();
   } else {
@@ -799,14 +741,14 @@ void MSG_task_set_bytes_amount(msg_task_t task, double data_size)
  *  If the communication does not exist it will return 0.
  *  So, if the communication has FINISHED or FAILED it returns zero.
  */
-double MSG_task_get_remaining_communication(msg_task_t task)
+double MSG_task_get_remaining_communication(const_msg_task_t task)
 {
   XBT_DEBUG("calling simcall_communication_get_remains(%p)", task->comm.get());
   return task->comm->get_remaining();
 }
 
 /** @brief Returns the size of the data attached to the given task. */
-double MSG_task_get_bytes_amount(msg_task_t task)
+double MSG_task_get_bytes_amount(const_msg_task_t task)
 {
   xbt_assert(task != nullptr, "Invalid parameter");
   return task->bytes_amount;
@@ -837,11 +779,13 @@ void MSG_task_set_bound(msg_task_t task, double bound)
  * @brief Sets the tracing category of a task.
  *
  * This function should be called after the creation of a MSG task, to define the category of that task. The
- * first parameter task must contain a task that was  =created with the function #MSG_task_create. The second
+ * first parameter task must contain a task that was =created with the function MSG_task_create(). The second
  * parameter category must contain a category that was previously declared with the function #TRACE_category
  * (or with #TRACE_category_with_color).
  *
- * See @ref outcomes_vizu for details on how to trace the (categorized) resource utilization.
+ * @beginrst
+ * See :ref:`outcomes_vizu` for details on how to trace the (categorized) resource utilization.
+ * @endrst
  *
  * @param task the task that is going to be categorized
  * @param category the name of the category to be associated to the task
@@ -869,7 +813,7 @@ void MSG_task_set_category(msg_task_t task, const char* category)
  * @param task the task to be considered
  * @return Returns the name of the tracing category of the given task, "" otherwise
  */
-const char* MSG_task_get_category(msg_task_t task)
+const char* MSG_task_get_category(const_msg_task_t task)
 {
   return task->get_tracing_category().c_str();
 }
