@@ -1,4 +1,4 @@
-/* Copyright (c) 2015-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2015-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -17,69 +17,89 @@
 #include <fstream>
 #include <numeric>
 
-XBT_LOG_NEW_DEFAULT_CATEGORY(s4u_file, "S4U files");
+XBT_LOG_NEW_DEFAULT_SUBCATEGORY(s4u_file, s4u, "S4U files");
 int sg_storage_max_file_descriptors = 1024;
 
+/** @defgroup plugin_filesystem Plugin FileSystem
+ *
+ * This adds the notion of Files on top of the storage notion that provided by the core of SimGrid.
+ * Activate this plugin at will.
+ */
+
 namespace simgrid {
+
+template class xbt::Extendable<s4u::File>;
+
 namespace s4u {
 simgrid::xbt::Extension<Disk, FileSystemDiskExt> FileSystemDiskExt::EXTENSION_ID;
 simgrid::xbt::Extension<Storage, FileSystemStorageExt> FileSystemStorageExt::EXTENSION_ID;
 simgrid::xbt::Extension<Host, FileDescriptorHostExt> FileDescriptorHostExt::EXTENSION_ID;
 
-File::File(const std::string& fullpath, void* userdata) : File(fullpath, Host::current(), userdata){};
-
-File::File(const std::string& fullpath, sg_host_t host, void* userdata) : fullpath_(fullpath), userdata_(userdata)
+Storage* File::find_local_storage_on(Host* host)
 {
-  // this cannot fail because we get a xbt_die if the mountpoint does not exist
-  if (not host->get_mounted_storages().empty()) {
-    Storage* st                  = nullptr;
-    size_t longest_prefix_length = 0;
-    XBT_DEBUG("Search for storage name for '%s' on '%s'", fullpath_.c_str(), host->get_cname());
+  Storage* st                  = nullptr;
+  size_t longest_prefix_length = 0;
+  XBT_DEBUG("Search for storage name for '%s' on '%s'", fullpath_.c_str(), host->get_cname());
 
-    for (auto const& mnt : host->get_mounted_storages()) {
-      XBT_DEBUG("See '%s'", mnt.first.c_str());
-      mount_point_ = fullpath_.substr(0, mnt.first.length());
+  for (auto const& mnt : host->get_mounted_storages()) {
+    XBT_DEBUG("See '%s'", mnt.first.c_str());
+    mount_point_ = fullpath_.substr(0, mnt.first.length());
 
-      if (mount_point_ == mnt.first && mnt.first.length() > longest_prefix_length) {
-        /* The current mount name is found in the full path and is bigger than the previous*/
-        longest_prefix_length = mnt.first.length();
-        st                    = mnt.second;
-      }
+    if (mount_point_ == mnt.first && mnt.first.length() > longest_prefix_length) {
+      /* The current mount name is found in the full path and is bigger than the previous*/
+      longest_prefix_length = mnt.first.length();
+      st                    = mnt.second;
+    }
+  }
+  if (longest_prefix_length > 0) { /* Mount point found, split fullpath_ into mount_name and path+filename*/
+    mount_point_ = fullpath_.substr(0, longest_prefix_length);
+    path_        = fullpath_.substr(longest_prefix_length, fullpath_.length());
+  } else
+    xbt_die("Can't find mount point for '%s' on '%s'", fullpath_.c_str(), host->get_cname());
+
+  return st;
+}
+
+Disk* File::find_local_disk_on(const Host* host)
+{
+  Disk* d                      = nullptr;
+  size_t longest_prefix_length = 0;
+  for (auto const& disk : host->get_disks()) {
+    std::string current_mount;
+    if (disk->get_host() != host)
+      current_mount = disk->extension<FileSystemDiskExt>()->get_mount_point(disk->get_host());
+    else
+      current_mount = disk->extension<FileSystemDiskExt>()->get_mount_point();
+    mount_point_ = fullpath_.substr(0, current_mount.length());
+    if (mount_point_ == current_mount && current_mount.length() > longest_prefix_length) {
+      /* The current mount name is found in the full path and is bigger than the previous*/
+      longest_prefix_length = current_mount.length();
+      d                     = disk;
     }
     if (longest_prefix_length > 0) { /* Mount point found, split fullpath_ into mount_name and path+filename*/
       mount_point_ = fullpath_.substr(0, longest_prefix_length);
-      path_        = fullpath_.substr(longest_prefix_length, fullpath_.length());
+      if (mount_point_ == std::string("/"))
+        path_ = fullpath_;
+      else
+        path_ = fullpath_.substr(longest_prefix_length, fullpath_.length());
+      XBT_DEBUG("%s + %s", mount_point_.c_str(), path_.c_str());
     } else
       xbt_die("Can't find mount point for '%s' on '%s'", fullpath_.c_str(), host->get_cname());
+  }
+  return d;
+}
 
-    local_storage_ = st;
+File::File(const std::string& fullpath, void* userdata) : File(fullpath, Host::current(), userdata) {}
+
+File::File(const std::string& fullpath, sg_host_t host, void* userdata) : fullpath_(fullpath)
+{
+  this->set_data(userdata);
+  // this cannot fail because we get a xbt_die if the mountpoint does not exist
+  if (not host->get_mounted_storages().empty()) {
+    local_storage_ = find_local_storage_on(host);
   }
   if (not host->get_disks().empty()) {
-    Disk* d                      = nullptr;
-    size_t longest_prefix_length = 0;
-    for (auto const& disk : host->get_disks()) {
-      std::string current_mount;
-      if (disk->get_host() != host)
-        current_mount = disk->extension<FileSystemDiskExt>()->get_mount_point(disk->get_host());
-      else
-        current_mount = disk->extension<FileSystemDiskExt>()->get_mount_point();
-      mount_point_              = fullpath_.substr(0, current_mount.length());
-      if (mount_point_ == current_mount && current_mount.length() > longest_prefix_length) {
-        /* The current mount name is found in the full path and is bigger than the previous*/
-        longest_prefix_length = current_mount.length();
-        d                     = disk;
-      }
-      if (longest_prefix_length > 0) { /* Mount point found, split fullpath_ into mount_name and path+filename*/
-        mount_point_ = fullpath_.substr(0, longest_prefix_length);
-        if (mount_point_ == std::string("/"))
-          path_ = fullpath_;
-        else
-          path_ = fullpath_.substr(longest_prefix_length, fullpath_.length());
-        XBT_DEBUG("%s + %s", mount_point_.c_str(), path_.c_str());
-      } else
-        xbt_die("Can't find mount point for '%s' on '%s'", fullpath_.c_str(), host->get_cname());
-    }
-    local_disk_ = d;
+    local_disk_ = find_local_disk_on(host);
   }
 
   // assign a file descriptor id to the newly opened File
@@ -175,22 +195,53 @@ sg_size_t File::read(sg_size_t size)
 }
 
 /** @brief Write into a file (local or remote)
+ * @ingroup plugin_filesystem
  *
  * @param size of the file to write
  * @return the number of bytes successfully write or -1 if an error occurred
  */
-sg_size_t File::write(sg_size_t size, int write_inside)
+sg_size_t File::write_on_disk(sg_size_t size, bool write_inside)
 {
-  if (size == 0) /* Nothing to write, return */
-    return 0;
   sg_size_t write_size = 0;
-  Host* host           = nullptr;
-
   /* Find the host where the file is physically located (remote or local)*/
-  if (local_storage_)
-    host = local_storage_->get_host();
-  if (local_disk_)
-    host = local_disk_->get_host();
+  Host* host = local_disk_->get_host();
+
+  if (host && host->get_name() != Host::current()->get_name()) {
+    /* the file is hosted on a remote host, initiate a communication between src and dest hosts for data transfer */
+    XBT_DEBUG("File is on %s remote host, initiate data transfer of %llu bytes.", host->get_cname(), size);
+    Host::current()->send_to(host, size);
+  }
+  XBT_DEBUG("WRITE %s on disk '%s'. size '%llu/%llu' '%llu:%llu'", get_path(), local_disk_->get_cname(), size, size_,
+            sg_disk_get_size_used(local_disk_), sg_disk_get_size(local_disk_));
+  // If the storage is full before even starting to write
+  if (sg_disk_get_size_used(local_disk_) >= sg_disk_get_size(local_disk_))
+    return 0;
+  if (not write_inside) {
+    /* Subtract the part of the file that might disappear from the used sized on the storage element */
+    local_disk_->extension<FileSystemDiskExt>()->decr_used_size(size_ - current_position_);
+    write_size = local_disk_->write(size);
+    local_disk_->extension<FileSystemDiskExt>()->incr_used_size(write_size);
+    current_position_ += write_size;
+    size_ = current_position_;
+  } else {
+    write_size = local_disk_->write(size);
+    current_position_ += write_size;
+    if (current_position_ > size_)
+      size_ = current_position_;
+  }
+  std::map<std::string, sg_size_t>* content = local_disk_->extension<FileSystemDiskExt>()->get_content();
+
+  content->erase(path_);
+  content->insert({path_, size_});
+
+  return write_size;
+}
+
+sg_size_t File::write_on_storage(sg_size_t size, bool write_inside)
+{
+  sg_size_t write_size = 0;
+  /* Find the host where the file is physically located (remote or local)*/
+  Host* host = local_storage_->get_host();
 
   if (host && host->get_name() != Host::current()->get_name()) {
     /* the file is hosted on a remote host, initiate a communication between src and dest hosts for data transfer */
@@ -198,58 +249,45 @@ sg_size_t File::write(sg_size_t size, int write_inside)
     Host::current()->send_to(host, size);
   }
 
-  if (local_storage_) {
-    XBT_DEBUG("WRITE %s on disk '%s'. size '%llu/%llu' '%llu:%llu'", get_path(), local_storage_->get_cname(), size,
-              size_, sg_storage_get_size_used(local_storage_), sg_storage_get_size(local_storage_));
-    // If the storage is full before even starting to write
-    if (sg_storage_get_size_used(local_storage_) >= sg_storage_get_size(local_storage_))
-      return 0;
-    if (write_inside == 0) {
-      /* Substract the part of the file that might disappear from the used sized on the storage element */
-      local_storage_->extension<FileSystemStorageExt>()->decr_used_size(size_ - current_position_);
-      write_size = local_storage_->write(size);
-      local_storage_->extension<FileSystemStorageExt>()->incr_used_size(write_size);
-      current_position_ += write_size;
+  XBT_DEBUG("WRITE %s on disk '%s'. size '%llu/%llu' '%llu:%llu'", get_path(), local_storage_->get_cname(), size, size_,
+            sg_storage_get_size_used(local_storage_), sg_storage_get_size(local_storage_));
+  // If the storage is full before even starting to write
+  if (sg_storage_get_size_used(local_storage_) >= sg_storage_get_size(local_storage_))
+    return 0;
+  if (not write_inside) {
+    /* Subtract the part of the file that might disappear from the used sized on the storage element */
+    local_storage_->extension<FileSystemStorageExt>()->decr_used_size(size_ - current_position_);
+    write_size = local_storage_->write(size);
+    local_storage_->extension<FileSystemStorageExt>()->incr_used_size(write_size);
+    current_position_ += write_size;
+    size_ = current_position_;
+  } else {
+    write_size = local_storage_->write(size);
+    current_position_ += write_size;
+    if (current_position_ > size_)
       size_ = current_position_;
-    } else {
-      write_size = local_storage_->write(size);
-      current_position_ += write_size;
-      if (current_position_ > size_)
-        size_ = current_position_;
-    }
-    std::map<std::string, sg_size_t>* content = local_storage_->extension<FileSystemStorageExt>()->get_content();
-
-    content->erase(path_);
-    content->insert({path_, size_});
   }
+  std::map<std::string, sg_size_t>* content = local_storage_->extension<FileSystemStorageExt>()->get_content();
 
-  if (local_disk_) {
-    XBT_DEBUG("WRITE %s on disk '%s'. size '%llu/%llu' '%llu:%llu'", get_path(), local_disk_->get_cname(), size, size_,
-              sg_disk_get_size_used(local_disk_), sg_disk_get_size(local_disk_));
-    // If the storage is full before even starting to write
-    if (sg_disk_get_size_used(local_disk_) >= sg_disk_get_size(local_disk_))
-      return 0;
-    if (write_inside == 0) {
-      /* Substract the part of the file that might disappear from the used sized on the storage element */
-      local_disk_->extension<FileSystemDiskExt>()->decr_used_size(size_ - current_position_);
-      write_size = local_disk_->write(size);
-      local_disk_->extension<FileSystemDiskExt>()->incr_used_size(write_size);
-      current_position_ += write_size;
-      size_ = current_position_;
-    } else {
-      write_size = local_disk_->write(size);
-      current_position_ += write_size;
-      if (current_position_ > size_)
-        size_ = current_position_;
-    }
-    std::map<std::string, sg_size_t>* content = local_disk_->extension<FileSystemDiskExt>()->get_content();
+  content->erase(path_);
+  content->insert({path_, size_});
 
-    content->erase(path_);
-    content->insert({path_, size_});
-  }
   return write_size;
 }
 
+sg_size_t File::write(sg_size_t size, bool write_inside)
+{
+  if (size == 0) /* Nothing to write, return */
+    return 0;
+
+  if (local_disk_)
+    return write_on_disk(size, write_inside);
+  if (local_storage_)
+    return write_on_storage(size, write_inside);
+
+  return 0;
+}
+
 sg_size_t File::size()
 {
   return size_;
@@ -335,7 +373,7 @@ int File::unlink()
       local_disk_->extension<FileSystemDiskExt>()->decr_used_size(size_);
 
     // Remove the file from storage
-    content->erase(fullpath_);
+    content->erase(path_);
 
     return 0;
   }
@@ -366,10 +404,10 @@ int File::remote_copy(sg_host_t host, const char* fullpath)
   current_position_ += read_size;
 
   Host* dst_host = host;
+  size_t longest_prefix_length = 0;
   if (local_storage_) {
     /* Find the host that owns the storage where the file has to be copied */
-    Storage* storage_dest        = nullptr;
-    size_t longest_prefix_length = 0;
+    const Storage* storage_dest = nullptr;
 
     for (auto const& elm : host->get_mounted_storages()) {
       std::string mount_point = std::string(fullpath).substr(0, elm.first.size());
@@ -390,8 +428,7 @@ int File::remote_copy(sg_host_t host, const char* fullpath)
   }
 
   if (local_disk_) {
-    size_t longest_prefix_length = 0;
-    Disk* dst_disk               = nullptr;
+    const Disk* dst_disk = nullptr;
 
     for (auto const& disk : host->get_disks()) {
       std::string current_mount = disk->extension<FileSystemDiskExt>()->get_mount_point();
@@ -435,7 +472,7 @@ int File::remote_move(sg_host_t host, const char* fullpath)
   return res;
 }
 
-FileSystemDiskExt::FileSystemDiskExt(simgrid::s4u::Disk* ptr)
+FileSystemDiskExt::FileSystemDiskExt(const Disk* ptr)
 {
   const char* size_str    = ptr->get_property("size");
   if (size_str)
@@ -452,10 +489,9 @@ FileSystemDiskExt::FileSystemDiskExt(simgrid::s4u::Disk* ptr)
     content_.reset(parse_content(content_str));
 }
 
-FileSystemStorageExt::FileSystemStorageExt(simgrid::s4u::Storage* ptr)
+FileSystemStorageExt::FileSystemStorageExt(const Storage* ptr) : size_(ptr->get_impl()->size_)
 {
   content_.reset(parse_content(ptr->get_impl()->content_name_));
-  size_    = ptr->get_impl()->size_;
 }
 
 std::map<std::string, sg_size_t>* FileSystemDiskExt::parse_content(const std::string& filename)
@@ -578,6 +614,13 @@ static void on_simulation_end()
 }
 
 /* **************************** Public interface *************************** */
+/** @brief Initialize the file system plugin.
+    @ingroup plugin_filesystem
+
+    @beginrst
+    See the examples in :ref:`s4u_ex_disk_io`.
+    @endrst
+ */
 void sg_storage_file_system_init()
 {
   sg_storage_max_file_descriptors = 1024;
@@ -617,17 +660,23 @@ sg_size_t sg_file_write(sg_file_t fd, sg_size_t size)
   return fd->write(size);
 }
 
-void sg_file_close(sg_file_t fd)
+void sg_file_close(const_sg_file_t fd)
 {
   delete fd;
 }
 
+/** Retrieves the path to the file
+ * @ingroup plugin_filesystem
+ */
 const char* sg_file_get_name(sg_file_t fd)
 {
   xbt_assert((fd != nullptr), "Invalid file descriptor");
   return fd->get_path();
 }
 
+/** Retrieves the size of the file
+ * @ingroup plugin_filesystem
+ */
 sg_size_t sg_file_get_size(sg_file_t fd)
 {
   return fd->size();
@@ -638,19 +687,25 @@ void sg_file_dump(sg_file_t fd)
   fd->dump();
 }
 
-void* sg_file_get_data(sg_file_t fd)
+/** Retrieves the user data associated with the file
+ * @ingroup plugin_filesystem
+ */
+void* sg_file_get_data(const_sg_file_t fd)
 {
-  return fd->get_userdata();
+  return fd->get_data();
 }
 
+/** Changes the user data associated with the file
+ * @ingroup plugin_filesystem
+ */
 void sg_file_set_data(sg_file_t fd, void* data)
 {
-  fd->set_userdata(data);
+  fd->set_data(data);
 }
 
 /**
- * @brief Set the file position indicator in the sg_file_t by adding offset bytes
- * to the position specified by origin (either SEEK_SET, SEEK_CUR, or SEEK_END).
+ * @brief Set the file position indicator in the sg_file_t by adding offset bytes to the position specified by origin (either SEEK_SET, SEEK_CUR, or SEEK_END).
+ * @ingroup plugin_filesystem
  *
  * @param fd : file object that identifies the stream
  * @param offset : number of bytes to offset from origin
@@ -681,6 +736,8 @@ void sg_file_unlink(sg_file_t fd)
 
 /**
  * @brief Copy a file to another location on a remote host.
+ * @ingroup plugin_filesystem
+ *
  * @param file : the file to move
  * @param host : the remote host where the file has to be copied
  * @param fullpath : the complete path destination on the remote host
@@ -693,6 +750,8 @@ int sg_file_rcopy(sg_file_t file, sg_host_t host, const char* fullpath)
 
 /**
  * @brief Move a file to another location on a remote host.
+ * @ingroup plugin_filesystem
+ *
  * @param file : the file to move
  * @param host : the remote host where the file has to be moved
  * @param fullpath : the complete path destination on the remote host
@@ -703,51 +762,52 @@ int sg_file_rmove(sg_file_t file, sg_host_t host, const char* fullpath)
   return file->remote_move(host, fullpath);
 }
 
-sg_size_t sg_disk_get_size_free(sg_disk_t d)
+sg_size_t sg_disk_get_size_free(const_sg_disk_t d)
 {
   return d->extension<FileSystemDiskExt>()->get_size() - d->extension<FileSystemDiskExt>()->get_used_size();
 }
 
-sg_size_t sg_disk_get_size_used(sg_disk_t d)
+sg_size_t sg_disk_get_size_used(const_sg_disk_t d)
 {
   return d->extension<FileSystemDiskExt>()->get_used_size();
 }
 
-sg_size_t sg_disk_get_size(sg_disk_t d)
+sg_size_t sg_disk_get_size(const_sg_disk_t d)
 {
   return d->extension<FileSystemDiskExt>()->get_size();
 }
 
-const char* sg_disk_get_mount_point(sg_disk_t d)
+const char* sg_disk_get_mount_point(const_sg_disk_t d)
 {
   return d->extension<FileSystemDiskExt>()->get_mount_point();
 }
 
-sg_size_t sg_storage_get_size_free(sg_storage_t st)
+sg_size_t sg_storage_get_size_free(const_sg_storage_t st)
 {
   return st->extension<FileSystemStorageExt>()->get_size() - st->extension<FileSystemStorageExt>()->get_used_size();
 }
 
-sg_size_t sg_storage_get_size_used(sg_storage_t st)
+sg_size_t sg_storage_get_size_used(const_sg_storage_t st)
 {
   return st->extension<FileSystemStorageExt>()->get_used_size();
 }
 
-sg_size_t sg_storage_get_size(sg_storage_t st)
+sg_size_t sg_storage_get_size(const_sg_storage_t st)
 {
   return st->extension<FileSystemStorageExt>()->get_size();
 }
 
-xbt_dict_t sg_storage_get_content(sg_storage_t storage)
+xbt_dict_t sg_storage_get_content(const_sg_storage_t storage)
 {
-  std::map<std::string, sg_size_t>* content = storage->extension<simgrid::s4u::FileSystemStorageExt>()->get_content();
+  const std::map<std::string, sg_size_t>* content =
+      storage->extension<simgrid::s4u::FileSystemStorageExt>()->get_content();
   // Note: ::operator delete is ok here (no destructor called) since the dict elements are of POD type sg_size_t.
   xbt_dict_t content_as_dict = xbt_dict_new_homogeneous(::operator delete);
 
   for (auto const& entry : *content) {
     sg_size_t* psize = new sg_size_t;
     *psize           = entry.second;
-    xbt_dict_set(content_as_dict, entry.first.c_str(), psize, nullptr);
+    xbt_dict_set(content_as_dict, entry.first.c_str(), psize);
   }
   return content_as_dict;
 }
@@ -757,7 +817,7 @@ xbt_dict_t sg_host_get_storage_content(sg_host_t host)
   xbt_assert((host != nullptr), "Invalid parameters");
   xbt_dict_t contents = xbt_dict_new_homogeneous(nullptr);
   for (auto const& elm : host->get_mounted_storages())
-    xbt_dict_set(contents, elm.first.c_str(), sg_storage_get_content(elm.second), nullptr);
+    xbt_dict_set(contents, elm.first.c_str(), sg_storage_get_content(elm.second));
 
   return contents;
 }
