@@ -1,4 +1,4 @@
-/* Copyright (c) 2010-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2010-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -83,19 +83,17 @@ namespace dvfs {
  *  global configuration
  */
 class Governor {
-
-private:
   simgrid::s4u::Host* const host_;
   double sampling_rate_;
-  int min_pstate; //< Never use a pstate less than this one
-  int max_pstate; //< Never use a pstate larger than this one
+  int min_pstate = cfg_min_pstate; //< Never use a pstate less than this one
+  int max_pstate = cfg_max_pstate; //< Never use a pstate larger than this one
 
 public:
   explicit Governor(simgrid::s4u::Host* ptr)
       : host_(ptr)
-      , min_pstate(cfg_min_pstate)
-      , max_pstate(cfg_max_pstate == max_pstate_not_limited ? host_->get_pstate_count() - 1 : cfg_max_pstate)
   {
+    if (cfg_max_pstate == max_pstate_not_limited)
+      max_pstate = host_->get_pstate_count() - 1;
     init();
   }
   virtual ~Governor() = default;
@@ -221,9 +219,9 @@ public:
  *
  * > The CPUfreq governor "conservative", much like the "ondemand"
  * > governor, sets the CPU frequency depending on the current usage.  It
- * > differs in behaviour in that it gracefully increases and decreases the
+ * > differs in behavior in that it gracefully increases and decreases the
  * > CPU speed rather than jumping to max speed the moment there is any load
- * > on the CPU. This behaviour is more suitable in a battery powered
+ * > on the CPU. This behavior is more suitable in a battery powered
  * > environment.
  */
 class Conservative : public Governor {
@@ -232,9 +230,9 @@ class Conservative : public Governor {
 
 public:
   explicit Conservative(simgrid::s4u::Host* ptr) : Governor(ptr) {}
-  virtual std::string get_name() const override { return "Conservative"; }
+  std::string get_name() const override { return "Conservative"; }
 
-  virtual void update() override
+  void update() override
   {
     double load = get_host()->get_core_count() * sg_host_get_avg_load(get_host());
     int pstate  = get_host()->get_pstate();
@@ -307,14 +305,14 @@ public:
     // FIXME I think that this fires at the same time for all hosts, so when the src sends something,
     // the dst will be notified even though it didn't even arrive at the recv yet
     simgrid::s4u::Link::on_communicate.connect(
-        [this](kernel::resource::NetworkAction const&, s4u::Host* src, s4u::Host* dst) {
+        [this](const kernel::resource::NetworkAction&, const s4u::Host* src, const s4u::Host* dst) {
           if ((get_host() == src || get_host() == dst) && iteration_running) {
             post_task();
           }
         });
   }
 
-  virtual std::string get_name() const override { return "Adagio"; }
+  std::string get_name() const override { return "Adagio"; }
 
   void pre_task()
   {
@@ -355,7 +353,7 @@ public:
     task_id++;
   }
 
-  virtual void update() override {}
+  void update() override {}
 };
 #endif
 } // namespace dvfs
