@@ -1,4 +1,4 @@
-/* Copyright (c) 2004-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -14,6 +14,9 @@
 #define VM_INTERFACE_HPP_
 
 namespace simgrid {
+
+extern template class XBT_PUBLIC xbt::Extendable<vm::VirtualMachineImpl>;
+
 namespace vm {
 
 /************
@@ -28,14 +31,16 @@ class XBT_PUBLIC VirtualMachineImpl : public surf::HostImpl, public simgrid::xbt
   friend simgrid::s4u::VirtualMachine;
 
 public:
-  explicit VirtualMachineImpl(s4u::VirtualMachine* piface, s4u::Host* host, int core_amount, size_t ramsize);
-  ~VirtualMachineImpl();
-
   /** @brief Callbacks fired after VM creation. Signature: `void(VirtualMachineImpl&)` */
   static xbt::signal<void(simgrid::vm::VirtualMachineImpl&)> on_creation;
   /** @brief Callbacks fired after VM destruction. Signature: `void(VirtualMachineImpl const&)` */
   static xbt::signal<void(simgrid::vm::VirtualMachineImpl const&)> on_destruction;
 
+  static std::deque<s4u::VirtualMachine*> allVms_;
+
+  explicit VirtualMachineImpl(s4u::VirtualMachine* piface, s4u::Host* host, int core_amount, size_t ramsize);
+  ~VirtualMachineImpl();
+
   virtual void suspend(kernel::actor::ActorImpl* issuer);
   virtual void resume();
   virtual void shutdown(kernel::actor::ActorImpl* issuer);
@@ -45,30 +50,35 @@ public:
   /** @brief Get the physical host on which the given VM is running */
   s4u::Host* get_physical_host() { return physical_host_; }
 
-  sg_size_t get_ramsize() { return ramsize_; }
+  sg_size_t get_ramsize() const { return ramsize_; }
   void set_ramsize(sg_size_t ramsize) { ramsize_ = ramsize; }
 
-  s4u::VirtualMachine::state get_state() { return vm_state_; }
+  s4u::VirtualMachine::state get_state() const { return vm_state_; }
   void set_state(s4u::VirtualMachine::state state) { vm_state_ = state; }
 
-  int get_core_amount() { return core_amount_; }
+  unsigned int get_core_amount() { return core_amount_; }
+  kernel::resource::Action* get_action() { return action_; }
 
   virtual void set_bound(double bound);
 
-  /* The vm object of the lower layer */
-  kernel::resource::Action* action_ = nullptr;
-  static std::deque<s4u::VirtualMachine*> allVms_;
-  bool is_migrating_ = false;
-  int active_tasks_ = 0;
-
   void update_action_weight();
 
+  void add_active_exec() { active_execs_++; }
+  void remove_active_exec() { active_execs_--; }
+
+  void start_migration() { is_migrating_ = true; }
+  void end_migration() { is_migrating_ = false; }
+  bool is_migrating() const { return is_migrating_; }
+
 private:
+  kernel::resource::Action* action_ = nullptr;
+  unsigned int active_execs_        = 0;
   s4u::Host* physical_host_;
-  int core_amount_;
-  double user_bound_;
-  size_t ramsize_            = 0;
+  unsigned int core_amount_;
+  double user_bound_                   = std::numeric_limits<double>::max();
+  size_t ramsize_                      = 0;
   s4u::VirtualMachine::state vm_state_ = s4u::VirtualMachine::state::CREATED;
+  bool is_migrating_                   = false;
 };
 
 /*********
@@ -82,8 +92,13 @@ class XBT_PRIVATE VMModel : public surf::HostModel {
 public:
   VMModel();
 
-  double next_occuring_event(double now) override;
+  double next_occurring_event(double now) override;
   void update_actions_state(double /*now*/, double /*delta*/) override{};
+  kernel::resource::Action* execute_parallel(const std::vector<s4u::Host*>& host_list, const double* flops_amount,
+                                             const double* bytes_amount, double rate) override
+  {
+    return nullptr;
+  };
 };
 }
 }
