@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2006-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -13,15 +13,17 @@
 #include "src/include/mc/mc.h"
 #include "src/kernel/activity/ExecImpl.hpp"
 #include "src/mc/mc_replay.hpp"
-#include "src/simix/smx_private.hpp"
 #include "src/surf/HostImpl.hpp"
 
 #include <algorithm>
 #include <sstream>
 
-XBT_LOG_NEW_DEFAULT_CATEGORY(s4u_actor, "S4U actors");
+XBT_LOG_NEW_DEFAULT_SUBCATEGORY(s4u_actor, s4u, "S4U actors");
 
 namespace simgrid {
+
+template class xbt::Extendable<s4u::Actor>;
+
 namespace s4u {
 
 xbt::signal<void(Actor&)> s4u::Actor::on_creation;
@@ -29,8 +31,9 @@ xbt::signal<void(Actor const&)> s4u::Actor::on_suspend;
 xbt::signal<void(Actor const&)> s4u::Actor::on_resume;
 xbt::signal<void(Actor const&)> s4u::Actor::on_sleep;
 xbt::signal<void(Actor const&)> s4u::Actor::on_wake_up;
-xbt::signal<void(Actor const&)> s4u::Actor::on_migration_start;
-xbt::signal<void(Actor const&)> s4u::Actor::on_migration_end;
+xbt::signal<void(Actor const&)> s4u::Actor::on_migration_start; // deprecated
+xbt::signal<void(Actor const&)> s4u::Actor::on_migration_end;   // deprecated
+xbt::signal<void(Actor const&, Host const& previous_location)> s4u::Actor::on_host_change;
 xbt::signal<void(Actor const&)> s4u::Actor::on_termination;
 xbt::signal<void(Actor const&)> s4u::Actor::on_destruction;
 
@@ -43,9 +46,10 @@ Actor* Actor::self()
 
   return self_context->get_actor()->ciface();
 }
+
 ActorPtr Actor::init(const std::string& name, s4u::Host* host)
 {
-  smx_actor_t self = SIMIX_process_self();
+  kernel::actor::ActorImpl* self = kernel::actor::ActorImpl::self();
   kernel::actor::ActorImpl* actor =
       kernel::actor::simcall([self, &name, host] { return self->init(name, host).get(); });
   return actor->iface();
@@ -59,7 +63,7 @@ ActorPtr Actor::start(const std::function<void()>& code)
 
 ActorPtr Actor::create(const std::string& name, s4u::Host* host, const std::function<void()>& code)
 {
-  smx_actor_t self = SIMIX_process_self();
+  kernel::actor::ActorImpl* self = kernel::actor::ActorImpl::self();
   kernel::actor::ActorImpl* actor =
       kernel::actor::simcall([self, &name, host, &code] { return self->init(name, host)->start(code); });
 
@@ -69,15 +73,15 @@ ActorPtr Actor::create(const std::string& name, s4u::Host* host, const std::func
 ActorPtr Actor::create(const std::string& name, s4u::Host* host, const std::string& function,
                        std::vector<std::string> args)
 {
-  simix::ActorCodeFactory& factory = SIMIX_get_actor_code_factory(function);
+  const simix::ActorCodeFactory& factory = SIMIX_get_actor_code_factory(function);
   return create(name, host, factory(std::move(args)));
 }
 
-void intrusive_ptr_add_ref(Actor* actor)
+void intrusive_ptr_add_ref(const Actor* actor)
 {
   intrusive_ptr_add_ref(actor->pimpl_);
 }
-void intrusive_ptr_release(Actor* actor)
+void intrusive_ptr_release(const Actor* actor)
 {
   intrusive_ptr_release(actor->pimpl_);
 }
@@ -95,8 +99,8 @@ void Actor::join()
 
 void Actor::join(double timeout)
 {
-  auto issuer = SIMIX_process_self();
-  auto target = pimpl_;
+  kernel::actor::ActorImpl* issuer = kernel::actor::ActorImpl::self();
+  kernel::actor::ActorImpl* target = pimpl_;
   kernel::actor::simcall_blocking<void>([issuer, target, timeout] {
     if (target->finished_) {
       // The joined process is already finished, just wake up the issuer right away
@@ -115,24 +119,29 @@ void Actor::set_auto_restart(bool autorestart)
     pimpl_->set_auto_restart(autorestart);
 
     kernel::actor::ProcessArg* arg = new kernel::actor::ProcessArg(pimpl_->get_host(), pimpl_);
-    XBT_DEBUG("Adding Process %s to the actors_at_boot_ list of Host %s", arg->name.c_str(), arg->host->get_cname());
-    pimpl_->get_host()->pimpl_->actors_at_boot_.emplace_back(arg);
+    XBT_DEBUG("Adding %s to the actors_at_boot_ list of Host %s", arg->name.c_str(), arg->host->get_cname());
+    pimpl_->get_host()->pimpl_->add_actor_at_boot(arg);
   });
 }
 
-void Actor::on_exit(const std::function<void(int, void*)>& fun, void* data) /* deprecated */
-{
-  on_exit([fun, data](bool failed) { fun(failed ? SMX_EXIT_FAILURE : SMX_EXIT_SUCCESS, data); });
-}
-
 void Actor::on_exit(const std::function<void(bool /*failed*/)>& fun) const
 {
-  kernel::actor::simcall([this, &fun] { SIMIX_process_on_exit(pimpl_, fun); });
+  kernel::actor::simcall([this, &fun] { pimpl_->on_exit->emplace_back(fun); });
 }
 
-void Actor::migrate(Host* new_host)
+void Actor::set_host(Host* new_host)
 {
-  s4u::Actor::on_migration_start(*this);
+  if (s4u::Actor::on_migration_start.get_slot_count() > 0) { // XBT_ATTRIB_DEPRECATED_v329
+    static bool already_warned = false;
+    if (not already_warned) {
+      XBT_INFO("Please use s4u::Actor::on_host_change instead of s4u::Actor::on_migration_start. This will be removed "
+               "in v3.29");
+      already_warned = true;
+    }
+    s4u::Actor::on_migration_start(*this);
+  }
+
+  const s4u::Host* previous_location = get_host();
 
   kernel::actor::simcall([this, new_host]() {
     if (pimpl_->waiting_synchro != nullptr) {
@@ -146,7 +155,17 @@ void Actor::migrate(Host* new_host)
     this->pimpl_->set_host(new_host);
   });
 
-  s4u::Actor::on_migration_end(*this);
+  if (s4u::Actor::on_migration_end.get_slot_count() > 0) { // XBT_ATTRIB_DEPRECATED_v329
+    static bool already_warned = false;
+    if (not already_warned) {
+      XBT_INFO("Please use s4u::Actor::on_host_change instead of s4u::Actor::on_migration_end. This will be removed in "
+               "v3.29");
+      already_warned = true;
+    }
+    s4u::Actor::on_migration_end(*this);
+  }
+
+  s4u::Actor::on_host_change(*this, *previous_location);
 }
 
 s4u::Host* Actor::get_host() const
@@ -186,8 +205,8 @@ aid_t Actor::get_ppid() const
 
 void Actor::suspend()
 {
-  auto issuer = SIMIX_process_self();
-  auto target = pimpl_;
+  kernel::actor::ActorImpl* issuer = kernel::actor::ActorImpl::self();
+  kernel::actor::ActorImpl* target = pimpl_;
   s4u::Actor::on_suspend(*this);
   kernel::actor::simcall_blocking<void>([issuer, target]() {
     target->suspend();
@@ -220,42 +239,26 @@ double Actor::get_kill_time()
   return pimpl_->get_kill_time();
 }
 
-void Actor::kill(aid_t pid) // deprecated
-{
-  kernel::actor::ActorImpl* killer = SIMIX_process_self();
-  kernel::actor::ActorImpl* victim = SIMIX_process_from_PID(pid);
-  if (victim != nullptr) {
-    kernel::actor::simcall([killer, victim] { killer->kill(victim); });
-  } else {
-    std::ostringstream oss;
-    oss << "kill: (" << pid << ") - No such actor" << std::endl;
-    throw std::runtime_error(oss.str());
-  }
-}
-
 void Actor::kill()
 {
-  kernel::actor::ActorImpl* process = SIMIX_process_self();
-  kernel::actor::simcall([this, process] {
-    xbt_assert(pimpl_ != simix_global->maestro_process, "Killing maestro is a rather bad idea");
-    process->kill(pimpl_);
-  });
+  kernel::actor::ActorImpl* self = kernel::actor::ActorImpl::self();
+  kernel::actor::simcall([this, self] { self->kill(pimpl_); });
 }
 
 // ***** Static functions *****
 
 ActorPtr Actor::by_pid(aid_t pid)
 {
-  kernel::actor::ActorImpl* process = SIMIX_process_from_PID(pid);
-  if (process != nullptr)
-    return process->iface();
+  kernel::actor::ActorImpl* actor = SIMIX_process_from_PID(pid);
+  if (actor != nullptr)
+    return actor->iface();
   else
     return ActorPtr();
 }
 
 void Actor::kill_all()
 {
-  kernel::actor::ActorImpl* self = SIMIX_process_self();
+  kernel::actor::ActorImpl* self = kernel::actor::ActorImpl::self();
   kernel::actor::simcall([self] { self->kill_all(); });
 }
 
@@ -295,8 +298,7 @@ namespace this_actor {
  */
 bool is_maestro()
 {
-  kernel::actor::ActorImpl* process = SIMIX_process_self();
-  return process == nullptr || process == simix_global->maestro_process;
+  return SIMIX_is_maestro();
 }
 
 void sleep_for(double duration)
@@ -304,7 +306,7 @@ void sleep_for(double duration)
   xbt_assert(std::isfinite(duration), "duration is not finite!");
 
   if (duration > 0) {
-    kernel::actor::ActorImpl* issuer = SIMIX_process_self();
+    kernel::actor::ActorImpl* issuer = kernel::actor::ActorImpl::self();
     Actor::on_sleep(*issuer->ciface());
 
     kernel::actor::simcall_blocking<void>([issuer, duration]() {
@@ -346,11 +348,22 @@ void execute(double flops, double priority)
 void parallel_execute(const std::vector<s4u::Host*>& hosts, const std::vector<double>& flops_amounts,
                       const std::vector<double>& bytes_amounts)
 {
-  parallel_execute(hosts, flops_amounts, bytes_amounts, -1);
+  exec_init(hosts, flops_amounts, bytes_amounts)->wait();
 }
 
 void parallel_execute(const std::vector<s4u::Host*>& hosts, const std::vector<double>& flops_amounts,
-                      const std::vector<double>& bytes_amounts, double timeout)
+                      const std::vector<double>& bytes_amounts, double timeout) // XBT_ATTRIB_DEPRECATED_v329
+{
+  exec_init(hosts, flops_amounts, bytes_amounts)->wait_for(timeout);
+}
+
+ExecPtr exec_init(double flops_amount)
+{
+  return ExecPtr(new ExecSeq(get_host(), flops_amount));
+}
+
+ExecPtr exec_init(const std::vector<s4u::Host*>& hosts, const std::vector<double>& flops_amounts,
+                  const std::vector<double>& bytes_amounts)
 {
   xbt_assert(hosts.size() > 0, "Your parallel executions must span over at least one host.");
   xbt_assert(hosts.size() == flops_amounts.size() || flops_amounts.empty(),
@@ -372,38 +385,6 @@ void parallel_execute(const std::vector<s4u::Host*>& hosts, const std::vector<do
   xbt_assert(std::all_of(bytes_amounts.begin(), bytes_amounts.end(), [](double elm) { return std::isfinite(elm); }),
              "flops_amounts comprises infinite values!");
 
-  exec_init(hosts, flops_amounts, bytes_amounts)->set_timeout(timeout)->wait();
-}
-
-// deprecated
-void parallel_execute(int host_nb, s4u::Host* const* host_list, const double* flops_amount, const double* bytes_amount,
-                      double timeout)
-{
-  smx_activity_t s =
-      simcall_execution_parallel_start("", host_nb, host_list, flops_amount, bytes_amount, /* rate */ -1, timeout);
-  simcall_execution_wait(s);
-  delete[] flops_amount;
-  delete[] bytes_amount;
-}
-
-// deprecated
-void parallel_execute(int host_nb, s4u::Host* const* host_list, const double* flops_amount, const double* bytes_amount)
-{
-  smx_activity_t s = simcall_execution_parallel_start("", host_nb, host_list, flops_amount, bytes_amount,
-                                                      /* rate */ -1, /*timeout*/ -1);
-  simcall_execution_wait(s);
-  delete[] flops_amount;
-  delete[] bytes_amount;
-}
-
-ExecPtr exec_init(double flops_amount)
-{
-  return ExecPtr(new ExecSeq(get_host(), flops_amount));
-}
-
-ExecPtr exec_init(const std::vector<s4u::Host*>& hosts, const std::vector<double>& flops_amounts,
-                  const std::vector<double>& bytes_amounts)
-{
   return ExecPtr(new ExecPar(hosts, flops_amounts, bytes_amounts));
 }
 
@@ -416,66 +397,58 @@ ExecPtr exec_async(double flops)
 
 aid_t get_pid()
 {
-  return SIMIX_process_self()->get_pid();
+  return simgrid::kernel::actor::ActorImpl::self()->get_pid();
 }
 
 aid_t get_ppid()
 {
-  return SIMIX_process_self()->get_ppid();
+  return simgrid::kernel::actor::ActorImpl::self()->get_ppid();
 }
 
 std::string get_name()
 {
-  return SIMIX_process_self()->get_name();
+  return simgrid::kernel::actor::ActorImpl::self()->get_name();
 }
 
 const char* get_cname()
 {
-  return SIMIX_process_self()->get_cname();
+  return simgrid::kernel::actor::ActorImpl::self()->get_cname();
 }
 
 Host* get_host()
 {
-  return SIMIX_process_self()->get_host();
+  return simgrid::kernel::actor::ActorImpl::self()->get_host();
 }
 
 void suspend()
 {
-  kernel::actor::ActorImpl* self = SIMIX_process_self();
+  kernel::actor::ActorImpl* self = simgrid::kernel::actor::ActorImpl::self();
   s4u::Actor::on_suspend(*self->ciface());
   kernel::actor::simcall_blocking<void>([self] { self->suspend(); });
 }
 
-void resume()
-{
-  kernel::actor::ActorImpl* self = SIMIX_process_self();
-  kernel::actor::simcall([self] { self->resume(); });
-  Actor::on_resume(*self->ciface());
-}
-
 void exit()
 {
-  kernel::actor::ActorImpl* self = SIMIX_process_self();
+  kernel::actor::ActorImpl* self = simgrid::kernel::actor::ActorImpl::self();
   simgrid::kernel::actor::simcall([self] { self->exit(); });
 }
 
 void on_exit(const std::function<void(bool)>& fun)
 {
-  SIMIX_process_self()->iface()->on_exit(fun);
-}
-
-void on_exit(const std::function<void(int, void*)>& fun, void* data) /* deprecated */
-{
-  SIMIX_process_self()->iface()->on_exit([fun, data](bool exit) { fun(exit, data); });
+  simgrid::kernel::actor::ActorImpl::self()->iface()->on_exit(fun);
 }
 
 /** @brief Moves the current actor to another host
  *
  * @see simgrid::s4u::Actor::migrate() for more information
  */
-void migrate(Host* new_host)
+void set_host(Host* new_host)
 {
-  SIMIX_process_self()->iface()->migrate(new_host);
+  simgrid::kernel::actor::ActorImpl::self()->iface()->set_host(new_host);
+}
+void migrate(Host* new_host) // deprecated
+{
+  set_host(new_host);
 }
 
 } // namespace this_actor
@@ -484,12 +457,25 @@ void migrate(Host* new_host)
 
 /* **************************** Public C interface *************************** */
 
+sg_actor_t sg_actor_init(const char* name, sg_host_t host)
+{
+  return simgrid::s4u::Actor::init(name, host).get();
+}
+
+void sg_actor_start(sg_actor_t actor, xbt_main_func_t code, int argc, char** argv)
+{
+  simgrid::simix::ActorCode function;
+  if (code)
+    function = simgrid::xbt::wrap_main(code, argc, static_cast<const char* const*>(argv));
+  actor->start(std::move(function));
+}
+
 /** @ingroup m_actor_management
  * @brief Returns the process ID of @a actor.
  *
  * This function checks whether @a actor is a valid pointer and return its PID (or 0 in case of problem).
  */
-aid_t sg_actor_get_PID(sg_actor_t actor)
+aid_t sg_actor_get_PID(const_sg_actor_t actor)
 {
   /* Do not raise an exception here: this function is called by the logs
    * and the exceptions, so it would be called back again and again */
@@ -504,7 +490,7 @@ aid_t sg_actor_get_PID(sg_actor_t actor)
  * This function checks whether @a actor is a valid pointer and return its parent's PID.
  * Returns -1 if the actor has not been created by any other actor.
  */
-aid_t sg_actor_get_PPID(sg_actor_t actor)
+aid_t sg_actor_get_PPID(const_sg_actor_t actor)
 {
   return actor->get_ppid();
 }
@@ -525,12 +511,12 @@ sg_actor_t sg_actor_by_PID(aid_t pid)
 /** @ingroup m_actor_management
  * @brief Return the name of an actor.
  */
-const char* sg_actor_get_name(sg_actor_t actor)
+const char* sg_actor_get_name(const_sg_actor_t actor)
 {
   return actor->get_cname();
 }
 
-sg_host_t sg_actor_get_host(sg_actor_t actor)
+sg_host_t sg_actor_get_host(const_sg_actor_t actor)
 {
   return actor->get_host();
 }
@@ -542,7 +528,7 @@ sg_host_t sg_actor_get_host(sg_actor_t actor)
  * @param name a property name
  * @return value of a property (or nullptr if the property is not set)
  */
-const char* sg_actor_get_property_value(sg_actor_t actor, const char* name)
+const char* sg_actor_get_property_value(const_sg_actor_t actor, const char* name)
 {
   return actor->get_property(name);
 }
@@ -552,7 +538,7 @@ const char* sg_actor_get_property_value(sg_actor_t actor, const char* name)
  *
  * This function returns all the parameters associated with an actor
  */
-xbt_dict_t sg_actor_get_properties(sg_actor_t actor)
+xbt_dict_t sg_actor_get_properties(const_sg_actor_t actor)
 {
   xbt_assert(actor != nullptr, "Invalid parameter: First argument must not be nullptr");
   xbt_dict_t as_dict                        = xbt_dict_new_homogeneous(xbt_free_f);
@@ -560,7 +546,7 @@ xbt_dict_t sg_actor_get_properties(sg_actor_t actor)
   if (props == nullptr)
     return nullptr;
   for (auto const& kv : *props) {
-    xbt_dict_set(as_dict, kv.first.c_str(), xbt_strdup(kv.second.c_str()), nullptr);
+    xbt_dict_set(as_dict, kv.first.c_str(), xbt_strdup(kv.second.c_str()));
   }
   return as_dict;
 }
@@ -629,9 +615,13 @@ void sg_actor_daemonize(sg_actor_t actor)
  *
  * This function changes the value of the #sg_host_t on  which @a actor is running.
  */
-void sg_actor_migrate(sg_actor_t process, sg_host_t host)
+void sg_actor_set_host(sg_actor_t actor, sg_host_t host)
 {
-  process->migrate(host);
+  actor->set_host(host);
+}
+void sg_actor_migrate(sg_actor_t process, sg_host_t host) // deprecated
+{
+  process->set_host(host);
 }
 
 /** @ingroup m_actor_management
@@ -720,6 +710,16 @@ const char* sg_actor_self_get_name()
   return simgrid::s4u::this_actor::get_cname();
 }
 
+void* sg_actor_self_data()
+{
+  return simgrid::s4u::Actor::self()->get_data();
+}
+
+void sg_actor_self_data_set(void* userdata)
+{
+  simgrid::s4u::Actor::self()->set_data(userdata);
+}
+
 sg_actor_t sg_actor_self()
 {
   return simgrid::s4u::Actor::self();
@@ -731,18 +731,18 @@ void sg_actor_self_execute(double flops)
 }
 
 /** @brief Take an extra reference on that actor to prevent it to be garbage-collected */
-void sg_actor_ref(sg_actor_t actor)
+void sg_actor_ref(const_sg_actor_t actor)
 {
   intrusive_ptr_add_ref(actor);
 }
 /** @brief Release a reference on that actor so that it can get be garbage-collected */
-void sg_actor_unref(sg_actor_t actor)
+void sg_actor_unref(const_sg_actor_t actor)
 {
   intrusive_ptr_release(actor);
 }
 
 /** @brief Return the user data of a #sg_actor_t */
-void* sg_actor_data(sg_actor_t actor)
+void* sg_actor_data(const_sg_actor_t actor)
 {
   return actor->get_data();
 }
