@@ -1,4 +1,4 @@
-/* Copyright (c) 2009-2019. The SimGrid Team.
+/* Copyright (c) 2009-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -31,7 +31,7 @@ static void dot_task_p_free(void *task) {
  * The size attribute of a node describes:
  *   - for a compute task: the amount of flops to execute
  *   - for a communication task : the amount of bytes to transfer
- * If this attribute is ommited, the default value is zero.
+ * If this attribute is omitted, the default value is zero.
  */
 xbt_dynar_t SD_dotload(const char *filename) {
   return SD_dotload_generic(filename, true, false);
@@ -99,11 +99,11 @@ xbt_dynar_t SD_dotload_generic(const char* filename, bool sequential, bool sched
           if (comp != computers.end()) {
             computer = comp->second;
           } else {
-            computer = new std::vector<SD_task_t>;
+            computer = new std::vector<SD_task_t>();
             computers.insert({char_performer, computer});
           }
           if (static_cast<unsigned int>(order) < computer->size()) {
-            SD_task_t task_test = computer->at(order);
+            const s_SD_task_t* task_test = computer->at(order);
             if (task_test && task_test != task) {
               /* the user gave the same order to several tasks */
               schedule_success = false;
@@ -153,8 +153,8 @@ xbt_dynar_t SD_dotload_generic(const char* filename, bool sequential, bool sched
     std::sort(edges.begin(), edges.end(), [](const Agedge_t* a, const Agedge_t* b) { return AGSEQ(a) < AGSEQ(b); });
 
     for (Agedge_t* edge : edges) {
-      char *src_name=agnameof(agtail(edge));
-      char *dst_name=agnameof(aghead(edge));
+      const char* src_name = agnameof(agtail(edge));
+      const char* dst_name = agnameof(aghead(edge));
       double size = atof(agget(edge, (char *) "size"));
 
       SD_task_t src = jobs.at(src_name);
