@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2006-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -33,7 +33,6 @@ std::set<SD_task_t>* simulate(double how_long){
   /* main loop */
   while (elapsed_time >= 0 && (how_long < 0 || 0.00001 < (how_long - total_time)) &&
          not sd_global->watch_point_reached) {
-
     XBT_DEBUG("Total time: %f", total_time);
 
     elapsed_time = surf_solve(how_long > 0 ? surf_get_clock() + how_long - total_time: -1.0);
@@ -43,7 +42,7 @@ std::set<SD_task_t>* simulate(double how_long){
 
     /* let's see which tasks are done */
     for (auto const& model : all_existing_models) {
-      simgrid::kernel::resource::Action* action = model->extract_done_action();
+      const simgrid::kernel::resource::Action* action = model->extract_done_action();
       while (action != nullptr && action->get_data() != nullptr) {
         SD_task_t task = static_cast<SD_task_t>(action->get_data());
         XBT_VERB("Task '%s' done", SD_task_get_name(task));
@@ -214,7 +213,7 @@ void SD_simulate(double how_long)
 
 void SD_simulate_with_update(double how_long, xbt_dynar_t changed_tasks_dynar)
 {
-  std::set<SD_task_t> *changed_tasks = simgrid::sd::simulate(how_long);
+  const std::set<SD_task_t>* changed_tasks = simgrid::sd::simulate(how_long);
   for (auto const& task : *changed_tasks)
     xbt_dynar_push(changed_tasks_dynar, &task);
 }
