@@ -1,4 +1,4 @@
-/* Copyright (c) 2015-2019. The SimGrid Team.
+/* Copyright (c) 2015-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -35,7 +35,7 @@ typename C::mapped_type const* find_map_ptr(C const& c, K const& k)
     return &i->second;
 }
 
-}
-}
+} // namespace util
+} // namespace simgrid
 
 #endif
