@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -8,13 +8,37 @@
 #include "smpi_file.hpp"
 #include "smpi_datatype.hpp"
 
+XBT_LOG_EXTERNAL_DEFAULT_CATEGORY(smpi_pmpi);
+#define CHECK_RDONLY(fh)                                                                                               \
+  if ((fh)->flags() & MPI_MODE_RDONLY)                                                                                 \
+    return MPI_ERR_AMODE;
+#define CHECK_WRONLY(fh)                                                                                               \
+  if ((fh)->flags() & MPI_MODE_WRONLY)                                                                                 \
+    return MPI_ERR_AMODE;
+#define PASS_ZEROCOUNT(count)                                                                                          \
+  if ((count) == 0) {                                                                                                  \
+    status->count = 0;                                                                                                 \
+    return MPI_SUCCESS;                                                                                                \
+  }
+
+#define CHECK_FILE_INPUTS                                                                                              \
+  CHECK_FILE(1, fh)                                                                                                    \
+  CHECK_BUFFER(2, buf, count)                                                                                          \
+  CHECK_COUNT(3, count)                                                                                                \
+  CHECK_TYPE(4, datatype)                                                                                              \
+
+#define CHECK_FILE_INPUT_OFFSET                                                                                        \
+  CHECK_FILE(1, fh)                                                                                                    \
+  CHECK_BUFFER(2, buf, count)                                                                                          \
+  CHECK_OFFSET(3, offset)                                                                                                 \
+  CHECK_COUNT(4, count)                                                                                                \
+  CHECK_TYPE(5, datatype)                                                                                              \
+
 extern MPI_Errhandler SMPI_default_File_Errhandler;
 
 int PMPI_File_open(MPI_Comm comm, const char *filename, int amode, MPI_Info info, MPI_File *fh){
-  if (comm == MPI_COMM_NULL)
-    return MPI_ERR_COMM;
-  if (filename == nullptr)
-    return MPI_ERR_FILE;
+  CHECK_COMM(1)
+  CHECK_NULL(2, MPI_ERR_FILE, filename)
   if (amode < 0)
     return MPI_ERR_AMODE;
   smpi_bench_end();
@@ -30,66 +54,33 @@ int PMPI_File_open(MPI_Comm comm, const char *filename, int amode, MPI_Info info
 }
 
 int PMPI_File_close(MPI_File *fh){
-  if (fh==nullptr)
-    return MPI_ERR_ARG;
+  CHECK_NULL(2, MPI_ERR_ARG, fh)
   smpi_bench_end();
   int ret = simgrid::smpi::File::close(fh);
   *fh = MPI_FILE_NULL;
   smpi_bench_begin();
   return ret;
 }
-#define CHECK_FILE(fh)                                                                                                 \
-  if ((fh) == MPI_FILE_NULL)                                                                                           \
-    return MPI_ERR_FILE;
-#define CHECK_BUFFER(buf, count)                                                                                       \
-  if ((buf) == nullptr && (count) > 0)                                                                                 \
-    return MPI_ERR_BUFFER;
-#define CHECK_COUNT(count)                                                                                             \
-  if ((count) < 0)                                                                                                     \
-    return MPI_ERR_COUNT;
-#define CHECK_OFFSET(offset)                                                                                           \
-  if ((offset) < 0)                                                                                                    \
-    return MPI_ERR_DISP;
-#define CHECK_DATATYPE(datatype, count)                                                                                \
-  if ((datatype) == MPI_DATATYPE_NULL && (count) > 0)                                                                  \
-    return MPI_ERR_TYPE;
-#define CHECK_STATUS(status)                                                                                           \
-  if ((status) == nullptr)                                                                                             \
-    return MPI_ERR_ARG;
-#define CHECK_FLAGS(fh)                                                                                                \
-  if ((fh)->flags() & MPI_MODE_SEQUENTIAL)                                                                             \
-    return MPI_ERR_AMODE;
-#define CHECK_RDONLY(fh)                                                                                               \
-  if ((fh)->flags() & MPI_MODE_RDONLY)                                                                                 \
-    return MPI_ERR_AMODE;
-
-#define PASS_ZEROCOUNT(count)                                                                                          \
-  if ((count) == 0) {                                                                                                  \
-    status->count = 0;                                                                                                 \
-    return MPI_SUCCESS;                                                                                                \
-  }
 
 int PMPI_File_seek(MPI_File fh, MPI_Offset offset, int whence){
-  CHECK_FILE(fh);
+  CHECK_FILE(1, fh)
   smpi_bench_end();
   int ret = fh->seek(offset,whence);
   smpi_bench_begin();
   return ret;
-
 }
 
 int PMPI_File_seek_shared(MPI_File fh, MPI_Offset offset, int whence){
-  CHECK_FILE(fh)
+  CHECK_FILE(1, fh)
   smpi_bench_end();
   int ret = fh->seek_shared(offset,whence);
   smpi_bench_begin();
   return ret;
-
 }
 
 int PMPI_File_get_position(MPI_File fh, MPI_Offset* offset){
-  if (offset==nullptr)
-    return MPI_ERR_DISP;
+  CHECK_FILE(1, fh)
+  CHECK_NULL(2, MPI_ERR_DISP, offset)
   smpi_bench_end();
   int ret = fh->get_position(offset);
   smpi_bench_begin();
@@ -97,9 +88,8 @@ int PMPI_File_get_position(MPI_File fh, MPI_Offset* offset){
 }
 
 int PMPI_File_get_position_shared(MPI_File fh, MPI_Offset* offset){
-  CHECK_FILE(fh)
-  if (offset==nullptr)
-    return MPI_ERR_DISP;
+  CHECK_FILE(1, fh)
+  CHECK_NULL(2, MPI_ERR_DISP, offset)
   smpi_bench_end();
   int ret = fh->get_position_shared(offset);
   smpi_bench_begin();
@@ -107,12 +97,8 @@ int PMPI_File_get_position_shared(MPI_File fh, MPI_Offset* offset){
 }
 
 int PMPI_File_read(MPI_File fh, void *buf, int count,MPI_Datatype datatype, MPI_Status *status){
-  CHECK_FILE(fh)
-  CHECK_BUFFER(buf, count)
-  CHECK_COUNT(count)
-  CHECK_DATATYPE(datatype, count)
-  CHECK_STATUS(status)
-  CHECK_FLAGS(fh)
+  CHECK_FILE_INPUTS
+  CHECK_WRONLY(fh)
   PASS_ZEROCOUNT(count)
   smpi_bench_end();
   int rank_traced = simgrid::s4u::this_actor::get_pid();
@@ -124,12 +110,8 @@ int PMPI_File_read(MPI_File fh, void *buf, int count,MPI_Datatype datatype, MPI_
 }
 
 int PMPI_File_read_shared(MPI_File fh, void *buf, int count,MPI_Datatype datatype, MPI_Status *status){
-  CHECK_FILE(fh)
-  CHECK_BUFFER(buf, count)
-  CHECK_COUNT(count)
-  CHECK_DATATYPE(datatype, count)
-  CHECK_STATUS(status)
-  CHECK_FLAGS(fh)
+  CHECK_FILE_INPUTS
+  CHECK_WRONLY(fh)
   PASS_ZEROCOUNT(count)
   smpi_bench_end();
   int rank_traced = simgrid::s4u::this_actor::get_pid();
@@ -142,12 +124,7 @@ int PMPI_File_read_shared(MPI_File fh, void *buf, int count,MPI_Datatype datatyp
 }
 
 int PMPI_File_write(MPI_File fh, const void *buf, int count,MPI_Datatype datatype, MPI_Status *status){
-  CHECK_FILE(fh)
-  CHECK_BUFFER(buf, count)
-  CHECK_COUNT(count)
-  CHECK_DATATYPE(datatype, count)
-  CHECK_STATUS(status)
-  CHECK_FLAGS(fh)
+  CHECK_FILE_INPUTS
   CHECK_RDONLY(fh)
   PASS_ZEROCOUNT(count)
   smpi_bench_end();
@@ -160,12 +137,7 @@ int PMPI_File_write(MPI_File fh, const void *buf, int count,MPI_Datatype datatyp
 }
 
 int PMPI_File_write_shared(MPI_File fh, const void *buf, int count,MPI_Datatype datatype, MPI_Status *status){
-  CHECK_FILE(fh)
-  CHECK_BUFFER(buf, count)
-  CHECK_COUNT(count)
-  CHECK_DATATYPE(datatype, count)
-  CHECK_STATUS(status)
-  CHECK_FLAGS(fh)
+  CHECK_FILE_INPUTS
   CHECK_RDONLY(fh)
   PASS_ZEROCOUNT(count)
   smpi_bench_end();
@@ -179,12 +151,8 @@ int PMPI_File_write_shared(MPI_File fh, const void *buf, int count,MPI_Datatype
 }
 
 int PMPI_File_read_all(MPI_File fh, void *buf, int count,MPI_Datatype datatype, MPI_Status *status){
-  CHECK_FILE(fh)
-  CHECK_BUFFER(buf, count)
-  CHECK_COUNT(count)
-  CHECK_DATATYPE(datatype, count)
-  CHECK_STATUS(status)
-  CHECK_FLAGS(fh)
+  CHECK_FILE_INPUTS
+  CHECK_WRONLY(fh)
   smpi_bench_end();
   int rank_traced = simgrid::s4u::this_actor::get_pid();
   TRACE_smpi_comm_in(rank_traced, __func__, new simgrid::instr::CpuTIData("IO - read_all", count * datatype->size()));
@@ -195,12 +163,8 @@ int PMPI_File_read_all(MPI_File fh, void *buf, int count,MPI_Datatype datatype,
 }
 
 int PMPI_File_read_ordered(MPI_File fh, void *buf, int count,MPI_Datatype datatype, MPI_Status *status){
-  CHECK_FILE(fh)
-  CHECK_BUFFER(buf, count)
-  CHECK_COUNT(count)
-  CHECK_DATATYPE(datatype, count)
-  CHECK_STATUS(status)
-  CHECK_FLAGS(fh)
+  CHECK_FILE_INPUTS
+  CHECK_WRONLY(fh)
   smpi_bench_end();
   int rank_traced = simgrid::s4u::this_actor::get_pid();
   TRACE_smpi_comm_in(rank_traced, __func__,
@@ -212,12 +176,7 @@ int PMPI_File_read_ordered(MPI_File fh, void *buf, int count,MPI_Datatype dataty
 }
 
 int PMPI_File_write_all(MPI_File fh, const void *buf, int count,MPI_Datatype datatype, MPI_Status *status){
-  CHECK_FILE(fh)
-  CHECK_BUFFER(buf, count)
-  CHECK_COUNT(count)
-  CHECK_DATATYPE(datatype, count)
-  CHECK_STATUS(status)
-  CHECK_FLAGS(fh)
+  CHECK_FILE_INPUTS
   CHECK_RDONLY(fh)
   smpi_bench_end();
   int rank_traced = simgrid::s4u::this_actor::get_pid();
@@ -229,12 +188,7 @@ int PMPI_File_write_all(MPI_File fh, const void *buf, int count,MPI_Datatype dat
 }
 
 int PMPI_File_write_ordered(MPI_File fh, const void *buf, int count,MPI_Datatype datatype, MPI_Status *status){
-  CHECK_FILE(fh)
-  CHECK_BUFFER(buf, count)
-  CHECK_COUNT(count)
-  CHECK_DATATYPE(datatype, count)
-  CHECK_STATUS(status)
-  CHECK_FLAGS(fh)
+  CHECK_FILE_INPUTS
   CHECK_RDONLY(fh)
   smpi_bench_end();
   int rank_traced = simgrid::s4u::this_actor::get_pid();
@@ -247,13 +201,8 @@ int PMPI_File_write_ordered(MPI_File fh, const void *buf, int count,MPI_Datatype
 }
 
 int PMPI_File_read_at(MPI_File fh, MPI_Offset offset, void *buf, int count,MPI_Datatype datatype, MPI_Status *status){
-  CHECK_FILE(fh)
-  CHECK_BUFFER(buf, count)
-  CHECK_OFFSET(offset)
-  CHECK_COUNT(count)
-  CHECK_DATATYPE(datatype, count)
-  CHECK_STATUS(status)
-  CHECK_FLAGS(fh)
+  CHECK_FILE_INPUTS
+  CHECK_WRONLY(fh)
   PASS_ZEROCOUNT(count);
   smpi_bench_end();
   int rank_traced = simgrid::s4u::this_actor::get_pid();
@@ -268,13 +217,8 @@ int PMPI_File_read_at(MPI_File fh, MPI_Offset offset, void *buf, int count,MPI_D
 }
 
 int PMPI_File_read_at_all(MPI_File fh, MPI_Offset offset, void *buf, int count,MPI_Datatype datatype, MPI_Status *status){
-  CHECK_FILE(fh)
-  CHECK_BUFFER(buf, count)
-  CHECK_OFFSET(offset)
-  CHECK_COUNT(count)
-  CHECK_DATATYPE(datatype, count)
-  CHECK_STATUS(status)
-  CHECK_FLAGS(fh)
+  CHECK_FILE_INPUT_OFFSET
+  CHECK_WRONLY(fh)
   smpi_bench_end();
   int rank_traced = simgrid::s4u::this_actor::get_pid();
   TRACE_smpi_comm_in(rank_traced, __func__,
@@ -289,13 +233,7 @@ int PMPI_File_read_at_all(MPI_File fh, MPI_Offset offset, void *buf, int count,M
 }
 
 int PMPI_File_write_at(MPI_File fh, MPI_Offset offset, const void *buf, int count,MPI_Datatype datatype, MPI_Status *status){
-  CHECK_FILE(fh)
-  CHECK_BUFFER(buf, count)
-  CHECK_OFFSET(offset)
-  CHECK_COUNT(count)
-  CHECK_DATATYPE(datatype, count)
-  CHECK_STATUS(status)
-  CHECK_FLAGS(fh)
+  CHECK_FILE_INPUT_OFFSET
   CHECK_RDONLY(fh)
   PASS_ZEROCOUNT(count);
   smpi_bench_end();
@@ -311,13 +249,7 @@ int PMPI_File_write_at(MPI_File fh, MPI_Offset offset, const void *buf, int coun
 }
 
 int PMPI_File_write_at_all(MPI_File fh, MPI_Offset offset, const void *buf, int count,MPI_Datatype datatype, MPI_Status *status){
-  CHECK_FILE(fh)
-  CHECK_BUFFER(buf, count)
-  CHECK_OFFSET(offset)
-  CHECK_COUNT(count)
-  CHECK_DATATYPE(datatype, count)
-  CHECK_STATUS(status)
-  CHECK_FLAGS(fh)
+  CHECK_FILE_INPUT_OFFSET
   CHECK_RDONLY(fh)
   smpi_bench_end();
   int rank_traced = simgrid::s4u::this_actor::get_pid();
@@ -341,44 +273,67 @@ int PMPI_File_delete(const char *filename, MPI_Info info){
   return ret;
 }
 
+int PMPI_File_set_view(MPI_File fh, MPI_Offset disp, MPI_Datatype etype, MPI_Datatype filetype, const char *datarep, MPI_Info info){
+  CHECK_FILE(1, fh)
+  if(not ((fh->flags() & MPI_MODE_SEQUENTIAL) && (disp == MPI_DISPLACEMENT_CURRENT)))
+    CHECK_OFFSET(2, disp)
+  CHECK_TYPE(3, etype)
+  CHECK_TYPE(4, filetype)
+  smpi_bench_end();
+  int ret = fh->set_view(disp, etype, filetype, datarep, info);
+  smpi_bench_begin();
+  return ret;
+}
+
+int PMPI_File_get_view(MPI_File fh, MPI_Offset *disp, MPI_Datatype *etype, MPI_Datatype *filetype, char *datarep){
+  CHECK_FILE(1, fh)
+  CHECK_NULL(2, MPI_ERR_ARG, disp)
+  CHECK_NULL(3, MPI_ERR_ARG, etype)
+  CHECK_NULL(4, MPI_ERR_ARG, filetype)
+  smpi_bench_end();
+  int ret = fh->get_view(disp, etype, filetype, datarep);
+  smpi_bench_begin();
+  return ret;
+}
+
 int PMPI_File_get_info(MPI_File  fh, MPI_Info* info)
 {
-  CHECK_FILE(fh)
+  CHECK_FILE(1, fh)
   *info = fh->info();
   return MPI_SUCCESS;
 }
 
 int PMPI_File_set_info(MPI_File  fh, MPI_Info info)
 {
-  CHECK_FILE(fh)
+  CHECK_FILE(1, fh)
   fh->set_info(info);
   return MPI_SUCCESS;
 }
 
 int PMPI_File_get_size(MPI_File  fh, MPI_Offset* size)
 {
-  CHECK_FILE(fh)
+  CHECK_FILE(1, fh)
   *size = fh->size();
   return MPI_SUCCESS;
 }
 
 int PMPI_File_get_amode(MPI_File  fh, int* amode)
 {
-  CHECK_FILE(fh)
+  CHECK_FILE(1, fh)
   *amode = fh->flags();
   return MPI_SUCCESS;
 }
 
 int PMPI_File_get_group(MPI_File  fh, MPI_Group* group)
 {
-  CHECK_FILE(fh)
+  CHECK_FILE(1, fh)
   *group = fh->comm()->group();
   return MPI_SUCCESS;
 }
 
 int PMPI_File_sync(MPI_File  fh)
 {
-  CHECK_FILE(fh)
+  CHECK_FILE(1, fh)
   fh->sync();
   return MPI_SUCCESS;
 }
@@ -414,6 +369,8 @@ int PMPI_File_call_errhandler(MPI_File file,int errorcode){
   if (file == nullptr) {
     return MPI_ERR_WIN;
   }
-  file->errhandler()->call(file, errorcode);
+  MPI_Errhandler err = file->errhandler();
+  err->call(file, errorcode);
+  simgrid::smpi::Errhandler::unref(err);
   return MPI_SUCCESS;
 }
