@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -49,7 +49,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 *****************************************************************************/
 
-
 /*****************************************************************************
  * Function: allgather_bruck
  * return: int
@@ -63,7 +62,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *   comm: communication
  * Descrp: Function realizes the allgather operation using the bruck
  *         algorithm.
- * Auther: MPICH
+ * Author: MPICH
  * Comment: Original bruck algorithm from MPICH is slightly modified by
  *          Ahmad Faraj.
  ****************************************************************************/
@@ -73,10 +72,10 @@ namespace smpi{
 
 
 
-int Coll_allgather_bruck::allgather(const void *send_buff, int send_count,
-                                    MPI_Datatype send_type, void *recv_buff,
-                                    int recv_count, MPI_Datatype recv_type,
-                                    MPI_Comm comm)
+int allgather__bruck(const void *send_buff, int send_count,
+                     MPI_Datatype send_type, void *recv_buff,
+                     int recv_count, MPI_Datatype recv_type,
+                     MPI_Comm comm)
 {
   // MPI variables
   MPI_Status status;
