@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -28,11 +28,10 @@
 namespace simgrid{
 namespace smpi{
 
-int
-Coll_allgatherv_mpich_ring::allgatherv(const void *sendbuf, int sendcount,
-    MPI_Datatype send_type, void *recvbuf,
-    const int *recvcounts, const int *displs, MPI_Datatype recvtype,
-    MPI_Comm comm)
+int allgatherv__mpich_ring(const void *sendbuf, int sendcount,
+                           MPI_Datatype send_type, void *recvbuf,
+                           const int *recvcounts, const int *displs, MPI_Datatype recvtype,
+                           MPI_Comm comm)
 {
 
   char * sbuf = NULL, * rbuf = NULL;
