@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -24,18 +24,18 @@
 #include "../colls_private.hpp"
 #include <algorithm>
 
-namespace simgrid{
-namespace smpi{
-int Coll_allreduce_mvapich2_rs::allreduce(const void *sendbuf,
-                            void *recvbuf,
-                            int count,
-                            MPI_Datatype datatype,
-                            MPI_Op op, MPI_Comm comm)
+namespace simgrid {
+namespace smpi {
+int allreduce__mvapich2_rs(const void *sendbuf,
+                           void *recvbuf,
+                           int count,
+                           MPI_Datatype datatype,
+                           MPI_Op op, MPI_Comm comm)
 {
     int mpi_errno = MPI_SUCCESS;
     int newrank = 0;
     int mask, pof2, i, send_idx, recv_idx, last_idx, send_cnt;
-    int dst, is_commutative, rem, newdst, recv_cnt;
+    int dst, rem, newdst, recv_cnt;
     MPI_Aint true_lb, true_extent, extent;
 
     if (count == 0) {
@@ -47,7 +47,7 @@ int Coll_allreduce_mvapich2_rs::allreduce(const void *sendbuf,
     int comm_size =  comm->size();
     int rank = comm->rank();
 
-    is_commutative = (op==MPI_OP_NULL || op->is_commutative());
+    bool is_commutative = (op == MPI_OP_NULL || op->is_commutative());
 
     /* need to allocate temporary buffer to store incoming data */
     datatype->extent(&true_lb, &true_extent);
@@ -84,7 +84,7 @@ int Coll_allreduce_mvapich2_rs::allreduce(const void *sendbuf,
                                      COLL_TAG_ALLREDUCE, comm);
 
             /* temporarily set the rank to -1 so that this
-               process does not pariticipate in recursive
+               process does not participate in recursive
                doubling */
             newrank = -1;
         } else {
