@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -8,8 +8,8 @@
 //#include <star-reduction.c>
 namespace simgrid{
 namespace smpi{
-int Coll_allreduce_rdb::allreduce(const void *sbuff, void *rbuff, int count,
-                                  MPI_Datatype dtype, MPI_Op op, MPI_Comm comm)
+int allreduce__rdb(const void *sbuff, void *rbuff, int count,
+                   MPI_Datatype dtype, MPI_Op op, MPI_Comm comm)
 {
   int nprocs, rank, tag = COLL_TAG_ALLREDUCE;
   int mask, dst, pof2, newrank, rem, newdst;
@@ -55,7 +55,7 @@ int Coll_allreduce_rdb::allreduce(const void *sbuff, void *rbuff, int count,
       Request::send(rbuff, count, dtype, rank + 1, tag, comm);
 
       // temporarily set the rank to -1 so that this
-      // process does not pariticipate in recursive
+      // process does not participate in recursive
       // doubling
       newrank = -1;
     } else                      // odd
@@ -99,7 +99,7 @@ int Coll_allreduce_rdb::allreduce(const void *sbuff, void *rbuff, int count,
       // recvbuf contains data accumulated so far
 
       // op is commutative OR the order is already right
-      // we assume it is commuttive op
+      // we assume it is commutative op
       //      if (op -> op_commute  || (dst < rank))
       if ((dst < rank)) {
         if(op!=MPI_OP_NULL) op->apply( tmp_buf, rbuff, &count, dtype);
