@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -6,14 +6,12 @@
 
 #include "../colls_private.hpp"
 /* IMPLEMENTED BY PITCH PATARASUK
-   Non-topoloty-specific (however, number of cores/node need to be changed)
+   Non-topology-specific (however, number of cores/node need to be changed)
    all-reduce operation designed for smp clusters
    It uses 2-layer communication: binomial for both intra-communication
    inter-communication
    The communication are done in a pipeline fashion */
 
-
-
 /* this is a default segment size for pipelining,
    but it is typically passed as a command line argument */
 int allreduce_smp_binomial_pipeline_segment_size = 4096;
@@ -40,10 +38,10 @@ This fucntion performs all-reduce operation as follow. ** in a pipeline fashion
 */
 namespace simgrid{
 namespace smpi{
-int Coll_allreduce_smp_binomial_pipeline::allreduce(const void *send_buf,
-                                                    void *recv_buf, int count,
-                                                    MPI_Datatype dtype,
-                                                    MPI_Op op, MPI_Comm comm)
+int allreduce__smp_binomial_pipeline(const void *send_buf,
+                                     void *recv_buf, int count,
+                                     MPI_Datatype dtype,
+                                     MPI_Op op, MPI_Comm comm)
 {
   int comm_size, rank;
   int tag = COLL_TAG_ALLREDUCE;
