@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -6,12 +6,11 @@
 
 #include "../colls_private.hpp"
 /* IMPLEMENTED BY PITCH PATARASUK
-   Non-topoloty-specific (however, number of cores/node need to be changed)
+   Non-topology-specific (however, number of cores/node need to be changed)
    all-reduce operation designed for smp clusters
    It uses 2-layer communication: binomial for intra-communication
    and rdb for inter-communication*/
 
-
 /* ** NOTE **
    Use -DMPICH2 if this code does not compile.
    MPICH1 code also work on MPICH2 on our cluster and the performance are similar.
@@ -28,9 +27,9 @@ This fucntion performs all-reduce operation as follow.
 */
 namespace simgrid{
 namespace smpi{
-int Coll_allreduce_smp_rdb::allreduce(const void *send_buf, void *recv_buf, int count,
-                                      MPI_Datatype dtype, MPI_Op op,
-                                      MPI_Comm comm)
+int allreduce__smp_rdb(const void *send_buf, void *recv_buf, int count,
+                       MPI_Datatype dtype, MPI_Op op,
+                       MPI_Comm comm)
 {
   int comm_size, rank;
   int tag = COLL_TAG_ALLREDUCE;
