@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -25,14 +25,14 @@
  * Descrp: Function works when P is power of two. In each phase of P - 1
            phases, nodes in pair communicate their data.
 
- * Auther: Ahmad Faraj
+ * Author: Ahmad Faraj
 
  ****************************************************************************/
 namespace simgrid{
 namespace smpi{
-int Coll_alltoall_pair_rma::alltoall(const void *send_buff, int send_count, MPI_Datatype send_type,
-                  void *recv_buff, int recv_count, MPI_Datatype recv_type,
-                  MPI_Comm comm)
+int alltoall__pair_rma(const void *send_buff, int send_count, MPI_Datatype send_type,
+                       void *recv_buff, int recv_count, MPI_Datatype recv_type,
+                       MPI_Comm comm)
 {
 
   MPI_Aint send_chunk, recv_chunk;
@@ -64,10 +64,10 @@ int Coll_alltoall_pair_rma::alltoall(const void *send_buff, int send_count, MPI_
 }
 
 
-int Coll_alltoall_pair::alltoall(const void *send_buff, int send_count,
-                                  MPI_Datatype send_type,
-                                  void *recv_buff, int recv_count,
-                                  MPI_Datatype recv_type, MPI_Comm comm)
+int alltoall__pair(const void *send_buff, int send_count,
+                   MPI_Datatype send_type,
+                   void *recv_buff, int recv_count,
+                   MPI_Datatype recv_type, MPI_Comm comm)
 {
 
   MPI_Aint send_chunk, recv_chunk;
@@ -81,7 +81,7 @@ int Coll_alltoall_pair::alltoall(const void *send_buff, int send_count,
   num_procs = comm->size();
 
   if((num_procs&(num_procs-1)))
-    THROWF(arg_error,0, "alltoall pair algorithm can't be used with non power of two number of processes ! ");
+    throw std::invalid_argument("alltoall pair algorithm can't be used with non power of two number of processes!");
 
   send_chunk = send_type->get_extent();
   recv_chunk = recv_type->get_extent();
