@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -22,16 +22,15 @@
 
  * Descrp: Function works in P - 1 steps. In step i, node j - i -> j -> j + i.
 
- * Auther: Ahmad Faraj
+ * Author: Ahmad Faraj
 
  ****************************************************************************/
-namespace simgrid{
-namespace smpi{
-int
-Coll_alltoall_ring::alltoall(const void *send_buff, int send_count,
-                              MPI_Datatype send_type, void *recv_buff,
-                              int recv_count, MPI_Datatype recv_type,
-                              MPI_Comm comm)
+namespace simgrid {
+namespace smpi {
+int alltoall__ring(const void *send_buff, int send_count,
+                   MPI_Datatype send_type, void *recv_buff,
+                   int recv_count, MPI_Datatype recv_type,
+                   MPI_Comm comm)
 {
   MPI_Status s;
   MPI_Aint send_chunk, recv_chunk;
