@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -15,10 +15,10 @@
  **/
 namespace simgrid{
 namespace smpi{
-int Coll_alltoallv_bruck::alltoallv(const void *sendbuf, const int *sendcounts, const int *senddisps,
-                                   MPI_Datatype sendtype, void *recvbuf,
-                                   const int *recvcounts,const int *recvdisps, MPI_Datatype recvtype,
-                                   MPI_Comm comm)
+int alltoallv__bruck(const void *sendbuf, const int *sendcounts, const int *senddisps,
+                     MPI_Datatype sendtype, void *recvbuf,
+                     const int *recvcounts,const int *recvdisps, MPI_Datatype recvtype,
+                     MPI_Comm comm)
 {
   int system_tag = COLL_TAG_ALLTOALLV;
   int i, rank, size, err, count;
@@ -78,7 +78,7 @@ int Coll_alltoallv_bruck::alltoallv(const void *sendbuf, const int *sendcounts,
         count++;
       }
       /* Wait for them all. */
-      // Colls::startall(count, requests);
+      // colls::startall(count, requests);
       XBT_DEBUG("<%d> wait for %d requests", rank, count);
       Request::waitall(count, requests, MPI_STATUSES_IGNORE);
       delete[] requests;
