@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -22,16 +22,15 @@
 
  * Descrp: Function works in P - 1 steps. In step i, node j - i -> j -> j + i.
 
- * Auther: Ahmad Faraj
+ * Author: Ahmad Faraj
 
  ****************************************************************************/
 namespace simgrid{
 namespace smpi{
-int
-Coll_alltoallv_ring_one_barrier::alltoallv(const void *send_buff, const int *send_counts, const int *send_disps,
-                                          MPI_Datatype send_type,
-                                          void *recv_buff, const int *recv_counts, const int *recv_disps,
-                                          MPI_Datatype recv_type, MPI_Comm comm)
+int alltoallv__ring_one_barrier(const void *send_buff, const int *send_counts, const int *send_disps,
+                                MPI_Datatype send_type,
+                                void *recv_buff, const int *recv_counts, const int *recv_disps,
+                                MPI_Datatype recv_type, MPI_Comm comm)
 {
   MPI_Status s;
   MPI_Aint send_chunk, recv_chunk;
@@ -46,7 +45,7 @@ Coll_alltoallv_ring_one_barrier::alltoallv(const void *send_buff, const int *sen
   send_chunk = send_type->get_extent();
   recv_chunk = recv_type->get_extent();
 
-  Colls::barrier(comm);
+  colls::barrier(comm);
   for (i = 0; i < num_procs; i++) {
     src = (rank - i + num_procs) % num_procs;
     dst = (rank + i) % num_procs;
