@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -18,9 +18,9 @@ int bcast_arrival_pattern_aware_wait_segment_size_in_byte = 8192;
 namespace simgrid{
 namespace smpi{
 /* Non-topology-specific pipelined linear-bcast function */
-int Coll_bcast_arrival_pattern_aware_wait::bcast(void *buf, int count,
-                                                     MPI_Datatype datatype,
-                                                     int root, MPI_Comm comm)
+int bcast__arrival_pattern_aware_wait(void *buf, int count,
+                                      MPI_Datatype datatype,
+                                      int root, MPI_Comm comm)
 {
   MPI_Status status;
   MPI_Request request;
@@ -239,7 +239,7 @@ int Coll_bcast_arrival_pattern_aware_wait::bcast(void *buf, int count,
   /* when count is not divisible by block size, use default BCAST for the remainder */
   if ((remainder != 0) && (count > segment)) {
     XBT_WARN("MPI_bcast_arrival_pattern_aware_wait use default MPI_bcast.");
-    Colls::bcast((char *)buf + (pipe_length * increment), remainder, datatype, root, comm);
+    colls::bcast((char*)buf + (pipe_length * increment), remainder, datatype, root, comm);
   }
 
   return MPI_SUCCESS;
