@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -14,9 +14,9 @@ static int bcast_NTSL_segment_size_in_byte = 8192;
 namespace simgrid{
 namespace smpi{
 /* Non-topology-specific pipelined linear-bcast function */
-int Coll_bcast_arrival_pattern_aware::bcast(void *buf, int count,
-                                                MPI_Datatype datatype, int root,
-                                                MPI_Comm comm)
+int bcast__arrival_pattern_aware(void *buf, int count,
+                                 MPI_Datatype datatype, int root,
+                                 MPI_Comm comm)
 {
   int tag = -COLL_TAG_BCAST;
   MPI_Status status;
@@ -351,7 +351,7 @@ int Coll_bcast_arrival_pattern_aware::bcast(void *buf, int count,
   /* when count is not divisible by block size, use default BCAST for the remainder */
   if ((remainder != 0) && (count > segment)) {
     XBT_WARN("MPI_bcast_arrival_pattern_aware use default MPI_bcast.");
-    Colls::bcast((char *)buf + (pipe_length * increment), remainder, datatype, root, comm);
+    colls::bcast((char*)buf + (pipe_length * increment), remainder, datatype, root, comm);
   }
 
   return MPI_SUCCESS;
