@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -16,9 +16,9 @@
 namespace simgrid{
 namespace smpi{
 /* Non-topology-specific pipelined linear-bcast function */
-int Coll_bcast_arrival_scatter::bcast(void *buf, int count,
-                                          MPI_Datatype datatype, int root,
-                                          MPI_Comm comm)
+int bcast__arrival_scatter(void *buf, int count,
+                           MPI_Datatype datatype, int root,
+                           MPI_Comm comm)
 {
   int tag = -COLL_TAG_BCAST;//in order to use ANY_TAG, make this one positive
   int header_tag = -10;
@@ -60,7 +60,7 @@ int Coll_bcast_arrival_scatter::bcast(void *buf, int count,
   /* message too small */
   if (count < size) {
     XBT_WARN("MPI_bcast_arrival_scatter use default MPI_bcast.");
-    Colls::bcast(buf, count, datatype, root, comm);
+    colls::bcast(buf, count, datatype, root, comm);
     return MPI_SUCCESS;
   }
 
