@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -11,11 +11,11 @@
 
 namespace simgrid{
 namespace smpi{
-int Coll_bcast_ompi_pipeline::bcast( void* buffer,
-                                      int original_count,
-                                      MPI_Datatype datatype,
-                                      int root,
-                                      MPI_Comm comm)
+int bcast__ompi_pipeline( void* buffer,
+                          int original_count,
+                          MPI_Datatype datatype,
+                          int root,
+                          MPI_Comm comm)
 {
     int count_by_segment = original_count;
     size_t type_size;
