@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -10,9 +10,9 @@
 //#include <star-reduction.c>
 namespace simgrid{
 namespace smpi{
-int Coll_reduce_binomial::reduce(const void *sendbuf, void *recvbuf, int count,
-                                    MPI_Datatype datatype, MPI_Op op, int root,
-                                    MPI_Comm comm)
+int reduce__binomial(const void *sendbuf, void *recvbuf, int count,
+                     MPI_Datatype datatype, MPI_Op op, int root,
+                     MPI_Comm comm)
 {
   MPI_Status status;
   int comm_size, rank;
@@ -29,7 +29,7 @@ int Coll_reduce_binomial::reduce(const void *sendbuf, void *recvbuf, int count,
   extent = datatype->get_extent();
 
   unsigned char* tmp_buf = smpi_get_tmp_sendbuffer(count * extent);
-  int is_commutative =  (op==MPI_OP_NULL || op->is_commutative());
+  bool is_commutative    = (op == MPI_OP_NULL || op->is_commutative());
   mask = 1;
 
   int lroot;
