@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team.
+/* Copyright (c) 2013-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -116,9 +116,9 @@ static int MPIR_Reduce_knomial_trace(int root, int reduce_knomial_factor,
     return 0;
 }
 
-namespace simgrid{
-namespace smpi{
-int Coll_reduce_mvapich2_knomial::reduce (
+namespace simgrid {
+namespace smpi {
+int reduce__mvapich2_knomial(
         const void *sendbuf,
         void *recvbuf,
         int count,
@@ -128,7 +128,7 @@ int Coll_reduce_mvapich2_knomial::reduce (
         MPI_Comm comm)
 {
     int mpi_errno = MPI_SUCCESS;
-    int rank, is_commutative;
+    int rank;
     int src, k;
     MPI_Request send_request;
     int index=0;
@@ -146,7 +146,7 @@ int Coll_reduce_mvapich2_knomial::reduce (
     datatype->extent(&true_lb, &true_extent);
     extent = datatype->get_extent();
 
-    is_commutative =  (op==MPI_OP_NULL || op->is_commutative());
+    bool is_commutative = (op == MPI_OP_NULL || op->is_commutative());
 
     if (rank != root) {
         recvbuf = (void*)smpi_get_tmp_recvbuffer(count * std::max(extent, true_extent));
