@@ -2,7 +2,7 @@
 /* This is the tuning used by MVAPICH for Stampede platform based on (MV2_ARCH_INTEL_XEON_E5_2680_16,
  * MV2_HCA_MLX_CX_FDR) */
 
-/* Copyright (c) 2009-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2009-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -42,19 +42,19 @@ int mv2_alltoall_num_ppn_conf                             = 1;
 int* mv2_size_alltoall_tuning_table                       = NULL;
 mv2_alltoall_tuning_table** mv2_alltoall_thresholds_table = NULL;
 
-#define MPIR_Alltoall_bruck_MV2 simgrid::smpi::Coll_alltoall_bruck::alltoall
-#define MPIR_Alltoall_RD_MV2 simgrid::smpi::Coll_alltoall_rdb::alltoall
-#define MPIR_Alltoall_Scatter_dest_MV2 simgrid::smpi::Coll_alltoall_mvapich2_scatter_dest::alltoall
-#define MPIR_Alltoall_pairwise_MV2 simgrid::smpi::Coll_alltoall_pair::alltoall
-#define MPIR_Alltoall_inplace_MV2 simgrid::smpi::Coll_alltoall_ring::alltoall
+#define MPIR_Alltoall_bruck_MV2 simgrid::smpi::alltoall__bruck
+#define MPIR_Alltoall_RD_MV2 simgrid::smpi::alltoall__rdb
+#define MPIR_Alltoall_Scatter_dest_MV2 simgrid::smpi::alltoall__mvapich2_scatter_dest
+#define MPIR_Alltoall_pairwise_MV2 simgrid::smpi::alltoall__pair
+#define MPIR_Alltoall_inplace_MV2 simgrid::smpi::alltoall__ring
 
 static void init_mv2_alltoall_tables_stampede()
 {
   int agg_table_sum                      = 0;
   mv2_alltoall_tuning_table** table_ptrs = NULL;
   mv2_alltoall_num_ppn_conf              = 3;
-  if (simgrid::smpi::Colls::smpi_coll_cleanup_callback == NULL)
-    simgrid::smpi::Colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
+  if (simgrid::smpi::colls::smpi_coll_cleanup_callback == NULL)
+    simgrid::smpi::colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
   mv2_alltoall_thresholds_table                      = new mv2_alltoall_tuning_table*[mv2_alltoall_num_ppn_conf];
   table_ptrs                                         = new mv2_alltoall_tuning_table*[mv2_alltoall_num_ppn_conf];
   mv2_size_alltoall_tuning_table                     = new int[mv2_alltoall_num_ppn_conf];
@@ -339,7 +339,7 @@ struct mv2_allgather_tuning_element {
 
 struct mv2_allgather_tuning_table {
   int numproc;
-  int two_level[MV2_MAX_NB_THRESHOLDS];
+  bool two_level[MV2_MAX_NB_THRESHOLDS];
   int size_inter_table;
   mv2_allgather_tuning_element inter_leader[MV2_MAX_NB_THRESHOLDS];
 };
@@ -358,17 +358,17 @@ static int MPIR_Allgather_RD_Allgather_Comm_MV2(const void* sendbuf, int sendcou
   return 0;
 }
 
-#define MPIR_Allgather_Bruck_MV2 simgrid::smpi::Coll_allgather_bruck::allgather
-#define MPIR_Allgather_RD_MV2 simgrid::smpi::Coll_allgather_rdb::allgather
-#define MPIR_Allgather_Ring_MV2 simgrid::smpi::Coll_allgather_ring::allgather
-#define MPIR_2lvl_Allgather_MV2 simgrid::smpi::Coll_allgather_mvapich2_smp::allgather
+#define MPIR_Allgather_Bruck_MV2 simgrid::smpi::allgather__bruck
+#define MPIR_Allgather_RD_MV2 simgrid::smpi::allgather__rdb
+#define MPIR_Allgather_Ring_MV2 simgrid::smpi::allgather__ring
+#define MPIR_2lvl_Allgather_MV2 simgrid::smpi::allgather__mvapich2_smp
 
 static void init_mv2_allgather_tables_stampede()
 {
   int agg_table_sum = 0;
 
-  if (simgrid::smpi::Colls::smpi_coll_cleanup_callback == NULL)
-    simgrid::smpi::Colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
+  if (simgrid::smpi::colls::smpi_coll_cleanup_callback == NULL)
+    simgrid::smpi::colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
   mv2_allgather_num_ppn_conf                         = 3;
   mv2_allgather_thresholds_table                     = new mv2_allgather_tuning_table*[mv2_allgather_num_ppn_conf];
   mv2_allgather_tuning_table** table_ptrs            = new mv2_allgather_tuning_table*[mv2_allgather_num_ppn_conf];
@@ -379,7 +379,7 @@ static void init_mv2_allgather_tables_stampede()
   mv2_allgather_tuning_table mv2_tmp_allgather_thresholds_table_1ppn[] = {
       {
           2,
-          {0},
+          {false},
           1,
           {
               {0, -1, &MPIR_Allgather_Ring_MV2},
@@ -387,7 +387,7 @@ static void init_mv2_allgather_tables_stampede()
       },
       {
           4,
-          {0, 0},
+          {false, false},
           2,
           {
               {0, 262144, &MPIR_Allgather_RD_MV2}, {262144, -1, &MPIR_Allgather_Ring_MV2},
@@ -395,7 +395,7 @@ static void init_mv2_allgather_tables_stampede()
       },
       {
           8,
-          {0, 0},
+          {false, false},
           2,
           {
               {0, 131072, &MPIR_Allgather_RD_MV2}, {131072, -1, &MPIR_Allgather_Ring_MV2},
@@ -403,7 +403,7 @@ static void init_mv2_allgather_tables_stampede()
       },
       {
           16,
-          {0, 0},
+          {false, false},
           2,
           {
               {0, 131072, &MPIR_Allgather_RD_MV2}, {131072, -1, &MPIR_Allgather_Ring_MV2},
@@ -411,7 +411,7 @@ static void init_mv2_allgather_tables_stampede()
       },
       {
           32,
-          {0, 0},
+          {false, false},
           2,
           {
               {0, 65536, &MPIR_Allgather_RD_MV2}, {65536, -1, &MPIR_Allgather_Ring_MV2},
@@ -419,7 +419,7 @@ static void init_mv2_allgather_tables_stampede()
       },
       {
           64,
-          {0, 0},
+          {false, false},
           2,
           {
               {0, 32768, &MPIR_Allgather_RD_MV2}, {32768, -1, &MPIR_Allgather_Ring_MV2},
@@ -432,7 +432,7 @@ static void init_mv2_allgather_tables_stampede()
   mv2_allgather_tuning_table mv2_tmp_allgather_thresholds_table_2ppn[] = {
       {
           4,
-          {0, 0},
+          {false, false},
           2,
           {
               {0, 524288, &MPIR_Allgather_RD_MV2}, {524288, -1, &MPIR_Allgather_Ring_MV2},
@@ -440,7 +440,7 @@ static void init_mv2_allgather_tables_stampede()
       },
       {
           8,
-          {0, 1, 0},
+          {false, true, false},
           2,
           {
               {0, 32768, &MPIR_Allgather_RD_MV2},
@@ -450,7 +450,7 @@ static void init_mv2_allgather_tables_stampede()
       },
       {
           16,
-          {0, 1, 0},
+          {false, true, false},
           2,
           {
               {0, 16384, &MPIR_Allgather_RD_MV2},
@@ -460,7 +460,7 @@ static void init_mv2_allgather_tables_stampede()
       },
       {
           32,
-          {1, 1, 0},
+          {true, true, false},
           2,
           {
               {0, 65536, &MPIR_Allgather_RD_MV2},
@@ -470,7 +470,7 @@ static void init_mv2_allgather_tables_stampede()
       },
       {
           64,
-          {1, 1, 0},
+          {true, true, false},
           2,
           {
               {0, 32768, &MPIR_Allgather_RD_MV2},
@@ -480,7 +480,7 @@ static void init_mv2_allgather_tables_stampede()
       },
       {
           128,
-          {1, 1, 0},
+          {true, true, false},
           2,
           {
               {0, 65536, &MPIR_Allgather_RD_MV2},
@@ -495,7 +495,7 @@ static void init_mv2_allgather_tables_stampede()
   mv2_allgather_tuning_table mv2_tmp_allgather_thresholds_table_16ppn[] = {
       {
           16,
-          {0, 0},
+          {false, false},
           2,
           {
               {0, 1024, &MPIR_Allgather_RD_MV2}, {1024, -1, &MPIR_Allgather_Ring_MV2},
@@ -503,7 +503,7 @@ static void init_mv2_allgather_tables_stampede()
       },
       {
           32,
-          {0, 0},
+          {false, false},
           2,
           {
               {0, 1024, &MPIR_Allgather_RD_Allgather_Comm_MV2}, {1024, -1, &MPIR_Allgather_Ring_MV2},
@@ -511,7 +511,7 @@ static void init_mv2_allgather_tables_stampede()
       },
       {
           64,
-          {0, 0},
+          {false, false},
           2,
           {
               {0, 1024, &MPIR_Allgather_RD_Allgather_Comm_MV2}, {1024, -1, &MPIR_Allgather_Ring_MV2},
@@ -519,7 +519,7 @@ static void init_mv2_allgather_tables_stampede()
       },
       {
           128,
-          {0, 0},
+          {false, false},
           2,
           {
               {0, 1024, &MPIR_Allgather_RD_Allgather_Comm_MV2}, {1024, -1, &MPIR_Allgather_Ring_MV2},
@@ -527,7 +527,7 @@ static void init_mv2_allgather_tables_stampede()
       },
       {
           256,
-          {0, 0},
+          {false, false},
           2,
           {
               {0, 1024, &MPIR_Allgather_RD_Allgather_Comm_MV2}, {1024, -1, &MPIR_Allgather_Ring_MV2},
@@ -535,7 +535,7 @@ static void init_mv2_allgather_tables_stampede()
       },
       {
           512,
-          {0, 0},
+          {false, false},
           2,
           {
               {0, 1024, &MPIR_Allgather_RD_Allgather_Comm_MV2}, {1024, -1, &MPIR_Allgather_Ring_MV2},
@@ -583,15 +583,15 @@ typedef int (*MV2_Gather_function_ptr)(const void* sendbuf, int sendcnt, MPI_Dat
 MV2_Gather_function_ptr MV2_Gather_inter_leader_function = NULL;
 MV2_Gather_function_ptr MV2_Gather_intra_node_function   = NULL;
 
-#define MPIR_Gather_MV2_Direct simgrid::smpi::Coll_gather_ompi_basic_linear::gather
-#define MPIR_Gather_MV2_two_level_Direct simgrid::smpi::Coll_gather_mvapich2_two_level::gather
-#define MPIR_Gather_intra simgrid::smpi::Coll_gather_mpich::gather
+#define MPIR_Gather_MV2_Direct simgrid::smpi::gather__ompi_basic_linear
+#define MPIR_Gather_MV2_two_level_Direct simgrid::smpi::gather__mvapich2_two_level
+#define MPIR_Gather_intra simgrid::smpi::gather__mpich
 
 static void init_mv2_gather_tables_stampede()
 {
 
-  if (simgrid::smpi::Colls::smpi_coll_cleanup_callback == NULL)
-    simgrid::smpi::Colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
+  if (simgrid::smpi::colls::smpi_coll_cleanup_callback == NULL)
+    simgrid::smpi::colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
   mv2_size_gather_tuning_table                       = 7;
   mv2_gather_thresholds_table                               = new mv2_gather_tuning_table[mv2_size_gather_tuning_table];
   mv2_gather_tuning_table mv2_tmp_gather_thresholds_table[] = {
@@ -668,14 +668,14 @@ int (*MV2_Allgatherv_function)(const void* sendbuf, int sendcount, MPI_Datatype
 int mv2_size_allgatherv_tuning_table                         = 0;
 mv2_allgatherv_tuning_table* mv2_allgatherv_thresholds_table = NULL;
 
-#define MPIR_Allgatherv_Rec_Doubling_MV2 simgrid::smpi::Coll_allgatherv_mpich_rdb::allgatherv
-#define MPIR_Allgatherv_Bruck_MV2 simgrid::smpi::Coll_allgatherv_ompi_bruck::allgatherv
-#define MPIR_Allgatherv_Ring_MV2 simgrid::smpi::Coll_allgatherv_mpich_ring::allgatherv
+#define MPIR_Allgatherv_Rec_Doubling_MV2 simgrid::smpi::allgatherv__mpich_rdb
+#define MPIR_Allgatherv_Bruck_MV2 simgrid::smpi::allgatherv__ompi_bruck
+#define MPIR_Allgatherv_Ring_MV2 simgrid::smpi::allgatherv__mpich_ring
 
 static void init_mv2_allgatherv_tables_stampede()
 {
-  if (simgrid::smpi::Colls::smpi_coll_cleanup_callback == NULL)
-    simgrid::smpi::Colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
+  if (simgrid::smpi::colls::smpi_coll_cleanup_callback == NULL)
+    simgrid::smpi::colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
   mv2_size_allgatherv_tuning_table                   = 6;
   mv2_allgatherv_thresholds_table = new mv2_allgatherv_tuning_table[mv2_size_allgatherv_tuning_table];
   mv2_allgatherv_tuning_table mv2_tmp_allgatherv_thresholds_table[] = {
@@ -737,8 +737,8 @@ struct mv2_allreduce_tuning_element {
 
 struct mv2_allreduce_tuning_table {
   int numproc;
-  int mcast_enabled;
-  int is_two_level_allreduce[MV2_MAX_NB_THRESHOLDS];
+  bool mcast_enabled;
+  bool is_two_level_allreduce[MV2_MAX_NB_THRESHOLDS];
   int size_inter_table;
   mv2_allreduce_tuning_element inter_leader[MV2_MAX_NB_THRESHOLDS];
   int size_intra_table;
@@ -769,32 +769,32 @@ static int MPIR_Allreduce_mcst_reduce_redscat_gather_MV2(const void* sendbuf, vo
 static int MPIR_Allreduce_reduce_p2p_MV2(const void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype, MPI_Op op,
                                          MPI_Comm comm)
 {
-  simgrid::smpi::Colls::reduce(sendbuf, recvbuf, count, datatype, op, 0, comm);
+  simgrid::smpi::colls::reduce(sendbuf, recvbuf, count, datatype, op, 0, comm);
   return MPI_SUCCESS;
 }
 
 static int MPIR_Allreduce_reduce_shmem_MV2(const void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype, MPI_Op op,
                                            MPI_Comm comm)
 {
-  simgrid::smpi::Colls::reduce(sendbuf, recvbuf, count, datatype, op, 0, comm);
+  simgrid::smpi::colls::reduce(sendbuf, recvbuf, count, datatype, op, 0, comm);
   return MPI_SUCCESS;
 }
 
-#define MPIR_Allreduce_pt2pt_rd_MV2 simgrid::smpi::Coll_allreduce_rdb::allreduce
-#define MPIR_Allreduce_pt2pt_rs_MV2 simgrid::smpi::Coll_allreduce_mvapich2_rs::allreduce
-#define MPIR_Allreduce_two_level_MV2 simgrid::smpi::Coll_allreduce_mvapich2_two_level::allreduce
+#define MPIR_Allreduce_pt2pt_rd_MV2 simgrid::smpi::allreduce__rdb
+#define MPIR_Allreduce_pt2pt_rs_MV2 simgrid::smpi::allreduce__mvapich2_rs
+#define MPIR_Allreduce_two_level_MV2 simgrid::smpi::allreduce__mvapich2_two_level
 
 static void init_mv2_allreduce_tables_stampede()
 {
-  if (simgrid::smpi::Colls::smpi_coll_cleanup_callback == NULL)
-    simgrid::smpi::Colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
+  if (simgrid::smpi::colls::smpi_coll_cleanup_callback == NULL)
+    simgrid::smpi::colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
   mv2_size_allreduce_tuning_table                    = 8;
   mv2_allreduce_thresholds_table                     = new mv2_allreduce_tuning_table[mv2_size_allreduce_tuning_table];
   mv2_allreduce_tuning_table mv2_tmp_allreduce_thresholds_table[] = {
       {
           16,
-          0,
-          {1, 0},
+          false,
+          {true, false},
           2,
           {
               {0, 1024, &MPIR_Allreduce_pt2pt_rd_MV2}, {1024, -1, &MPIR_Allreduce_pt2pt_rs_MV2},
@@ -806,8 +806,8 @@ static void init_mv2_allreduce_tables_stampede()
       },
       {
           32,
-          0,
-          {1, 1, 0},
+          false,
+          {true, true, false},
           3,
           {
               {0, 1024, &MPIR_Allreduce_pt2pt_rd_MV2},
@@ -821,8 +821,8 @@ static void init_mv2_allreduce_tables_stampede()
       },
       {
           64,
-          0,
-          {1, 1, 0},
+          false,
+          {true, true, false},
           3,
           {
               {0, 512, &MPIR_Allreduce_pt2pt_rd_MV2},
@@ -836,8 +836,8 @@ static void init_mv2_allreduce_tables_stampede()
       },
       {
           128,
-          0,
-          {1, 1, 0},
+          false,
+          {true, true, false},
           3,
           {
               {0, 512, &MPIR_Allreduce_pt2pt_rd_MV2},
@@ -851,8 +851,8 @@ static void init_mv2_allreduce_tables_stampede()
       },
       {
           256,
-          0,
-          {1, 1, 0},
+          false,
+          {true, true, false},
           3,
           {
               {0, 512, &MPIR_Allreduce_pt2pt_rd_MV2},
@@ -866,8 +866,8 @@ static void init_mv2_allreduce_tables_stampede()
       },
       {
           512,
-          0,
-          {1, 1, 0},
+          false,
+          {true, true, false},
           3,
           {
               {0, 512, &MPIR_Allreduce_pt2pt_rd_MV2},
@@ -881,8 +881,8 @@ static void init_mv2_allreduce_tables_stampede()
       },
       {
           1024,
-          0,
-          {1, 1, 1, 0},
+          false,
+          {true, true, true, false},
           4,
           {
               {0, 512, &MPIR_Allreduce_pt2pt_rd_MV2},
@@ -897,8 +897,8 @@ static void init_mv2_allreduce_tables_stampede()
       },
       {
           2048,
-          0,
-          {1, 1, 1, 0},
+          false,
+          {true, true, true, false},
           4,
           {
               {0, 64, &MPIR_Allreduce_pt2pt_rd_MV2},
@@ -929,7 +929,7 @@ struct mv2_bcast_tuning_table {
   int bcast_segment_size;
   int intra_node_knomial_factor;
   int inter_node_knomial_factor;
-  int is_two_level_bcast[MV2_MAX_NB_THRESHOLDS];
+  bool is_two_level_bcast[MV2_MAX_NB_THRESHOLDS];
   int size_inter_table;
   mv2_bcast_tuning_element inter_leader[MV2_MAX_NB_THRESHOLDS];
   int size_intra_table;
@@ -955,23 +955,23 @@ int mv2_intra_node_knomial_factor     = 4;
 
 #define INTRA_NODE_ROOT 0
 
-#define MPIR_Pipelined_Bcast_Zcpy_MV2 simgrid::smpi::Coll_bcast_mpich::bcast
-#define MPIR_Pipelined_Bcast_MV2 simgrid::smpi::Coll_bcast_mpich::bcast
-#define MPIR_Bcast_binomial_MV2 simgrid::smpi::Coll_bcast_binomial_tree::bcast
-#define MPIR_Bcast_scatter_ring_allgather_shm_MV2 simgrid::smpi::Coll_bcast_scatter_LR_allgather::bcast
-#define MPIR_Bcast_scatter_doubling_allgather_MV2 simgrid::smpi::Coll_bcast_scatter_rdb_allgather::bcast
-#define MPIR_Bcast_scatter_ring_allgather_MV2 simgrid::smpi::Coll_bcast_scatter_LR_allgather::bcast
-#define MPIR_Shmem_Bcast_MV2 simgrid::smpi::Coll_bcast_mpich::bcast
-#define MPIR_Bcast_tune_inter_node_helper_MV2 simgrid::smpi::Coll_bcast_mvapich2_inter_node::bcast
-#define MPIR_Bcast_inter_node_helper_MV2 simgrid::smpi::Coll_bcast_mvapich2_inter_node::bcast
-#define MPIR_Knomial_Bcast_intra_node_MV2 simgrid::smpi::Coll_bcast_mvapich2_knomial_intra_node::bcast
-#define MPIR_Bcast_intra_MV2 simgrid::smpi::Coll_bcast_mvapich2_intra_node::bcast
+#define MPIR_Pipelined_Bcast_Zcpy_MV2 simgrid::smpi::bcast__mpich
+#define MPIR_Pipelined_Bcast_MV2 simgrid::smpi::bcast__mpich
+#define MPIR_Bcast_binomial_MV2 simgrid::smpi::bcast__binomial_tree
+#define MPIR_Bcast_scatter_ring_allgather_shm_MV2 simgrid::smpi::bcast__scatter_LR_allgather
+#define MPIR_Bcast_scatter_doubling_allgather_MV2 simgrid::smpi::bcast__scatter_rdb_allgather
+#define MPIR_Bcast_scatter_ring_allgather_MV2 simgrid::smpi::bcast__scatter_LR_allgather
+#define MPIR_Shmem_Bcast_MV2 simgrid::smpi::bcast__mpich
+#define MPIR_Bcast_tune_inter_node_helper_MV2 simgrid::smpi::bcast__mvapich2_inter_node
+#define MPIR_Bcast_inter_node_helper_MV2 simgrid::smpi::bcast__mvapich2_inter_node
+#define MPIR_Knomial_Bcast_intra_node_MV2 simgrid::smpi::bcast__mvapich2_knomial_intra_node
+#define MPIR_Bcast_intra_MV2 simgrid::smpi::bcast__mvapich2_intra_node
 
 static void init_mv2_bcast_tables_stampede()
 {
   // Stampede,
-  if (simgrid::smpi::Colls::smpi_coll_cleanup_callback == NULL)
-    simgrid::smpi::Colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
+  if (simgrid::smpi::colls::smpi_coll_cleanup_callback == NULL)
+    simgrid::smpi::colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
   mv2_size_bcast_tuning_table                        = 8;
   mv2_bcast_thresholds_table                         = new mv2_bcast_tuning_table[mv2_size_bcast_tuning_table];
 
@@ -980,7 +980,7 @@ static void init_mv2_bcast_tables_stampede()
        8192,
        4,
        4,
-       {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1},
+       {true, true, true, true, true, true, true, true, true, true, true},
        11,
        {{0, 8, &MPIR_Pipelined_Bcast_Zcpy_MV2, 2},
         {8, 16, &MPIR_Pipelined_Bcast_Zcpy_MV2, 4},
@@ -1009,7 +1009,7 @@ static void init_mv2_bcast_tables_stampede()
        8192,
        4,
        4,
-       {1, 1, 1, 1, 1, 1, 1, 1},
+       {true, true, true, true, true, true, true, true},
        8,
        {{0, 128, &MPIR_Pipelined_Bcast_Zcpy_MV2, 2},
         {128, 256, &MPIR_Pipelined_Bcast_Zcpy_MV2, 4},
@@ -1032,7 +1032,7 @@ static void init_mv2_bcast_tables_stampede()
        8192,
        4,
        4,
-       {1, 1, 1, 1, 1, 1, 1, 1, 1},
+       {true, true, true, true, true, true, true, true, true},
        9,
        {{0, 2, &MPIR_Pipelined_Bcast_Zcpy_MV2, 4},
         {2, 4, &MPIR_Pipelined_Bcast_Zcpy_MV2, 8},
@@ -1057,7 +1057,7 @@ static void init_mv2_bcast_tables_stampede()
        8192,
        4,
        4,
-       {1, 1, 1, 0},
+       {true, true, true, false},
        4,
        {{0, 8192, &MPIR_Pipelined_Bcast_Zcpy_MV2, 8},
         {8192, 16384, &MPIR_Pipelined_Bcast_Zcpy_MV2, 4},
@@ -1072,7 +1072,7 @@ static void init_mv2_bcast_tables_stampede()
        8192,
        4,
        4,
-       {1, 1, 1, 1, 1},
+       {true, true, true, true, true},
        5,
        {{0, 16384, &MPIR_Pipelined_Bcast_Zcpy_MV2, 4},
         {16384, 131072, &MPIR_Pipelined_Bcast_Zcpy_MV2, 2},
@@ -1089,7 +1089,7 @@ static void init_mv2_bcast_tables_stampede()
        8192,
        4,
        4,
-       {1, 1, 1, 1, 1},
+       {true, true, true, true, true},
        5,
        {{0, 4096, &MPIR_Pipelined_Bcast_Zcpy_MV2, 8},
         {4096, 16384, &MPIR_Pipelined_Bcast_Zcpy_MV2, 4},
@@ -1106,7 +1106,7 @@ static void init_mv2_bcast_tables_stampede()
        8192,
        4,
        4,
-       {1, 1, 1, 1, 1},
+       {true, true, true, true, true},
        5,
        {{0, 8192, &MPIR_Pipelined_Bcast_Zcpy_MV2, 8},
         {8192, 16384, &MPIR_Pipelined_Bcast_Zcpy_MV2, 4},
@@ -1123,7 +1123,7 @@ static void init_mv2_bcast_tables_stampede()
        8192,
        4,
        4,
-       {1, 1, 1, 1, 1, 1, 1},
+       {true, true, true, true, true, true, true},
        7,
        {{0, 16, &MPIR_Pipelined_Bcast_Zcpy_MV2, 8},
         {16, 32, &MPIR_Pipelined_Bcast_Zcpy_MV2, 4},
@@ -1157,7 +1157,7 @@ struct mv2_reduce_tuning_table {
   int numproc;
   int inter_k_degree;
   int intra_k_degree;
-  int is_two_level_reduce[MV2_MAX_NB_THRESHOLDS];
+  bool is_two_level_reduce[MV2_MAX_NB_THRESHOLDS];
   int size_inter_table;
   mv2_reduce_tuning_element inter_leader[MV2_MAX_NB_THRESHOLDS];
   int size_intra_table;
@@ -1176,17 +1176,17 @@ int (*MV2_Reduce_function)(const void* sendbuf, void* recvbuf, int count, MPI_Da
 int (*MV2_Reduce_intra_function)(const void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype, MPI_Op op, int root,
                                  MPI_Comm comm_ptr) = NULL;
 
-#define MPIR_Reduce_inter_knomial_wrapper_MV2 simgrid::smpi::Coll_reduce_mvapich2_knomial::reduce
-#define MPIR_Reduce_intra_knomial_wrapper_MV2 simgrid::smpi::Coll_reduce_mvapich2_knomial::reduce
-#define MPIR_Reduce_binomial_MV2 simgrid::smpi::Coll_reduce_binomial::reduce
-#define MPIR_Reduce_redscat_gather_MV2 simgrid::smpi::Coll_reduce_scatter_gather::reduce
-#define MPIR_Reduce_shmem_MV2 simgrid::smpi::Coll_reduce_ompi_basic_linear::reduce
-#define MPIR_Reduce_two_level_helper_MV2 simgrid::smpi::Coll_reduce_mvapich2_two_level::reduce
+#define MPIR_Reduce_inter_knomial_wrapper_MV2 simgrid::smpi::reduce__mvapich2_knomial
+#define MPIR_Reduce_intra_knomial_wrapper_MV2 simgrid::smpi::reduce__mvapich2_knomial
+#define MPIR_Reduce_binomial_MV2 simgrid::smpi::reduce__binomial
+#define MPIR_Reduce_redscat_gather_MV2 simgrid::smpi::reduce__scatter_gather
+#define MPIR_Reduce_shmem_MV2 simgrid::smpi::reduce__ompi_basic_linear
+#define MPIR_Reduce_two_level_helper_MV2 simgrid::smpi::reduce__mvapich2_two_level
 
 static void init_mv2_reduce_tables_stampede()
 {
-  if (simgrid::smpi::Colls::smpi_coll_cleanup_callback == NULL)
-    simgrid::smpi::Colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
+  if (simgrid::smpi::colls::smpi_coll_cleanup_callback == NULL)
+    simgrid::smpi::colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
   /*Stampede*/
   mv2_size_reduce_tuning_table = 8;
   mv2_reduce_thresholds_table                               = new mv2_reduce_tuning_table[mv2_size_reduce_tuning_table];
@@ -1195,7 +1195,7 @@ static void init_mv2_reduce_tables_stampede()
           16,
           4,
           4,
-          {1, 0, 0},
+          {true, false, false},
           3,
           {
               {0, 262144, &MPIR_Reduce_inter_knomial_wrapper_MV2},
@@ -1211,7 +1211,7 @@ static void init_mv2_reduce_tables_stampede()
           32,
           4,
           4,
-          {1, 1, 1, 1, 0, 0, 0},
+          {true, true, true, true, false, false, false},
           7,
           {
               {0, 8192, &MPIR_Reduce_inter_knomial_wrapper_MV2},
@@ -1236,7 +1236,7 @@ static void init_mv2_reduce_tables_stampede()
           64,
           4,
           4,
-          {1, 1, 1, 1, 0},
+          {true, true, true, true, false},
           5,
           {
               {0, 8192, &MPIR_Reduce_inter_knomial_wrapper_MV2},
@@ -1258,7 +1258,7 @@ static void init_mv2_reduce_tables_stampede()
           128,
           4,
           4,
-          {1, 0, 1, 0, 1, 0},
+          {true, false, true, false, true, false},
           6,
           {
               {0, 8192, &MPIR_Reduce_inter_knomial_wrapper_MV2},
@@ -1281,7 +1281,7 @@ static void init_mv2_reduce_tables_stampede()
           256,
           4,
           4,
-          {1, 1, 1, 0, 1, 1, 0},
+          {true, true, true, false, true, true, false},
           7,
           {
               {0, 8192, &MPIR_Reduce_inter_knomial_wrapper_MV2},
@@ -1306,7 +1306,7 @@ static void init_mv2_reduce_tables_stampede()
           512,
           4,
           4,
-          {1, 0, 1, 1, 1, 0},
+          {true, false, true, true, true, false},
           6,
           {
               {0, 8192, &MPIR_Reduce_inter_knomial_wrapper_MV2},
@@ -1329,7 +1329,7 @@ static void init_mv2_reduce_tables_stampede()
           1024,
           4,
           4,
-          {1, 0, 1, 1, 1},
+          {true, false, true, true, true},
           5,
           {
               {0, 8192, &MPIR_Reduce_inter_knomial_wrapper_MV2},
@@ -1351,7 +1351,7 @@ static void init_mv2_reduce_tables_stampede()
           2048,
           4,
           4,
-          {1, 0, 1, 1, 1, 1},
+          {true, false, true, true, true, true},
           6,
           {
               {0, 2048, &MPIR_Reduce_inter_knomial_wrapper_MV2},
@@ -1400,18 +1400,17 @@ int (*MV2_Red_scat_function)(const void* sendbuf, void* recvbuf, const int* recv
 static int MPIR_Reduce_Scatter_Basic_MV2(const void* sendbuf, void* recvbuf, const int* recvcnts, MPI_Datatype datatype, MPI_Op op,
                                          MPI_Comm comm)
 {
-  simgrid::smpi::Coll_reduce_scatter_default::reduce_scatter(sendbuf, recvbuf, recvcnts, datatype, op, comm);
+  simgrid::smpi::reduce_scatter__default(sendbuf, recvbuf, recvcnts, datatype, op, comm);
   return MPI_SUCCESS;
 }
-#define MPIR_Reduce_scatter_non_comm_MV2 simgrid::smpi::Coll_reduce_scatter_mpich_noncomm::reduce_scatter
-#define MPIR_Reduce_scatter_Rec_Halving_MV2                                                                            \
-  simgrid::smpi::Coll_reduce_scatter_ompi_basic_recursivehalving::reduce_scatter
-#define MPIR_Reduce_scatter_Pair_Wise_MV2 simgrid::smpi::Coll_reduce_scatter_mpich_pair::reduce_scatter
+#define MPIR_Reduce_scatter_non_comm_MV2 simgrid::smpi::reduce_scatter__mpich_noncomm
+#define MPIR_Reduce_scatter_Rec_Halving_MV2 simgrid::smpi::reduce_scatter__ompi_basic_recursivehalving
+#define MPIR_Reduce_scatter_Pair_Wise_MV2 simgrid::smpi::reduce_scatter__mpich_pair
 
 static void init_mv2_reduce_scatter_tables_stampede()
 {
-  if (simgrid::smpi::Colls::smpi_coll_cleanup_callback == NULL)
-    simgrid::smpi::Colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
+  if (simgrid::smpi::colls::smpi_coll_cleanup_callback == NULL)
+    simgrid::smpi::colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
   mv2_size_red_scat_tuning_table                     = 6;
   mv2_red_scat_thresholds_table                      = new mv2_red_scat_tuning_table[mv2_size_red_scat_tuning_table];
   mv2_red_scat_tuning_table mv2_tmp_red_scat_thresholds_table[] = {
@@ -1504,15 +1503,15 @@ int MPIR_Scatter_mcst_wrap_MV2(const void* sendbuf, int sendcnt, MPI_Datatype se
   return 0;
 }
 
-#define MPIR_Scatter_MV2_Binomial simgrid::smpi::Coll_scatter_ompi_binomial::scatter
-#define MPIR_Scatter_MV2_Direct simgrid::smpi::Coll_scatter_ompi_basic_linear::scatter
-#define MPIR_Scatter_MV2_two_level_Binomial simgrid::smpi::Coll_scatter_mvapich2_two_level_binomial::scatter
-#define MPIR_Scatter_MV2_two_level_Direct simgrid::smpi::Coll_scatter_mvapich2_two_level_direct::scatter
+#define MPIR_Scatter_MV2_Binomial simgrid::smpi::scatter__ompi_binomial
+#define MPIR_Scatter_MV2_Direct simgrid::smpi::scatter__ompi_basic_linear
+#define MPIR_Scatter_MV2_two_level_Binomial simgrid::smpi::scatter__mvapich2_two_level_binomial
+#define MPIR_Scatter_MV2_two_level_Direct simgrid::smpi::scatter__mvapich2_two_level_direct
 
 static void init_mv2_scatter_tables_stampede()
 {
-  if (simgrid::smpi::Colls::smpi_coll_cleanup_callback == NULL)
-    simgrid::smpi::Colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
+  if (simgrid::smpi::colls::smpi_coll_cleanup_callback == NULL)
+    simgrid::smpi::colls::smpi_coll_cleanup_callback = &smpi_coll_cleanup_mvapich2;
 
   int agg_table_sum = 0;
   mv2_scatter_num_ppn_conf              = 3;
