@@ -1,4 +1,4 @@
-/* Copyright (c) 2010-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2010-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -15,12 +15,12 @@ namespace simgrid{
 namespace smpi{
 
 class Topo {
-  MPI_Comm comm_;
+  MPI_Comm comm_ = MPI_COMM_NULL;
 
 public:
   virtual ~Topo() = default;
   MPI_Comm getComm() const { return comm_; }
-  void setComm(MPI_Comm comm) { comm_ = comm; }
+  void setComm(MPI_Comm comm);
 };
 
 class Topo_Cart: public Topo {
