@@ -1,4 +1,4 @@
-/* Copyright (c) 2010-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2010-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -28,18 +28,10 @@ namespace smpi{
 std::unordered_map<int, smpi_key_elem> Comm::keyvals_;
 int Comm::keyval_id_=0;
 
-Comm::Comm(MPI_Group group, MPI_Topology topo, int smp, int in_id) : group_(group), topo_(topo),is_smp_comm_(smp), id_(in_id)
+Comm::Comm(MPI_Group group, MPI_Topology topo, bool smp, int in_id)
+    : group_(group), topo_(topo), is_smp_comm_(smp), id_(in_id)
 {
-  refcount_        = 1;
-  topoType_        = MPI_INVALID_TOPO;
-  intra_comm_      = MPI_COMM_NULL;
-  leaders_comm_    = MPI_COMM_NULL;
-  is_uniform_      = 1;
-  non_uniform_map_ = nullptr;
-  leaders_map_     = nullptr;
-  is_blocked_      = 0;
-  info_            = MPI_INFO_NULL;
-  errhandler_      = MPI_ERRORS_ARE_FATAL;
+  errhandler_->ref();
   //First creation of comm is done before SIMIX_run, so only do comms for others
   if(in_id==MPI_UNDEFINED && smp==0 && this->rank()!=MPI_UNDEFINED ){
     int id;
@@ -48,10 +40,10 @@ Comm::Comm(MPI_Group group, MPI_Topology topo, int smp, int in_id) : group_(grou
       id=global_id_;
       global_id_++;
     }
-    Colls::bcast(&id, 1, MPI_INT, 0, this);
+    colls::bcast(&id, 1, MPI_INT, 0, this);
     XBT_DEBUG("Communicator %p has id %d", this, id);
     id_=id;//only set here, as we don't want to change it in the middle of the bcast
-    Colls::barrier(this);
+    colls::barrier(this);
   }
 }
 
@@ -61,12 +53,11 @@ void Comm::destroy(Comm* comm)
     Comm::destroy(smpi_process()->comm_world());
     return;
   }
-  delete comm->topo_; // there's no use count on topos
   Comm::unref(comm);
 }
 
 int Comm::dup(MPI_Comm* newcomm){
-  if (smpi_privatize_global_variables == SmpiPrivStrategies::MMAP) {
+  if (smpi_cfg_privatization() == SmpiPrivStrategies::MMAP) {
     // we need to switch as the called function may silently touch global variables
     smpi_switch_data_segment(s4u::Actor::self());
   }
@@ -121,6 +112,7 @@ int Comm::dup_with_info(MPI_Info info, MPI_Comm* newcomm){
     (*newcomm)->info_=MPI_INFO_NULL;
   }
   if(info != MPI_INFO_NULL){
+    info->ref();
     (*newcomm)->info_=info;
   }
   return ret;
@@ -211,19 +203,22 @@ MPI_Comm Comm::get_intra_comm(){
   else return intra_comm_;
 }
 
-int Comm::is_uniform(){
+bool Comm::is_uniform()
+{
   if (this == MPI_COMM_UNINITIALIZED)
     return smpi_process()->comm_world()->is_uniform();
-  return is_uniform_;
+  return is_uniform_ != 0;
 }
 
-int Comm::is_blocked(){
+bool Comm::is_blocked()
+{
   if (this == MPI_COMM_UNINITIALIZED)
     return smpi_process()->comm_world()->is_blocked();
-  return is_blocked_;
+  return is_blocked_ != 0;
 }
 
-int Comm::is_smp_comm(){
+bool Comm::is_smp_comm()
+{
   if (this == MPI_COMM_UNINITIALIZED)
     return smpi_process()->comm_world()->is_smp_comm();
   return is_smp_comm_;
@@ -250,7 +245,7 @@ MPI_Comm Comm::split(int color, int key)
   } else {
     recvbuf = nullptr;
   }
-  Coll_gather_default::gather(sendbuf, 2, MPI_INT, recvbuf, 2, MPI_INT, 0, this);
+  gather__default(sendbuf, 2, MPI_INT, recvbuf, 2, MPI_INT, 0, this);
   xbt_free(sendbuf);
   /* Do the actual job */
   if (myrank == 0) {
@@ -334,16 +329,21 @@ void Comm::unref(Comm* comm){
   if(comm->refcount_==0){
     comm->cleanup_smp();
     comm->cleanup_attr<Comm>();
+    if (comm->info_ != MPI_INFO_NULL)
+      simgrid::smpi::Info::unref(comm->info_);
+    if (comm->errhandler_ != MPI_ERRHANDLER_NULL)
+      simgrid::smpi::Errhandler::unref(comm->errhandler_);
+    delete comm->topo_; // there's no use count on topos
     delete comm;
   }
 }
 
 MPI_Comm Comm::find_intra_comm(int * leader){
   //get the indices of all processes sharing the same simix host
-  auto& process_list      = sg_host_self()->pimpl_->process_list_;
+  auto& actor_list        = sg_host_self()->pimpl_->actor_list_;
   int intra_comm_size     = 0;
   int min_index           = INT_MAX; // the minimum index will be the leader
-  for (auto& actor : process_list) {
+  for (auto& actor : actor_list) {
     int index = actor.get_pid();
     if (this->group()->rank(actor.ciface()) != MPI_UNDEFINED) { // Is this process in the current group?
       intra_comm_size++;
@@ -354,7 +354,7 @@ MPI_Comm Comm::find_intra_comm(int * leader){
   XBT_DEBUG("number of processes deployed on my node : %d", intra_comm_size);
   MPI_Group group_intra = new  Group(intra_comm_size);
   int i = 0;
-  for (auto& actor : process_list) {
+  for (auto& actor : actor_list) {
     if (this->group()->rank(actor.ciface()) != MPI_UNDEFINED) {
       group_intra->set_mapping(actor.ciface(), i);
       i++;
@@ -380,11 +380,11 @@ void Comm::init_smp(){
     smpi_process()->set_replaying(false);
   }
 
-  if (smpi_privatize_global_variables == SmpiPrivStrategies::MMAP) {
+  if (smpi_cfg_privatization() == SmpiPrivStrategies::MMAP) {
     // we need to switch as the called function may silently touch global variables
     smpi_switch_data_segment(s4u::Actor::self());
   }
-  //identify neighbours in comm
+  // identify neighbors in comm
   MPI_Comm comm_intra = find_intra_comm(&leader);
 
 
@@ -393,9 +393,9 @@ void Comm::init_smp(){
   std::fill_n(leaders_map, comm_size, 0);
   std::fill_n(leader_list, comm_size, -1);
 
-  Coll_allgather_ring::allgather(&leader, 1, MPI_INT , leaders_map, 1, MPI_INT, this);
+  allgather__ring(&leader, 1, MPI_INT , leaders_map, 1, MPI_INT, this);
 
-  if (smpi_privatize_global_variables == SmpiPrivStrategies::MMAP) {
+  if (smpi_cfg_privatization() == SmpiPrivStrategies::MMAP) {
     // we need to switch as the called function may silently touch global variables
     smpi_switch_data_segment(s4u::Actor::self());
   }
@@ -418,6 +418,7 @@ void Comm::init_smp(){
       leader_group_size++;
     }
   }
+  xbt_assert(leader_group_size > 0);
   std::sort(leader_list, leader_list + leader_group_size);
 
   MPI_Group leaders_group = new  Group(leader_group_size);
@@ -451,7 +452,7 @@ void Comm::init_smp(){
   if(comm_intra->rank()==0) {
     int is_uniform       = 1;
     int* non_uniform_map = xbt_new0(int,leader_group_size);
-    Coll_allgather_ring::allgather(&my_local_size, 1, MPI_INT,
+    allgather__ring(&my_local_size, 1, MPI_INT,
         non_uniform_map, 1, MPI_INT, leader_comm);
     for(i=0; i < leader_group_size; i++) {
       if(non_uniform_map[0] != non_uniform_map[i]) {
@@ -459,16 +460,16 @@ void Comm::init_smp(){
         break;
       }
     }
-    if(is_uniform==0 && this->is_uniform()!=0){
+    if (is_uniform == 0 && this->is_uniform()) {
       non_uniform_map_ = non_uniform_map;
     }else{
       xbt_free(non_uniform_map);
     }
     is_uniform_=is_uniform;
   }
-  Coll_bcast_scatter_LR_allgather::bcast(&(is_uniform_),1, MPI_INT, 0, comm_intra );
+  bcast__scatter_LR_allgather(&(is_uniform_),1, MPI_INT, 0, comm_intra );
 
-  if (smpi_privatize_global_variables == SmpiPrivStrategies::MMAP) {
+  if (smpi_cfg_privatization() == SmpiPrivStrategies::MMAP) {
     // we need to switch as the called function may silently touch global variables
     smpi_switch_data_segment(s4u::Actor::self());
   }
@@ -485,7 +486,7 @@ void Comm::init_smp(){
   }
 
   int global_blocked;
-  Coll_allreduce_default::allreduce(&is_blocked, &(global_blocked), 1, MPI_INT, MPI_LAND, this);
+  allreduce__default(&is_blocked, &(global_blocked), 1, MPI_INT, MPI_LAND, this);
 
   if(MPI_COMM_WORLD==MPI_COMM_UNINITIALIZED || this==MPI_COMM_WORLD){
     if(this->rank()==0){
@@ -537,30 +538,40 @@ void Comm::finish_rma_calls(){
   }
 }
 
-MPI_Info Comm::info(){
-  if(info_== MPI_INFO_NULL)
+MPI_Info Comm::info()
+{
+  if (info_ == MPI_INFO_NULL)
     info_ = new Info();
   info_->ref();
   return info_;
 }
 
-void Comm::set_info(MPI_Info info){
-  if(info_!= MPI_INFO_NULL)
+void Comm::set_info(MPI_Info info)
+{
+  if (info_ != MPI_INFO_NULL)
+    simgrid::smpi::Info::unref(info);
+  info_ = info;
+  if (info_ != MPI_INFO_NULL)
     info->ref();
-  info_=info;
 }
 
-MPI_Errhandler Comm::errhandler(){
+MPI_Errhandler Comm::errhandler()
+{
+  if (errhandler_ != MPI_ERRHANDLER_NULL)
+    errhandler_->ref();
   return errhandler_;
 }
 
-void Comm::set_errhandler(MPI_Errhandler errhandler){
-  errhandler_=errhandler;
-  if(errhandler_!= MPI_ERRHANDLER_NULL)
-    errhandler->ref();
+void Comm::set_errhandler(MPI_Errhandler errhandler)
+{
+  if (errhandler_ != MPI_ERRHANDLER_NULL)
+    simgrid::smpi::Errhandler::unref(errhandler_);
+  errhandler_ = errhandler;
+  if (errhandler_ != MPI_ERRHANDLER_NULL)
+    errhandler_->ref();
 }
 
-MPI_Comm Comm::split_type(int type, int /*key*/, MPI_Info)
+MPI_Comm Comm::split_type(int type, int /*key*/, const Info*)
 {
   //MPI_UNDEFINED can be given to some nodes... but we need them to still perform the smp part which is collective
   if(type != MPI_COMM_TYPE_SHARED && type != MPI_UNDEFINED){
@@ -571,6 +582,7 @@ MPI_Comm Comm::split_type(int type, int /*key*/, MPI_Info)
   if(type != MPI_UNDEFINED)
     return res;
   else{
+    xbt_assert(res->refcount_ == 1); // ensure the next call to Comm::destroy really frees the comm
     Comm::destroy(res);
     return MPI_COMM_NULL;
   }
