@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -13,6 +13,8 @@
 
 #include "smpi_file.hpp"
 #include "smpi_status.hpp"
+#include "simgrid/s4u/Disk.hpp"
+#include "simgrid/s4u/Host.hpp"
 #include "simgrid/plugins/file_system.h"
 
 #define FP_SIZE sizeof(MPI_Offset)
@@ -25,22 +27,44 @@ namespace simgrid{
 namespace smpi{
 
   File::File(MPI_Comm comm, const char *filename, int amode, MPI_Info info): comm_(comm), flags_(amode), info_(info) {
-    file_= new simgrid::s4u::File(filename, nullptr);
+    if (info_ != MPI_INFO_NULL)
+      info_->ref();
+    std::string fullname=filename;
+    if (simgrid::s4u::Host::current()->get_disks().empty())
+      xbt_die("SMPI/IO : Trying to open file on a diskless host ! Add one to your platform file");
+
+    size_t found=fullname.find('/');
+    //in case no fullpath is provided ... just pick the first mountpoint.
+    if(found==std::string::npos){
+      auto disk = simgrid::s4u::Host::current()->get_disks().front();
+      std::string mount;
+      if (disk->get_host() != simgrid::s4u::Host::current())
+        mount = disk->extension<simgrid::s4u::FileSystemDiskExt>()->get_mount_point(disk->get_host());
+      else
+        mount = disk->extension<simgrid::s4u::FileSystemDiskExt>()->get_mount_point();
+      XBT_DEBUG("No absolute path given for file opening, use '%s'", mount.c_str());
+      mount.append("/");
+      fullname.insert(0, mount);
+    }
+
+    file_= new simgrid::s4u::File(fullname, nullptr);
     list_=nullptr;
     if (comm_->rank() == 0) {
       int size= comm_->size() + FP_SIZE;
       list_ = new char[size];
       errhandler_= SMPI_default_File_Errhandler;
+      errhandler_->ref();
       memset(list_, 0, size);
       shared_file_pointer_ = new MPI_Offset();
       shared_mutex_ = s4u::Mutex::create();
       *shared_file_pointer_ = 0;
       win_=new Win(list_, size, 1, MPI_INFO_NULL, comm_);
     }else{
+      errhandler_ = MPI_ERRHANDLER_NULL;
       win_=new Win(list_, 0, 1, MPI_INFO_NULL, comm_);
     }
-    simgrid::smpi::Colls::bcast(&shared_file_pointer_, 1, MPI_AINT, 0, comm);
-    simgrid::smpi::Colls::bcast(&shared_mutex_, 1, MPI_AINT, 0, comm);
+    simgrid::smpi::colls::bcast(&shared_file_pointer_, 1, MPI_AINT, 0, comm);
+    simgrid::smpi::colls::bcast(&shared_mutex_, 1, MPI_AINT, 0, comm);
     if(comm_->rank() != 0)
       intrusive_ptr_add_ref(&*shared_mutex_);
   }
@@ -52,6 +76,10 @@ namespace smpi{
     }
     delete win_;
     delete file_;
+    if (info_ != MPI_INFO_NULL)
+      simgrid::smpi::Info::unref(info_);
+    if (errhandler_ != MPI_ERRHANDLER_NULL)
+      simgrid::smpi::Errhandler::unref(errhandler_);
   }
 
   int File::close(MPI_File *fh){
@@ -63,7 +91,7 @@ namespace smpi{
     return MPI_SUCCESS;
   }
 
-  int File::del(const char* filename, MPI_Info)
+  int File::del(const char* filename, const Info*)
   {
     //get the file with MPI_MODE_DELETE_ON_CLOSE and then close it
     File* f = new File(MPI_COMM_SELF,filename,MPI_MODE_DELETE_ON_CLOSE|MPI_MODE_RDWR, nullptr);
@@ -124,7 +152,8 @@ namespace smpi{
       fh->file_->seek(position+movesize, SEEK_SET);
     }
     XBT_VERB("Position after read in MPI_File %s : %llu",fh->file_->get_path(), fh->file_->tell());
-    status->count=count*datatype->size();
+    if(status != MPI_STATUS_IGNORE)
+      status->count=count*datatype->size();
     return MPI_SUCCESS;
   }
 
@@ -157,7 +186,7 @@ namespace smpi{
     }
 
     MPI_Offset result;
-    simgrid::smpi::Colls::scan(&val, &result, 1, MPI_OFFSET, MPI_SUM, fh->comm_);
+    simgrid::smpi::colls::scan(&val, &result, 1, MPI_OFFSET, MPI_SUM, fh->comm_);
     fh->seek(result, MPI_SEEK_SET);
     int ret = fh->op_all<simgrid::smpi::File::read>(buf, count, datatype, status);
     if(fh->comm_->rank()==fh->comm_->size()-1){
@@ -166,7 +195,7 @@ namespace smpi{
       fh->shared_mutex_->unlock();
     }
     char c;
-    simgrid::smpi::Colls::bcast(&c, 1, MPI_BYTE, fh->comm_->size()-1, fh->comm_);
+    simgrid::smpi::colls::bcast(&c, 1, MPI_BYTE, fh->comm_->size() - 1, fh->comm_);
     return ret;
   }
 
@@ -177,13 +206,14 @@ namespace smpi{
     MPI_Offset movesize = datatype->get_extent()*count;
     MPI_Offset writesize = datatype->size()*count;
     XBT_DEBUG("Position before write in MPI_File %s : %llu",fh->file_->get_path(),fh->file_->tell());
-    MPI_Offset write = fh->file_->write(writesize, 1);
+    MPI_Offset write = fh->file_->write(writesize, true);
     XBT_VERB("Write in MPI_File %s, %lld bytes written, readsize %lld bytes, movesize %lld", fh->file_->get_path(), write, writesize, movesize);
     if(writesize!=movesize){
       fh->file_->seek(position+movesize, SEEK_SET);
     }
     XBT_VERB("Position after write in MPI_File %s : %llu",fh->file_->get_path(), fh->file_->tell());
-    status->count=count*datatype->size();
+    if(status != MPI_STATUS_IGNORE)
+      status->count=count*datatype->size();
     return MPI_SUCCESS;
   }
 
@@ -205,7 +235,7 @@ namespace smpi{
       val=count*datatype->size();
     }
     MPI_Offset result;
-    simgrid::smpi::Colls::scan(&val, &result, 1, MPI_OFFSET, MPI_SUM, fh->comm_);
+    simgrid::smpi::colls::scan(&val, &result, 1, MPI_OFFSET, MPI_SUM, fh->comm_);
     fh->seek(result, MPI_SEEK_SET);
     int ret = fh->op_all<simgrid::smpi::File::write>(const_cast<void*>(buf), count, datatype, status);
     if(fh->comm_->rank()==fh->comm_->size()-1){
@@ -214,10 +244,27 @@ namespace smpi{
       fh->shared_mutex_->unlock();
     }
     char c;
-    simgrid::smpi::Colls::bcast(&c, 1, MPI_BYTE, fh->comm_->size()-1, fh->comm_);
+    simgrid::smpi::colls::bcast(&c, 1, MPI_BYTE, fh->comm_->size() - 1, fh->comm_);
     return ret;
   }
 
+  int File::set_view(MPI_Offset /*disp*/, MPI_Datatype etype, MPI_Datatype filetype, const char* datarep, const Info*)
+  {
+    etype_=etype;
+    filetype_=filetype;
+    datarep_=std::string(datarep);
+    seek_shared(0,MPI_SEEK_SET);
+    return MPI_SUCCESS;
+  }
+
+  int File::get_view(MPI_Offset* /*disp*/, MPI_Datatype* etype, MPI_Datatype* filetype, char* datarep)
+  {
+    *etype=etype_;
+    *filetype=filetype_;
+    snprintf(datarep, MPI_MAX_NAME_STRING+1, "%s", datarep_.c_str());
+    return MPI_SUCCESS;
+  }
+
   int File::size(){
     return file_->size();
   }
@@ -228,34 +275,44 @@ namespace smpi{
 
   int File::sync(){
     //no idea
-    return simgrid::smpi::Colls::barrier(comm_);
+    return simgrid::smpi::colls::barrier(comm_);
   }
 
-  MPI_Info File::info(){
-    if(info_== MPI_INFO_NULL)
+  MPI_Info File::info()
+  {
+    if (info_ == MPI_INFO_NULL)
       info_ = new Info();
     info_->ref();
     return info_;
   }
 
-  void File::set_info(MPI_Info info){
-    if(info_!= MPI_INFO_NULL)
-      info->ref();
-    info_=info;
+  void File::set_info(MPI_Info info)
+  {
+    if (info_ != MPI_INFO_NULL)
+      simgrid::smpi::Info::unref(info_);
+    info_ = info;
+    if (info_ != MPI_INFO_NULL)
+      info_->ref();
   }
 
   MPI_Comm File::comm(){
     return comm_;
   }
 
-  MPI_Errhandler File::errhandler(){
+  MPI_Errhandler File::errhandler()
+  {
+    if (errhandler_ != MPI_ERRHANDLER_NULL)
+      errhandler_->ref();
     return errhandler_;
   }
 
-  void File::set_errhandler(MPI_Errhandler errhandler){
-    errhandler_=errhandler;
-    if(errhandler_!= MPI_ERRHANDLER_NULL)
-      errhandler->ref();
+  void File::set_errhandler(MPI_Errhandler errhandler)
+  {
+    if (errhandler_ != MPI_ERRHANDLER_NULL)
+      simgrid::smpi::Errhandler::unref(errhandler_);
+    errhandler_ = errhandler;
+    if (errhandler_ != MPI_ERRHANDLER_NULL)
+      errhandler_->ref();
   }
 }
 }
