@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -50,7 +50,7 @@ Request::Request(const void* buf, int count, MPI_Datatype datatype, int src, int
       }
     }
   }
-  // This part handles the problem of non-contiguous memory (for the unserialisation at the reception)
+  // This part handles the problem of non-contiguous memory (for the unserialization at the reception)
   old_buf_  = old_buf;
   size_ = datatype->size() * count;
   datatype->ref();
@@ -108,58 +108,49 @@ void Request::unref(MPI_Request* request)
   }
 }
 
-int Request::match_recv(void* a, void* b, simgrid::kernel::activity::CommImpl*)
+bool Request::match_common(MPI_Request req, MPI_Request sender, MPI_Request receiver)
 {
-  MPI_Request ref = static_cast<MPI_Request>(a);
-  MPI_Request req = static_cast<MPI_Request>(b);
-  XBT_DEBUG("Trying to match a recv of src %d against %d, tag %d against %d, id %d against %d",ref->src_,req->src_, ref->tag_, req->tag_,ref->comm_->id(),req->comm_->id());
+  xbt_assert(sender, "Cannot match against null sender");
+  xbt_assert(receiver, "Cannot match against null receiver");
+  XBT_DEBUG("Trying to match %s of sender src %d against %d, tag %d against %d, id %d against %d",
+            (req == receiver ? "send" : "recv"), sender->src_, receiver->src_, sender->tag_, receiver->tag_,
+            sender->comm_->id(), receiver->comm_->id());
 
-  xbt_assert(ref, "Cannot match recv against null reference");
-  xbt_assert(req, "Cannot match recv against null request");
-  if((ref->comm_->id()==MPI_UNDEFINED || req->comm_->id() == MPI_UNDEFINED || (ref->comm_->id()==req->comm_->id()))
-    && ((ref->src_ == MPI_ANY_SOURCE  && (ref->comm_->group()->rank(req->src_) != MPI_UNDEFINED)) || req->src_ == ref->src_)
-    && ((ref->tag_ == MPI_ANY_TAG && req->tag_ >=0) || req->tag_ == ref->tag_)){
-    //we match, we can transfer some values
-    if(ref->src_ == MPI_ANY_SOURCE)
-      ref->real_src_ = req->src_;
-    if(ref->tag_ == MPI_ANY_TAG)
-      ref->real_tag_ = req->tag_;
-    if(ref->real_size_ < req->real_size_)
-      ref->truncated_ = true;
-    if (req->detached_)
-      ref->detached_sender_=req; //tie the sender to the receiver, as it is detached and has to be freed in the receiver
-    if(req->cancelled_==0)
-      req->cancelled_=-1;//mark as uncancellable
+  if ((receiver->comm_->id() == MPI_UNDEFINED || sender->comm_->id() == MPI_UNDEFINED ||
+       receiver->comm_->id() == sender->comm_->id()) &&
+      ((receiver->src_ == MPI_ANY_SOURCE && (receiver->comm_->group()->rank(sender->src_) != MPI_UNDEFINED)) ||
+       receiver->src_ == sender->src_) &&
+      ((receiver->tag_ == MPI_ANY_TAG && sender->tag_ >= 0) || receiver->tag_ == sender->tag_)) {
+    // we match, we can transfer some values
+    if (receiver->src_ == MPI_ANY_SOURCE)
+      receiver->real_src_ = sender->src_;
+    if (receiver->tag_ == MPI_ANY_TAG)
+      receiver->real_tag_ = sender->tag_;
+    if (receiver->real_size_ < sender->real_size_)
+      receiver->truncated_ = true;
+    if (sender->detached_)
+      receiver->detached_sender_ = sender; // tie the sender to the receiver, as it is detached and has to be freed in
+                                           // the receiver
+    if (req->cancelled_ == 0)
+      req->cancelled_ = -1; // mark as uncancelable
     XBT_DEBUG("match succeeded");
-    return 1;
-  }else return 0;
+    return true;
+  }
+  return false;
 }
 
-int Request::match_send(void* a, void* b, simgrid::kernel::activity::CommImpl*)
+bool Request::match_recv(void* a, void* b, simgrid::kernel::activity::CommImpl*)
 {
   MPI_Request ref = static_cast<MPI_Request>(a);
   MPI_Request req = static_cast<MPI_Request>(b);
-  XBT_DEBUG("Trying to match a send of src %d against %d, tag %d against %d, id %d against %d",ref->src_,req->src_, ref->tag_, req->tag_,ref->comm_->id(),req->comm_->id());
-  xbt_assert(ref, "Cannot match send against null reference");
-  xbt_assert(req, "Cannot match send against null request");
+  return match_common(req, req, ref);
+}
 
-  if((ref->comm_->id()==MPI_UNDEFINED || req->comm_->id() == MPI_UNDEFINED || (ref->comm_->id()==req->comm_->id()))
-      && ((req->src_ == MPI_ANY_SOURCE  && (req->comm_->group()->rank(ref->src_) != MPI_UNDEFINED)) || req->src_ == ref->src_)
-      && ((req->tag_ == MPI_ANY_TAG && ref->tag_ >=0)|| req->tag_ == ref->tag_)){
-    if(req->src_ == MPI_ANY_SOURCE)
-      req->real_src_ = ref->src_;
-    if(req->tag_ == MPI_ANY_TAG)
-      req->real_tag_ = ref->tag_;
-    if(req->real_size_ < ref->real_size_)
-      req->truncated_ = true;
-    if (ref->detached_)
-      req->detached_sender_=ref; //tie the sender to the receiver, as it is detached and has to be freed in the receiver
-    if(req->cancelled_==0)
-      req->cancelled_=-1;//mark as uncancellable
-    XBT_DEBUG("match succeeded");
-    return 1;
-  } else
-    return 0;
+bool Request::match_send(void* a, void* b, simgrid::kernel::activity::CommImpl*)
+{
+  MPI_Request ref = static_cast<MPI_Request>(a);
+  MPI_Request req = static_cast<MPI_Request>(b);
+  return match_common(req, ref, req);
 }
 
 void Request::print_request(const char *message)
@@ -168,11 +159,9 @@ void Request::print_request(const char *message)
        message, this, buf_, size_, src_, dst_, tag_, flags_);
 }
 
-
 /* factories, to hide the internal flags from the caller */
 MPI_Request Request::bsend_init(const void *buf, int count, MPI_Datatype datatype, int dst, int tag, MPI_Comm comm)
 {
-
   return new Request(buf == MPI_BOTTOM ? nullptr : buf, count, datatype, simgrid::s4u::this_actor::get_pid(),
                      comm->group()->actor(dst)->get_pid(), tag, comm,
                      MPI_REQ_PERSISTENT | MPI_REQ_SEND | MPI_REQ_PREPARED | MPI_REQ_BSEND);
@@ -180,7 +169,6 @@ MPI_Request Request::bsend_init(const void *buf, int count, MPI_Datatype datatyp
 
 MPI_Request Request::send_init(const void *buf, int count, MPI_Datatype datatype, int dst, int tag, MPI_Comm comm)
 {
-
   return new Request(buf == MPI_BOTTOM ? nullptr : buf, count, datatype, simgrid::s4u::this_actor::get_pid(),
                      comm->group()->actor(dst)->get_pid(), tag, comm,
                      MPI_REQ_PERSISTENT | MPI_REQ_SEND | MPI_REQ_PREPARED);
@@ -376,15 +364,13 @@ void Request::start()
 
     simgrid::smpi::ActorExt* process = smpi_process_remote(simgrid::s4u::Actor::by_pid(dst_));
 
-    int async_small_thresh = simgrid::config::get_value<int>("smpi/async-small-thresh");
-
     simgrid::s4u::MutexPtr mut = process->mailboxes_mutex();
-    if (async_small_thresh != 0 || (flags_ & MPI_REQ_RMA) != 0)
+    if (smpi_cfg_async_small_thresh() != 0 || (flags_ & MPI_REQ_RMA) != 0)
       mut->lock();
 
-    if (async_small_thresh == 0 && (flags_ & MPI_REQ_RMA) == 0) {
+    if (smpi_cfg_async_small_thresh() == 0 && (flags_ & MPI_REQ_RMA) == 0) {
       mailbox = process->mailbox();
-    } else if (((flags_ & MPI_REQ_RMA) != 0) || static_cast<int>(size_) < async_small_thresh) {
+    } else if (((flags_ & MPI_REQ_RMA) != 0) || static_cast<int>(size_) < smpi_cfg_async_small_thresh()) {
       //We have to check both mailboxes (because SSEND messages are sent to the large mbox).
       //begin with the more appropriate one : the small one.
       mailbox = process->mailbox_small();
@@ -423,7 +409,7 @@ void Request::start()
         process->replaying() ? &smpi_comm_null_copy_buffer_callback : smpi_comm_copy_data_callback, this, -1.0);
     XBT_DEBUG("recv simcall posted");
 
-    if (async_small_thresh != 0 || (flags_ & MPI_REQ_RMA) != 0)
+    if (smpi_cfg_async_small_thresh() != 0 || (flags_ & MPI_REQ_RMA) != 0)
       mut->unlock();
   } else { /* the RECV flag was not set, so this is a send */
     simgrid::smpi::ActorExt* process = smpi_process_remote(simgrid::s4u::Actor::by_pid(dst_));
@@ -437,7 +423,7 @@ void Request::start()
     void* buf = buf_;
     if ((flags_ & MPI_REQ_SSEND) == 0 &&
         ((flags_ & MPI_REQ_RMA) != 0 || (flags_ & MPI_REQ_BSEND) != 0 ||
-         static_cast<int>(size_) < simgrid::config::get_value<int>("smpi/send-is-detached-thresh"))) {
+         static_cast<int>(size_) < smpi_cfg_detached_send_thresh())) {
       void *oldbuf = nullptr;
       detached_    = true;
       XBT_DEBUG("Send request %p is detached", this);
@@ -445,7 +431,7 @@ void Request::start()
       if (not(old_type_->flags() & DT_FLAG_DERIVED)) {
         oldbuf = buf_;
         if (not process->replaying() && oldbuf != nullptr && size_ != 0) {
-          if ((smpi_privatize_global_variables != SmpiPrivStrategies::NONE) &&
+          if ((smpi_cfg_privatization() != SmpiPrivStrategies::NONE) &&
               (static_cast<char*>(buf_) >= smpi_data_exe_start) &&
               (static_cast<char*>(buf_) < smpi_data_exe_start + smpi_data_exe_size)) {
             XBT_DEBUG("Privatization : We are sending from a zone inside global memory. Switch data segment ");
@@ -474,16 +460,14 @@ void Request::start()
       XBT_DEBUG("sending size of %zu : sleep %f ", size_, sleeptime);
     }
 
-    int async_small_thresh = simgrid::config::get_value<int>("smpi/async-small-thresh");
-
     simgrid::s4u::MutexPtr mut = process->mailboxes_mutex();
 
-    if (async_small_thresh != 0 || (flags_ & MPI_REQ_RMA) != 0)
+    if (smpi_cfg_async_small_thresh() != 0 || (flags_ & MPI_REQ_RMA) != 0)
       mut->lock();
 
-    if (not(async_small_thresh != 0 || (flags_ & MPI_REQ_RMA) != 0)) {
+    if (not(smpi_cfg_async_small_thresh() != 0 || (flags_ & MPI_REQ_RMA) != 0)) {
       mailbox = process->mailbox();
-    } else if (((flags_ & MPI_REQ_RMA) != 0) || static_cast<int>(size_) < async_small_thresh) { // eager mode
+    } else if (((flags_ & MPI_REQ_RMA) != 0) || static_cast<int>(size_) < smpi_cfg_async_small_thresh()) { // eager mode
       mailbox = process->mailbox();
       XBT_DEBUG("Is there a corresponding recv already posted in the large mailbox %s?", mailbox->get_cname());
       smx_activity_t action = mailbox->iprobe(1, &match_send, static_cast<void*>(this));
@@ -515,7 +499,7 @@ void Request::start()
     action_   = simcall_comm_isend(
         simgrid::s4u::Actor::by_pid(src_)->get_impl(), mailbox->get_impl(), size_, -1.0, buf, real_size_, &match_send,
         &xbt_free_f, // how to free the userdata if a detached send fails
-        not process->replaying() ? smpi_comm_copy_data_callback : &smpi_comm_null_copy_buffer_callback, this,
+        process->replaying() ? &smpi_comm_null_copy_buffer_callback : smpi_comm_copy_data_callback, this,
         // detach if msg size < eager/rdv switch limit
         detached_);
     XBT_DEBUG("send simcall posted");
@@ -526,7 +510,7 @@ void Request::start()
           smpi_process()->get_tracing_category());
     }
 
-    if (async_small_thresh != 0 || ((flags_ & MPI_REQ_RMA) != 0))
+    if (smpi_cfg_async_small_thresh() != 0 || ((flags_ & MPI_REQ_RMA) != 0))
       mut->unlock();
   }
 }
@@ -605,7 +589,7 @@ int Request::test(MPI_Request * request, MPI_Status * status, int* flag) {
       nsleeps=1;//reset the number of sleeps we will do next time
       if (*request != MPI_REQUEST_NULL && ((*request)->flags_ & MPI_REQ_PERSISTENT) == 0)
         *request = MPI_REQUEST_NULL;
-    } else if (simgrid::config::get_value<bool>("smpi/grow-injected-times")) {
+    } else if (smpi_cfg_grow_injected_times()) {
       nsleeps++;
     }
   }
@@ -614,7 +598,6 @@ int Request::test(MPI_Request * request, MPI_Status * status, int* flag) {
 
 int Request::testsome(int incount, MPI_Request requests[], int *count, int *indices, MPI_Status status[])
 {
-  int ret = MPI_SUCCESS;
   int error=0;
   int count_dead = 0;
   int flag = 0;
@@ -624,7 +607,7 @@ int Request::testsome(int incount, MPI_Request requests[], int *count, int *indi
   *count = 0;
   for (int i = 0; i < incount; i++) {
     if (requests[i] != MPI_REQUEST_NULL && not (requests[i]->flags_ & MPI_REQ_FINISHED)) {
-      ret = test(&requests[i], pstat, &flag);
+      int ret = test(&requests[i], pstat, &flag);
       if(ret!=MPI_SUCCESS)
         error = 1;
       if(flag) {
@@ -722,11 +705,10 @@ int Request::testall(int count, MPI_Request requests[], int* outflag, MPI_Status
   MPI_Status *pstat = status == MPI_STATUSES_IGNORE ? MPI_STATUS_IGNORE : &stat;
   int flag;
   int error = 0;
-  int ret=MPI_SUCCESS;
   *outflag = 1;
   for(int i=0; i<count; i++){
     if (requests[i] != MPI_REQUEST_NULL && not(requests[i]->flags_ & MPI_REQ_PREPARED)) {
-      ret = test(&requests[i], pstat, &flag);
+      int ret = test(&requests[i], pstat, &flag);
       if (flag){
         flag=0;
         requests[i]=MPI_REQUEST_NULL;
@@ -765,7 +747,7 @@ void Request::iprobe(int source, int tag, MPI_Comm comm, int* flag, MPI_Status*
   // This can speed up the execution of certain applications by an order of magnitude, such as HPL
   static int nsleeps = 1;
   double speed        = s4u::this_actor::get_host()->get_speed();
-  double maxrate      = simgrid::config::get_value<double>("smpi/iprobe-cpu-usage");
+  double maxrate      = smpi_cfg_iprobe_cpu_usage();
   MPI_Request request = new Request(nullptr, 0, MPI_CHAR,
                                     source == MPI_ANY_SOURCE ? MPI_ANY_SOURCE : comm->group()->actor(source)->get_pid(),
                                     simgrid::s4u::this_actor::get_pid(), tag, comm, MPI_REQ_PERSISTENT | MPI_REQ_RECV);
@@ -788,7 +770,7 @@ void Request::iprobe(int source, int tag, MPI_Comm comm, int* flag, MPI_Status*
 
   request->print_request("New iprobe");
   // We have to test both mailboxes as we don't know if we will receive one or another
-  if (simgrid::config::get_value<int>("smpi/async-small-thresh") > 0) {
+  if (smpi_cfg_async_small_thresh() > 0) {
     mailbox = smpi_process()->mailbox_small();
     XBT_DEBUG("Trying to probe the perm recv mailbox");
     request->action_ = mailbox->iprobe(0, &match_recv, static_cast<void*>(request));
@@ -802,7 +784,7 @@ void Request::iprobe(int source, int tag, MPI_Comm comm, int* flag, MPI_Status*
 
   if (request->action_ != nullptr){
     kernel::activity::CommImplPtr sync_comm = boost::static_pointer_cast<kernel::activity::CommImpl>(request->action_);
-    MPI_Request req                         = static_cast<MPI_Request>(sync_comm->src_data_);
+    const Request* req                      = static_cast<MPI_Request>(sync_comm->src_data_);
     *flag = 1;
     if (status != MPI_STATUS_IGNORE && (req->flags_ & MPI_REQ_PREPARED) == 0) {
       status->MPI_SOURCE = comm->group()->rank(req->src_);
@@ -814,7 +796,7 @@ void Request::iprobe(int source, int tag, MPI_Comm comm, int* flag, MPI_Status*
   }
   else {
     *flag = 0;
-    if (simgrid::config::get_value<bool>("smpi/grow-injected-times"))
+    if (smpi_cfg_grow_injected_times())
       nsleeps++;
   }
   unref(&request);
@@ -852,8 +834,7 @@ void Request::finish_wait(MPI_Request* request, MPI_Status * status)
       // FIXME Handle the case of a partial shared malloc.
       if (((req->flags_ & MPI_REQ_ACCUMULATE) != 0) ||
           (datatype->flags() & DT_FLAG_DERIVED)) { // && (not smpi_is_shared(req->old_buf_))){
-
-        if (not smpi_process()->replaying() && smpi_privatize_global_variables != SmpiPrivStrategies::NONE &&
+        if (not smpi_process()->replaying() && smpi_cfg_privatization() != SmpiPrivStrategies::NONE &&
             static_cast<char*>(req->old_buf_) >= smpi_data_exe_start &&
             static_cast<char*>(req->old_buf_) < smpi_data_exe_start + smpi_data_exe_size) {
           XBT_VERB("Privatization : We are unserializing to a zone in global memory  Switch data segment ");
@@ -861,7 +842,7 @@ void Request::finish_wait(MPI_Request* request, MPI_Status * status)
         }
 
         if(datatype->flags() & DT_FLAG_DERIVED){
-          // This part handles the problem of non-contignous memory the unserialization at the reception
+          // This part handles the problem of non-contiguous memory the unserialization at the reception
           if ((req->flags_ & MPI_REQ_RECV) && datatype->size() != 0)
             datatype->unserialize(req->buf_, req->old_buf_, req->real_size_/datatype->size() , req->op_);
           xbt_free(req->buf_);
@@ -1114,7 +1095,8 @@ int Request::waitsome(int incount, MPI_Request requests[], int *indices, MPI_Sta
   return count;
 }
 
-MPI_Request Request::f2c(int id) {
+MPI_Request Request::f2c(int id)
+{
   char key[KEY_SIZE];
   if(id==MPI_FORTRAN_REQUEST_NULL)
     return static_cast<MPI_Request>(MPI_REQUEST_NULL);
@@ -1129,7 +1111,8 @@ void Request::free_f(int id)
   }
 }
 
-int Request::get_status(MPI_Request req, int* flag, MPI_Status * status){
+int Request::get_status(const Request* req, int* flag, MPI_Status* status)
+{
   *flag=0;
 
   if(req != MPI_REQUEST_NULL && req->action_ != nullptr) {
@@ -1156,8 +1139,9 @@ int Request::get_status(MPI_Request req, int* flag, MPI_Status * status){
   return MPI_SUCCESS;
 }
 
-int Request::grequest_start( MPI_Grequest_query_function *query_fn, MPI_Grequest_free_function *free_fn, MPI_Grequest_cancel_function *cancel_fn, void *extra_state, MPI_Request *request){
-
+int Request::grequest_start(MPI_Grequest_query_function* query_fn, MPI_Grequest_free_function* free_fn,
+                            MPI_Grequest_cancel_function* cancel_fn, void* extra_state, MPI_Request* request)
+{
   *request = new Request();
   (*request)->flags_ |= MPI_REQ_GENERALIZED;
   (*request)->flags_ |= MPI_REQ_PERSISTENT;
@@ -1172,7 +1156,8 @@ int Request::grequest_start( MPI_Grequest_query_function *query_fn, MPI_Grequest
   return MPI_SUCCESS;
 }
 
-int Request::grequest_complete( MPI_Request request){
+int Request::grequest_complete(MPI_Request request)
+{
   if ((!(request->flags_ & MPI_REQ_GENERALIZED)) || request->generalized_funcs->mutex==NULL) 
     return MPI_ERR_REQUEST;
   request->generalized_funcs->mutex->lock();
