@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2013-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -22,52 +22,6 @@ namespace surf {
 /*********
  * Model *
  *********/
-/* Helper function for executeParallelTask */
-static inline double has_cost(const double* array, size_t pos)
-{
-  if (array)
-    return array[pos];
-  return -1.0;
-}
-
-kernel::resource::Action* HostModel::execute_parallel(const std::vector<s4u::Host*>& host_list,
-                                                      const double* flops_amount, const double* bytes_amount,
-                                                      double rate)
-{
-  kernel::resource::Action* action = nullptr;
-  if ((host_list.size() == 1) && (has_cost(bytes_amount, 0) <= 0) && (has_cost(flops_amount, 0) > 0)) {
-    action = host_list[0]->pimpl_cpu->execution_start(flops_amount[0]);
-  } else if ((host_list.size() == 1) && (has_cost(flops_amount, 0) <= 0)) {
-    action = surf_network_model->communicate(host_list[0], host_list[0], bytes_amount[0], rate);
-  } else if ((host_list.size() == 2) && (has_cost(flops_amount, 0) <= 0) && (has_cost(flops_amount, 1) <= 0)) {
-    int nb = 0;
-    double value = 0.0;
-
-    for (size_t i = 0; i < host_list.size() * host_list.size(); i++) {
-      if (has_cost(bytes_amount, i) > 0.0) {
-        nb++;
-        value = has_cost(bytes_amount, i);
-      }
-    }
-    if (nb == 1) {
-      action = surf_network_model->communicate(host_list[0], host_list[1], value, rate);
-    } else if (nb == 0) {
-      xbt_die("Cannot have a communication with no flop to exchange in this model. You should consider using the "
-          "ptask model");
-    } else {
-      xbt_die("Cannot have a communication that is not a simple point-to-point in this model. You should consider "
-          "using the ptask model");
-    }
-  } else {
-    xbt_die(
-        "This model only accepts one of the following. You should consider using the ptask model for the other cases.\n"
-        " - execution with one host only and no communication\n"
-        " - Self-comms with one host only\n"
-        " - Communications with two hosts and no computation");
-  }
-  return action;
-}
-
 /************
  * Resource *
  ************/
@@ -80,13 +34,13 @@ HostImpl::HostImpl(s4u::Host* host) : piface_(host)
 
 HostImpl::~HostImpl()
 {
-  /* All processes should be gone when the host is turned off (by the end of the simulation). */
-  if (not process_list_.empty()) {
+  /* All actors should be gone when the host is turned off (by the end of the simulation). */
+  if (not actor_list_.empty()) {
     std::string msg = std::string("Shutting down host, but it's not empty:");
-    for (auto const& process : process_list_)
-      msg += "\n\t" + std::string(process.get_name());
+    for (auto const& actor : actor_list_)
+      msg += "\n\t" + std::string(actor.get_name());
 
-    SIMIX_display_process_status();
+    simix_global->display_all_actor_status();
     xbt_die("%s", msg.c_str());
   }
   for (auto const& arg : actors_at_boot_)
@@ -119,18 +73,16 @@ void HostImpl::turn_on()
 }
 
 /** Kill all actors hosted here */
-void HostImpl::turn_off()
+void HostImpl::turn_off(kernel::actor::ActorImpl* issuer)
 {
-  if (not process_list_.empty()) {
-    for (auto& actor : process_list_) {
-      XBT_DEBUG("Killing Actor %s@%s on behalf of %s which turned off that host.", actor.get_cname(),
-                actor.get_host()->get_cname(), SIMIX_process_self()->get_cname());
-      SIMIX_process_self()->kill(&actor);
-    }
+  for (auto& actor : actor_list_) {
+    XBT_DEBUG("Killing Actor %s@%s on behalf of %s which turned off that host.", actor.get_cname(),
+              actor.get_host()->get_cname(), issuer->get_cname());
+    issuer->kill(&actor);
   }
   // When a host is turned off, we want to keep only the actors that should restart for when it will boot again.
   // Then get rid of the others.
-  auto elm = remove_if(begin(actors_at_boot_), end(actors_at_boot_), [](kernel::actor::ProcessArg* arg) {
+  auto elm = remove_if(begin(actors_at_boot_), end(actors_at_boot_), [](const kernel::actor::ProcessArg* arg) {
     if (arg->auto_restart)
       return false;
     delete arg;
@@ -142,24 +94,31 @@ void HostImpl::turn_off()
 std::vector<s4u::ActorPtr> HostImpl::get_all_actors()
 {
   std::vector<s4u::ActorPtr> res;
-  for (auto& actor : process_list_)
+  for (auto& actor : actor_list_)
     res.push_back(actor.ciface());
   return res;
 }
 size_t HostImpl::get_actor_count()
 {
-  return process_list_.size();
+  return actor_list_.size();
 }
 
 std::vector<s4u::Disk*> HostImpl::get_disks()
 {
   std::vector<s4u::Disk*> disks;
   for (auto const& d : disks_)
-    disks.push_back(&d->piface_);
+    disks.push_back(d->get_iface());
   return disks;
 }
 
-void HostImpl::add_disk(s4u::Disk* disk)
+void HostImpl::set_disks(const std::vector<kernel::resource::DiskImpl*>& disks, s4u::Host* host)
+{
+  disks_ = std::move(disks);
+  for (auto d : disks_)
+    d->set_host(host);
+}
+
+void HostImpl::add_disk(const s4u::Disk* disk)
 {
   disks_.push_back(disk->get_impl());
 }
@@ -181,9 +140,16 @@ std::vector<const char*> HostImpl::get_attached_storages()
   std::vector<const char*> storages;
   for (auto const& s : storage_)
     if (s.second->get_host() == piface_->get_cname())
-      storages.push_back(s.second->piface_.get_cname());
+      storages.push_back(s.second->get_iface()->get_cname());
   return storages;
 }
-
+std::unordered_map<std::string, s4u::Storage*>* HostImpl::get_mounted_storages()
+{
+  std::unordered_map<std::string, s4u::Storage*>* mounts = new std::unordered_map<std::string, s4u::Storage*>();
+  for (auto const& m : storage_) {
+    mounts->insert({m.first, m.second->get_iface()});
+  }
+  return mounts;
+}
 } // namespace surf
 } // namespace simgrid
