@@ -1,12 +1,13 @@
-/* Copyright (c) 2013-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2013-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include "network_cm02.hpp"
+#include "src/surf/network_cm02.hpp"
 #include "simgrid/s4u/Host.hpp"
 #include "simgrid/sg_config.hpp"
 #include "src/kernel/resource/profile/Event.hpp"
+#include "src/surf/network_wifi.hpp"
 #include "src/surf/surf_interface.hpp"
 #include "surf/surf.hpp"
 
@@ -93,17 +94,16 @@ NetworkCm02Model::NetworkCm02Model(kernel::lmm::System* (*make_new_lmm_system)(b
 LinkImpl* NetworkCm02Model::create_link(const std::string& name, const std::vector<double>& bandwidths, double latency,
                                         s4u::Link::SharingPolicy policy)
 {
-  if (policy == s4u::Link::SharingPolicy::WIFI) {
-    return (new NetworkWifiLink(this, name, bandwidths, policy, get_maxmin_system()));
-  }
-  xbt_assert(bandwidths.size() == 1, "Non WIFI links must use only 1 bandwidth.");
+  if (policy == s4u::Link::SharingPolicy::WIFI)
+    return new NetworkWifiLink(this, name, bandwidths, get_maxmin_system());
+
+  xbt_assert(bandwidths.size() == 1, "Non-WIFI links must use only 1 bandwidth.");
   return new NetworkCm02Link(this, name, bandwidths[0], latency, policy, get_maxmin_system());
 }
 
 void NetworkCm02Model::update_actions_state_lazy(double now, double /*delta*/)
 {
   while (not get_action_heap().empty() && double_equals(get_action_heap().top_date(), now, sg_surf_precision)) {
-
     auto* action = static_cast<NetworkCm02Action*>(get_action_heap().pop());
     XBT_DEBUG("Something happened to action %p", action);
 
@@ -189,7 +189,7 @@ Action* NetworkCm02Model::communicate(s4u::Host* src, s4u::Host* dst, double siz
   action->latency_ = latency;
   action->rate_ = rate;
 
-  if (get_update_algorithm() == Model::UpdateAlgo::LAZY) {
+  if (is_update_lazy()) {
     action->set_last_update();
   }
 
@@ -214,7 +214,7 @@ Action* NetworkCm02Model::communicate(s4u::Host* src, s4u::Host* dst, double siz
 
   if (action->latency_ > 0) {
     action->set_variable(get_maxmin_system()->variable_new(action, 0.0, -1.0, constraints_per_variable));
-    if (get_update_algorithm() == Model::UpdateAlgo::LAZY) {
+    if (is_update_lazy()) {
       // add to the heap the event when the latency is payed
       double date = action->latency_ + action->get_last_update();
 
@@ -241,15 +241,14 @@ Action* NetworkCm02Model::communicate(s4u::Host* src, s4u::Host* dst, double siz
     if (link->get_sharing_policy() == s4u::Link::SharingPolicy::WIFI) {
       NetworkWifiLink* wifi_link = static_cast<NetworkWifiLink*>(link);
 
-      double src_rate = wifi_link->get_host_rate(src);
-      double dst_rate = wifi_link->get_host_rate(dst);
-      xbt_assert(
-          !(src_rate == -1 && dst_rate == -1),
-          "Some Stations are not associated to any Access Point. Make sure to call set_host_rate on all Stations.");
-      if (src_rate != -1)
-        get_maxmin_system()->expand(link->get_constraint(), action->get_variable(), 1.0 / src_rate);
-      else
-        get_maxmin_system()->expand(link->get_constraint(), action->get_variable(), 1.0 / dst_rate);
+      double wifi_rate = wifi_link->get_host_rate(src);
+      if (wifi_rate == -1.0)
+        wifi_rate = wifi_link->get_host_rate(dst);
+      xbt_assert(wifi_rate != -1.0,
+                 "None of the source (%s) or destination (%s) is connected to the Access Point '%s'. "
+                 "Please use set_host_rate() on all stations.",
+                 src->get_cname(), dst->get_cname(), link->get_cname());
+      get_maxmin_system()->expand(link->get_constraint(), action->get_variable(), 1.0 / wifi_rate);
 
     } else {
       get_maxmin_system()->expand(link->get_constraint(), action->get_variable(), 1.0);
@@ -306,7 +305,7 @@ NetworkCm02Link::NetworkCm02Link(NetworkCm02Model* model, const std::string& nam
   if (policy == s4u::Link::SharingPolicy::FATPIPE)
     get_constraint()->unshare();
 
-  simgrid::s4u::Link::on_creation(this->piface_);
+  simgrid::s4u::Link::on_creation(*get_iface());
 }
 
 void NetworkCm02Link::apply_event(kernel::profile::Event* triggered, double value)
@@ -323,9 +322,8 @@ void NetworkCm02Link::apply_event(kernel::profile::Event* triggered, double valu
   } else if (triggered == state_event_) {
     if (value > 0)
       turn_on();
-    else {
+    else
       turn_off();
-    }
     tmgr_trace_event_unref(&state_event_);
   } else {
     xbt_die("Unknown event!\n");
@@ -347,7 +345,7 @@ void NetworkCm02Link::set_bandwidth(double value)
   if (sg_weight_S_parameter > 0) {
     double delta = sg_weight_S_parameter / value - sg_weight_S_parameter / (bandwidth_.peak * bandwidth_.scale);
 
-    kernel::lmm::Variable* var;
+    const kernel::lmm::Variable* var;
     const kernel::lmm::Element* elem     = nullptr;
     const kernel::lmm::Element* nextelem = nullptr;
     int numelem                  = 0;
@@ -363,7 +361,7 @@ void NetworkCm02Link::set_bandwidth(double value)
 void NetworkCm02Link::set_latency(double value)
 {
   double delta                 = value - latency_.peak;
-  kernel::lmm::Variable* var   = nullptr;
+  const kernel::lmm::Variable* var;
   const kernel::lmm::Element* elem     = nullptr;
   const kernel::lmm::Element* nextelem = nullptr;
   int numelem                  = 0;
@@ -392,45 +390,6 @@ void NetworkCm02Link::set_latency(double value)
   }
 }
 
-NetworkWifiLink::NetworkWifiLink(NetworkCm02Model* model, const std::string& name, std::vector<double> bandwidths,
-                                 s4u::Link::SharingPolicy policy, lmm::System* system)
-    : NetworkCm02Link(
-          model, name, 1 / sg_bandwidth_factor, 0, policy,
-          system) // Since link use bw*sg_bandwidth_factor we should divise in order to as 1 as bound in the lmm system
-{
-  for (auto bandwidth : bandwidths) {
-    bandwidths_.push_back({bandwidth, 1.0, nullptr});
-  }
-}
-
-void NetworkWifiLink::set_host_rate(s4u::Host* host, int rate_level)
-{
-  auto insert_done = host_rates_.insert(std::make_pair(host->get_name(), rate_level));
-  if (insert_done.second == false)
-    insert_done.first->second = rate_level;
-}
-
-double NetworkWifiLink::get_host_rate(sg_host_t host)
-{
-  std::map<xbt::string, int>::iterator host_rates_it;
-  host_rates_it = host_rates_.find(host->get_name());
-
-  if (host_rates_it == host_rates_.end())
-    return -1;
-
-  int rate_id = host_rates_it->second;
-  xbt_assert(rate_id >= 0 && rate_id < (int)bandwidths_.size(), "Host \"%s\" has an invalid rate \"%d\"",
-             host->get_name().c_str(), rate_id);
-
-  Metric rate = bandwidths_[rate_id];
-  return rate.peak * rate.scale;
-}
-
-s4u::Link::SharingPolicy NetworkWifiLink::get_sharing_policy()
-{
-  return s4u::Link::SharingPolicy::WIFI;
-}
-
 /**********
  * Action *
  **********/
