@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2013-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -18,7 +18,7 @@ class NetworkConstantModel : public NetworkModel {
 public:
   NetworkConstantModel();
   Action* communicate(s4u::Host* src, s4u::Host* dst, double size, double rate) override;
-  double next_occuring_event(double now) override;
+  double next_occurring_event(double now) override;
   void update_actions_state(double now, double delta) override;
 
   LinkImpl* create_link(const std::string& name, const std::vector<double>& bws, double lat,
