@@ -1,4 +1,4 @@
-/* Copyright (c) 2014-2019. The SimGrid Team.
+/* Copyright (c) 2014-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -19,13 +19,10 @@ namespace resource {
 
 class XBT_PRIVATE IBNode;
 
-class XBT_PRIVATE ActiveComm {
-public:
-  IBNode* destination;
-  NetworkAction* action;
-  double init_rate;
-  ActiveComm() : destination(nullptr), action(nullptr), init_rate(-1){};
-  virtual ~ActiveComm() = default;
+struct XBT_PRIVATE ActiveComm {
+  IBNode* destination   = nullptr;
+  NetworkAction* action = nullptr;
+  double init_rate      = -1;
 };
 
 class IBNode {
@@ -36,8 +33,8 @@ public:
   // store the number of comms received from each node
   std::map<IBNode*, int> ActiveCommsDown;
   // number of comms the node is receiving
-  int nbActiveCommsDown;
-  explicit IBNode(int id) : id(id), nbActiveCommsDown(0){};
+  int nbActiveCommsDown = 0;
+  explicit IBNode(int id) : id(id){};
   virtual ~IBNode() = default;
 };
 
@@ -57,7 +54,6 @@ public:
 
   std::unordered_map<std::string, IBNode> active_nodes;
   std::unordered_map<NetworkAction*, std::pair<IBNode*, IBNode*>> active_comms;
-
 };
 } // namespace resource
 } // namespace kernel
