@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2013-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -21,7 +21,7 @@ extern std::map<std::string, simgrid::kernel::resource::StorageType*> storage_ty
 void check_disk_attachment()
 {
   for (auto const& s : simgrid::s4u::Engine::get_instance()->get_all_storages()) {
-    simgrid::kernel::routing::NetPoint* host_elm =
+    const simgrid::kernel::routing::NetPoint* host_elm =
         simgrid::s4u::Engine::get_instance()->netpoint_by_name_or_null(s->get_impl()->get_host());
     if (not host_elm)
       surf_parse_error(std::string("Unable to attach storage ") + s->get_cname() + ": host " +
@@ -52,7 +52,7 @@ StorageN11Model::StorageN11Model()
 StorageImpl* StorageN11Model::createStorage(const std::string& id, const std::string& type_id,
                                             const std::string& content_name, const std::string& attach)
 {
-  StorageType* storage_type = storage_types.at(type_id);
+  const StorageType* storage_type = storage_types.at(type_id);
 
   double Bread =
       surf_parse_get_bandwidth(storage_type->model_properties->at("Bread").c_str(), "property Bread, storage", type_id);
@@ -66,9 +66,9 @@ StorageImpl* StorageN11Model::createStorage(const std::string& id, const std::st
                         attach);
 }
 
-double StorageN11Model::next_occuring_event(double now)
+double StorageN11Model::next_occurring_event(double now)
 {
-  return StorageModel::next_occuring_event_full(now);
+  return StorageModel::next_occurring_event_full(now);
 }
 
 void StorageN11Model::update_actions_state(double /*now*/, double delta)
@@ -96,7 +96,7 @@ StorageN11::StorageN11(StorageModel* model, const std::string& name, lmm::System
     : StorageImpl(model, name, maxminSystem, bread, bwrite, type_id, content_name, size, attach)
 {
   XBT_DEBUG("Create resource with Bread '%f' Bwrite '%f' and Size '%llu'", bread, bwrite, size);
-  s4u::Storage::on_creation(this->piface_);
+  s4u::Storage::on_creation(*get_iface());
 }
 
 StorageAction* StorageN11::io_start(sg_size_t size, s4u::Io::OpType type)
@@ -127,10 +127,10 @@ StorageN11Action::StorageN11Action(Model* model, double cost, bool failed, Stora
   model->get_maxmin_system()->expand(storage->get_constraint(), get_variable(), 1.0);
   switch(type) {
     case s4u::Io::OpType::READ:
-      model->get_maxmin_system()->expand(storage->constraint_read_, get_variable(), 1.0);
+      model->get_maxmin_system()->expand(storage->get_read_constraint(), get_variable(), 1.0);
       break;
     case s4u::Io::OpType::WRITE:
-      model->get_maxmin_system()->expand(storage->constraint_write_, get_variable(), 1.0);
+      model->get_maxmin_system()->expand(storage->get_write_constraint(), get_variable(), 1.0);
       break;
     default:
       THROW_UNIMPLEMENTED;
