@@ -1,25 +1,18 @@
-/* Copyright (c) 2005-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2005-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "src/internal_config.h"
 
-#include "simgrid/simix.h" /* SIMIX_process_self_get_name() */
 #include <xbt/backtrace.hpp>
-#include <xbt/log.h>
 #include <xbt/string.hpp>
 #include <xbt/sysdep.h>
+#include <xbt/virtu.h>
 
-#include <cstddef>
+#include <cstdio>
 #include <cstdlib>
-#include <cstring>
-#include <fstream>
 #include <sstream>
-#include <sys/stat.h>
-#include <vector>
-
-#include <boost/algorithm/string.hpp>
 
 // Try to detect and use the C++ itanium ABI for name demangling:
 #ifdef __GXX_ABI_VERSION
@@ -34,8 +27,6 @@
 #include <boost/stacktrace.hpp>
 #endif
 
-XBT_LOG_NEW_DEFAULT_SUBCATEGORY(xbt_backtrace, xbt, "Backtrace");
-
 /** @brief show the backtrace of the current point (lovely while debugging) */
 void xbt_backtrace_display_current()
 {
@@ -60,95 +51,32 @@ std::unique_ptr<char, std::function<void(char*)>> demangle(const char* name)
 }
 
 class BacktraceImpl {
-  short refcount_ = 1;
-
-public:
-  void ref() { refcount_++; }
-  bool unref()
-  {
-    refcount_--;
-    if (refcount_ == 0) {
-      delete this;
-      return true;
-    } else {
-      return false;
-    }
-  }
 #if HAVE_BOOST_STACKTRACE_BACKTRACE || HAVE_BOOST_STACKTRACE_ADDR2LINE
-  boost::stacktrace::stacktrace st;
+  const boost::stacktrace::stacktrace st = boost::stacktrace::stacktrace();
+#else
+  const char st[1] = ""; // fallback value
 #endif
+public:
+  std::string resolve() const
+  {
+    std::stringstream ss;
+    ss << st;
+    return ss.str();
+  }
 };
 
-Backtrace::Backtrace()
-{
-#if HAVE_BOOST_STACKTRACE_BACKTRACE || HAVE_BOOST_STACKTRACE_ADDR2LINE
-  impl_     = new BacktraceImpl();
-  impl_->st = boost::stacktrace::stacktrace();
-#endif
-}
-Backtrace::Backtrace(const Backtrace& bt)
-{
-  impl_ = bt.impl_;
-  if (impl_)
-    impl_->ref();
-}
+Backtrace::Backtrace() : impl_(std::make_shared<BacktraceImpl>()) {}
 
-Backtrace::Backtrace(Backtrace&& bt)
+std::string Backtrace::resolve() const
 {
-  impl_    = bt.impl_;
-  bt.impl_ = nullptr;
-}
-
-Backtrace& Backtrace::operator=(const Backtrace& rhs)
-{
-  if (this != &rhs) {
-    if (impl_)
-      impl_->unref();
-    impl_ = rhs.impl_;
-    if (impl_)
-      impl_->ref();
-  }
-  return *this;
-}
-
-Backtrace& Backtrace::operator=(Backtrace&& rhs)
-{
-  if (this != &rhs) {
-    if (impl_)
-      impl_->unref();
-    impl_     = rhs.impl_;
-    rhs.impl_ = nullptr;
-  }
-  return *this;
-}
-
-Backtrace::~Backtrace()
-{
-  if (impl_)
-    impl_->unref();
-}
-
-std::string const Backtrace::resolve() const
-{
-  std::string result("");
-
-#if HAVE_BOOST_STACKTRACE_BACKTRACE || HAVE_BOOST_STACKTRACE_ADDR2LINE
-  std::stringstream ss;
-  ss << impl_->st;
-  result.append(ss.str());
-#endif
-  return result;
+  return impl_->resolve();
 }
 
 void Backtrace::display() const
 {
   std::string backtrace = resolve();
-  if (backtrace.empty()) {
-    fprintf(stderr, "(backtrace not set -- did you install Boost.Stacktrace?)\n");
-    return;
-  }
-  fprintf(stderr, "Backtrace (displayed in actor %s):\n", SIMIX_process_self_get_name());
-  std::fprintf(stderr, "%s\n", backtrace.c_str());
+  std::fprintf(stderr, "Backtrace (displayed in actor %s):\n%s\n", xbt_procname(),
+               backtrace.empty() ? "(backtrace not set -- did you install Boost.Stacktrace?)" : backtrace.c_str());
 }
 
 } // namespace xbt
