@@ -1,4 +1,4 @@
-/* Copyright (c) 2004-2019. The SimGrid Team. All rights reserved.     */
+/* Copyright (c) 2004-2020. The SimGrid Team. All rights reserved.     */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -25,7 +25,6 @@ static void make_set()
 
 TEST_CASE("xbt::config: Configuration support", "config")
 {
-
   SECTION("Alloc and free a config set")
   {
     auto temp = simgrid_config;
@@ -47,7 +46,7 @@ TEST_CASE("xbt::config: Configuration support", "config")
     int ival = simgrid::config::get_value<int>("speed");
     REQUIRE(ival == 42); // Unexpected value for speed
 
-    INFO("Access to a non-existant entry");
+    INFO("Access to a non-existent entry");
 
     REQUIRE_THROWS_AS(simgrid::config::set_parse("color:blue"), std::out_of_range);
 
