@@ -1,7 +1,7 @@
-/* dict_elm - elements of generic dictionnaries                             */
+/* dict_elm - elements of generic dictionaries                             */
 /* This file is not to be loaded from anywhere but dict.cpp                 */
 
-/* Copyright (c) 2004-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -17,7 +17,7 @@
 #include "xbt/dict.h"
 #include "xbt/mallocator.h"
 
-SG_BEGIN_DECL()
+SG_BEGIN_DECL
 
 typedef struct s_xbt_dict {
   void_f_pvoid_t free_f;
@@ -34,9 +34,9 @@ XBT_PRIVATE void * dict_elm_mallocator_new_f(void);
 
 /*####[ Function prototypes ]################################################*/
 XBT_PRIVATE xbt_dictelm_t xbt_dictelm_new(const char* key, int key_len, unsigned int hash_code, void* content);
-XBT_PRIVATE void xbt_dictelm_free(xbt_dict_t dict, xbt_dictelm_t element);
-XBT_PRIVATE void xbt_dictelm_set_data(xbt_dict_t dict, xbt_dictelm_t element, void* data);
+XBT_PRIVATE void xbt_dictelm_free(const_xbt_dict_t dict, xbt_dictelm_t element);
+XBT_PRIVATE void xbt_dictelm_set_data(const_xbt_dict_t dict, xbt_dictelm_t element, void* data);
 
-SG_END_DECL()
+SG_END_DECL
 
 #endif
