@@ -1,6 +1,6 @@
 /* log - a generic logging facility in the spirit of log4j                  */
 
-/* Copyright (c) 2004-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2004-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -123,10 +123,8 @@ void xbt_log_init(int *argc, char **argv)
   }
 }
 
-static void log_cat_exit(xbt_log_category_t cat)
+static void log_cat_exit(const s_xbt_log_category_t* cat)
 {
-  xbt_log_category_t child;
-
   if (cat->appender) {
     if (cat->appender->free_)
       cat->appender->free_(cat->appender);
@@ -138,7 +136,7 @@ static void log_cat_exit(xbt_log_category_t cat)
     xbt_free(cat->layout);
   }
 
-  for (child = cat->firstChild; child != nullptr; child = child->nextSibling)
+  for (auto const* child = cat->firstChild; child != nullptr; child = child->nextSibling)
     log_cat_exit(child);
 }
 
@@ -157,14 +155,14 @@ static constexpr size_t XBT_LOG_DYNAMIC_BUFFER_SIZE = 4096;
 
 void _xbt_log_event_log(xbt_log_event_t ev, const char *fmt, ...)
 {
-  xbt_log_category_t cat = ev->cat;
+  const xbt_log_category_s* cat = ev->cat;
 
   xbt_assert(ev->priority >= 0, "Negative logging priority naturally forbidden");
   xbt_assert(static_cast<size_t>(ev->priority) < sizeof(xbt_log_priority_names)/sizeof(xbt_log_priority_names[0]),
              "Priority %d is greater than the biggest allowed value", ev->priority);
 
   while (1) {
-    xbt_log_appender_t appender = cat->appender;
+    const s_xbt_log_appender_t* appender = cat->appender;
 
     if (appender != nullptr) {
       xbt_assert(cat->layout, "No valid layout for the appender of category %s", cat->name);
@@ -180,7 +178,6 @@ void _xbt_log_event_log(xbt_log_event_t ev, const char *fmt, ...)
       if (done) {
         appender->do_append(appender, buff);
       } else {
-
         /* The static buffer was too small, use a dynamically expanded one */
         ev->buffer_size = XBT_LOG_DYNAMIC_BUFFER_SIZE;
         ev->buffer      = static_cast<char*>(xbt_malloc(ev->buffer_size));
@@ -283,7 +280,7 @@ int _xbt_log_cat_init(xbt_log_category_t category, e_xbt_log_priority_t priority
 
     if (XBT_LOG_ISENABLED(log, xbt_log_priority_debug)) {
       std::string res;
-      xbt_log_category_t cpp = category->parent->firstChild;
+      const xbt_log_category_s* cpp = category->parent->firstChild;
       while (cpp) {
         res += std::string(" ") + cpp->name;
         cpp = cpp->nextSibling;
@@ -341,7 +338,7 @@ void xbt_log_parent_set(xbt_log_category_t cat, xbt_log_category_t parent)
   cat->isThreshInherited = 1;
 }
 
-static void _set_inherited_thresholds(xbt_log_category_t cat)
+static void _set_inherited_thresholds(const s_xbt_log_category_t* cat)
 {
   xbt_log_category_t child = cat->firstChild;
 
@@ -632,7 +629,7 @@ static void xbt_log_help_categories_rec(xbt_log_category_t category, const std::
     cats.push_back(cat);
 
   std::sort(begin(cats), end(cats),
-            [](xbt_log_category_t a, xbt_log_category_t b) { return strcmp(a->name, b->name) < 0; });
+            [](const s_xbt_log_category_t* a, const s_xbt_log_category_t* b) { return strcmp(a->name, b->name) < 0; });
 
   for (auto const& cat : cats) {
     XBT_HELP("%s%s: %s", this_prefix.c_str(), cat->name, cat->description);
