@@ -1,4 +1,4 @@
-/* Copyright (c) 2008-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2008-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -197,7 +197,7 @@ std::vector<VmMap> get_memory_map(pid_t pid)
 
     /* Ok we are good enough to try to get the info we need */
     /* First get the start and the end address of the map   */
-    char* tok = strtok_r(lfields[0], "-", &saveptr);
+    const char* tok = strtok_r(lfields[0], "-", &saveptr);
     if (tok == nullptr) {
       std::fprintf(stderr,
                    "Start and end address of the map are not concatenated by a hyphen (-). Recovery impossible.\n");
