@@ -1,6 +1,6 @@
 /* Classical synchro schema, implemented on top of SimGrid                  */
 
-/* Copyright (c) 2007-2019. The SimGrid Team.
+/* Copyright (c) 2007-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -12,8 +12,6 @@
 #include "src/kernel/activity/MutexImpl.hpp"
 #include "xbt/synchro.h"
 
-XBT_LOG_NEW_DEFAULT_SUBCATEGORY(xbt_sync, xbt, "Synchronization mechanism");
-
 /****** mutex related functions ******/
 xbt_mutex_t xbt_mutex_init(void)
 {
@@ -59,12 +57,12 @@ int xbt_cond_timedwait(xbt_cond_t cond, xbt_mutex_t mutex, double delay)
 
 void xbt_cond_signal(xbt_cond_t cond)
 {
-  cond->cond_.notify_one();
+  cond->get_iface()->notify_one();
 }
 
 void xbt_cond_broadcast(xbt_cond_t cond)
 {
-  cond->cond_.notify_all();
+  cond->get_iface()->notify_all();
 }
 
 void xbt_cond_destroy(xbt_cond_t cond)
