@@ -1,4 +1,4 @@
-/* Copyright (c) 2012-2019. The SimGrid Team.
+/* Copyright (c) 2012-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -32,11 +32,11 @@ typedef s_peer_t* peer_t;
 /* Peer: helper functions */
 msg_error_t peer_wait_for_message(peer_t peer);
 int peer_execute_task(peer_t peer, msg_task_t task);
-void peer_init_chain(peer_t peer, message_t msg);
+void peer_init_chain(peer_t peer, const s_message_t* msg);
 void peer_delete(peer_t p);
-void peer_shutdown(peer_t p);
+void peer_shutdown(const s_peer_t* p);
 void peer_init(peer_t p, int argc, char* argv[]);
-void peer_print_stats(peer_t p, float elapsed_time);
+void peer_print_stats(const s_peer_t* p, float elapsed_time);
 
 int peer(int argc, char* argv[]);
 
