@@ -1,4 +1,4 @@
-/* Copyright (c) 2010-2019. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2010-2020. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -15,8 +15,7 @@ int tasks_done = 0;
 
 static void task_cleanup_handler(void* task)
 {
-  if (task)
-    MSG_task_destroy(static_cast<msg_task_t>(task));
+  MSG_task_destroy(static_cast<msg_task_t>(task));
 }
 
 static int process_daemon(int /*argc*/, char** /*argv*/)
@@ -108,7 +107,7 @@ static int test_launcher(int /*argc*/, char** /*argv*/)
   }
 
   test = 3;
-  // Create a process running sucessive sleeps on a host and turn the host off during the execution of the process.
+  // Create a process running successive sleeps on a host and turn the host off during the execution of the process.
   if (xbt_dynar_search_or_negative(tests, &test) != -1) {
     xbt_die("Test 3 is superseeded by activity-lifecycle");
   }
