@@ -1,4 +1,4 @@
-/* Copyright (c) 2014-2019. The SimGrid Team.
+/* Copyright (c) 2014-2020. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -6,12 +6,9 @@
 
 /* Bug report: https://gforge.inria.fr/tracker/index.php?func=detail&aid=17132&group_id=12&atid=165 */
 
-#include "xbt/log.h"
 #include <stdio.h>
 #include <mpi.h>
 
-XBT_LOG_NEW_DEFAULT_CATEGORY(MM_mpi, "Messages for this SMPI test");
-
 int main(int argc, char ** argv)
 {
   size_t M = 8*1024;
