@@ -24,13 +24,13 @@
 
          call test_pair_send( comm, errs )
          call test_pair_ssend( comm, errs )
-         !call test_pair_rsend( comm, errs )
+         call test_pair_rsend( comm, errs )
          call test_pair_isend( comm, errs )
-         !call test_pair_irsend( comm, errs )
+         call test_pair_irsend( comm, errs )
          call test_pair_issend( comm, errs )
          call test_pair_psend( comm, errs )
-         !call test_pair_prsend( comm, errs )
-         !call test_pair_pssend( comm, errs )
+         call test_pair_prsend( comm, errs )
+         call test_pair_pssend( comm, errs )
          call test_pair_sendrecv( comm, errs )
          call test_pair_sendrecvrepl( comm, errs )
          call mtestFreeComm( comm )
