@@ -1,6 +1,6 @@
 #!/usr/bin/env perl
 
-# Copyright (c) 2012-2019. The SimGrid Team. All rights reserved.
+# Copyright (c) 2012-2020. The SimGrid Team. All rights reserved.
 
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the license (GNU LGPL) which comes with this package.
@@ -14,7 +14,7 @@ my $count = 0;
 while (defined(my $arg = shift)) {
 #    print "arg($count)$arg\n";
     if ($arg =~ m!/smpirun$!) {
-        @argv = ( $arg, "-keep-temps", "-wrapper", "@argv" );
+        @argv = ( $arg, "-keep-temps", "-quiet", "-wrapper", "@argv" );
     } elsif ($arg eq "--cd") {
         $arg = shift;
         print "cd $arg\n";
